@@ -28,7 +28,6 @@
 #include "itkLimiterFunctionBase.h"
 #include "itkFixedArray.h"
 #include "itkAdvancedTransform.h"
-#include <vnl/vnl_sparse_matrix.h>
 
 #include "itkImageMaskSpatialObject.h"
 
@@ -36,9 +35,9 @@
 #include "itkAdvancedBSplineDeformableTransform.h"
 #include "itkAdvancedCombinationTransform.h"
 
-#include "itkPlatformMultiThreader.h"
-
+#include <cassert>
 #include <memory> // For unique_ptr.
+#include <typeinfo>
 
 namespace itk
 {
@@ -120,20 +119,20 @@ public:
   using typename Superclass::GradientPixelType;
   using typename Superclass::GradientImageType;
   using typename Superclass::GradientImagePointer;
-  using typename Superclass::GradientImageFilterType;
-  using typename Superclass::GradientImageFilterPointer;
-  using typename Superclass::FixedImageMaskType;
-  using typename Superclass::FixedImageMaskPointer;
-  using typename Superclass::MovingImageMaskType;
-  using typename Superclass::MovingImageMaskPointer;
+
+  // Overrule the mask type from its base class, ITK ImageToImageMetric.
+  using FixedImageMaskType = ImageMaskSpatialObject<Self::FixedImageDimension>;
+  using FixedImageMaskPointer = SmartPointer<FixedImageMaskType>;
+  using FixedImageMaskConstPointer = SmartPointer<const FixedImageMaskType>;
+  using MovingImageMaskType = ImageMaskSpatialObject<Self::MovingImageDimension>;
+  using MovingImageMaskPointer = SmartPointer<MovingImageMaskType>;
+  using MovingImageMaskConstPointer = SmartPointer<const MovingImageMaskType>;
+
   using typename Superclass::MeasureType;
   using typename Superclass::DerivativeType;
   using DerivativeValueType = typename DerivativeType::ValueType;
   using typename Superclass::ParametersType;
 
-  using FixedImageMaskSpatialObject2Type = ImageMaskSpatialObject<Self::FixedImageDimension>;
-  using MovingImageMaskSpatialObject2Type = ImageMaskSpatialObject<Self::MovingImageDimension>;
-
   /** Some useful extra typedefs. */
   using FixedImagePixelType = typename FixedImageType::PixelType;
   using MovingImageRegionType = typename MovingImageType::RegionType;
@@ -167,43 +166,75 @@ public:
   using BSplineOrder2TransformPointer = typename BSplineOrder2TransformType::Pointer;
   using BSplineOrder3TransformPointer = typename BSplineOrder3TransformType::Pointer;
 
-  /** Hessian type; for SelfHessian (experimental feature) */
-  using HessianValueType = typename DerivativeType::ValueType;
-  using HessianType = vnl_sparse_matrix<HessianValueType>;
-
-  /** Typedefs for multi-threading. */
-  using ThreaderType = itk::PlatformMultiThreader;
-  using ThreadInfoType = typename ThreaderType::WorkUnitInfo;
+  /** Typedef for multi-threading. */
+  using ThreadInfoType = MultiThreaderBase::WorkUnitInfo;
 
   /** Public methods ********************/
 
+  virtual void
+  SetFixedImageMask(const FixedImageMaskType * const arg)
+  {
+    assert(arg == nullptr || typeid(*arg) == typeid(FixedImageMaskType));
+    Superclass::SetFixedImageMask(arg);
+  }
+
+  virtual void
+  SetMovingImageMask(const MovingImageMaskType * const arg)
+  {
+    assert(arg == nullptr || typeid(*arg) == typeid(MovingImageMaskType));
+    Superclass::SetMovingImageMask(arg);
+  }
+
+  const FixedImageMaskType *
+  GetFixedImageMask() const override
+  {
+    const auto * const mask = Superclass::GetFixedImageMask();
+    assert(mask == nullptr || typeid(*mask) == typeid(FixedImageMaskType));
+    return static_cast<const FixedImageMaskType *>(mask);
+  }
+
+  const MovingImageMaskType *
+  GetMovingImageMask() const override
+  {
+    const auto * const mask = Superclass::GetMovingImageMask();
+    assert(mask == nullptr || typeid(*mask) == typeid(MovingImageMaskType));
+    return static_cast<const MovingImageMaskType *>(mask);
+  }
+
   /** Set the transform, of advanced type. */
   virtual void
   SetTransform(AdvancedTransformType * arg)
   {
     this->Superclass::SetTransform(arg);
-    if (this->m_AdvancedTransform != arg)
+    if (m_AdvancedTransform != arg)
     {
-      this->m_AdvancedTransform = arg;
+      m_AdvancedTransform = arg;
       this->Modified();
     }
   }
 
 
   /** Get the advanced transform. */
+  AdvancedTransformType *
+  GetTransform() override
+  {
+    return m_AdvancedTransform.GetPointer();
+  }
+
+  /** Get the advanced transform. Const overload. */
   const AdvancedTransformType *
   GetTransform() const override
   {
-    return this->m_AdvancedTransform.GetPointer();
+    return m_AdvancedTransform.GetPointer();
   }
 
 
   /** Set/Get the image sampler. */
   itkSetObjectMacro(ImageSampler, ImageSamplerType);
-  virtual ImageSamplerType *
+  ImageSamplerType *
   GetImageSampler() const
   {
-    return this->m_ImageSampler.GetPointer();
+    return m_ImageSampler.GetPointer();
   }
 
 
@@ -267,16 +298,6 @@ public:
   void
   Initialize() override;
 
-  /** Experimental feature: compute SelfHessian.
-   * This base class just returns an identity matrix of the right size.
-   */
-  virtual void
-  GetSelfHessian(const TransformParametersType & parameters, HessianType & H) const;
-
-  /** Set number of threads to use for computations. */
-  virtual void
-  SetNumberOfWorkUnits(ThreadIdType numberOfThreads);
-
   /** Switch the function BeforeThreadedGetValueAndDerivative on or off. */
   itkSetMacro(UseMetricSingleThreaded, bool);
   itkGetConstReferenceMacro(UseMetricSingleThreaded, bool);
@@ -330,8 +351,6 @@ protected:
   using LinearInterpolatorType = AdvancedLinearInterpolateImageFunction<MovingImageType, CoordinateRepresentationType>;
   using LinearInterpolatorPointer = typename LinearInterpolatorType::Pointer;
   using MovingImageDerivativeType = typename BSplineInterpolatorType::CovariantVectorType;
-  using CentralDifferenceGradientFilterType = GradientImageFilter<MovingImageType, RealType, RealType>;
-  using CentralDifferenceGradientFilterPointer = typename CentralDifferenceGradientFilterType::Pointer;
 
   /** Typedefs for support of sparse Jacobians and compact support of transformations. */
   using NonZeroJacobianIndicesType = typename AdvancedTransformType::NonZeroJacobianIndicesType;
@@ -343,26 +362,13 @@ protected:
    */
   mutable ImageSamplerPointer m_ImageSampler{ nullptr };
 
-  /** Variables for image derivative computation. */
-  bool                              m_InterpolatorIsLinear{ false };
-  bool                              m_InterpolatorIsBSpline{ false };
-  bool                              m_InterpolatorIsBSplineFloat{ false };
-  bool                              m_InterpolatorIsReducedBSpline{ false };
-  LinearInterpolatorPointer         m_LinearInterpolator{ nullptr };
-  BSplineInterpolatorPointer        m_BSplineInterpolator{ nullptr };
-  BSplineInterpolatorFloatPointer   m_BSplineInterpolatorFloat{ nullptr };
-  ReducedBSplineInterpolatorPointer m_ReducedBSplineInterpolator{ nullptr };
-
-  CentralDifferenceGradientFilterPointer m_CentralDifferenceGradientFilter{ nullptr };
-
   /** Variables to store the AdvancedTransform. */
-  bool                                    m_TransformIsAdvanced{ false };
   typename AdvancedTransformType::Pointer m_AdvancedTransform{ nullptr };
-  mutable bool                            m_TransformIsBSpline{ false };
+
+  /** Member variable for TransformPenaltyTerm::CheckForBSplineTransform2 */
+  mutable bool m_TransformIsBSpline{ false };
 
   /** Variables for the Limiters. */
-  FixedImageLimiterPointer     m_FixedImageLimiter{ nullptr };
-  MovingImageLimiterPointer    m_MovingImageLimiter{ nullptr };
   FixedImagePixelType          m_FixedImageTrueMin{ 0 };
   FixedImagePixelType          m_FixedImageTrueMax{ 1 };
   MovingImagePixelType         m_MovingImageTrueMin{ 0 };
@@ -375,13 +381,11 @@ protected:
   /** Multi-threaded metric computation. */
 
   /** Multi-threaded version of GetValue(). */
-  virtual void
-  ThreadedGetValue(ThreadIdType threadID)
-  {}
+  virtual void ThreadedGetValue(ThreadIdType) const {}
 
   /** Finalize multi-threaded metric computation. */
   virtual void
-  AfterThreadedGetValue(MeasureType & value) const
+  AfterThreadedGetValue(MeasureType &) const
   {}
 
   /** GetValue threader callback function. */
@@ -393,13 +397,11 @@ protected:
   LaunchGetValueThreaderCallback() const;
 
   /** Multi-threaded version of GetValueAndDerivative(). */
-  virtual void
-  ThreadedGetValueAndDerivative(ThreadIdType threadID)
-  {}
+  virtual void ThreadedGetValueAndDerivative(ThreadIdType) const {}
 
   /** Finalize multi-threaded metric computation. */
   virtual void
-  AfterThreadedGetValueAndDerivative(MeasureType & value, DerivativeType & derivative) const
+  AfterThreadedGetValueAndDerivative(MeasureType &, DerivativeType &) const
   {}
 
   /** GetValueAndDerivative threader callback function. */
@@ -417,7 +419,6 @@ protected:
   /** Variables for multi-threading. */
   bool m_UseMetricSingleThreaded{ true };
   bool m_UseMultiThread{ false };
-  bool m_UseOpenMP;
 
   /** Helper structs that multi-threads the computation of
    * the metric derivative using ITK threads.
@@ -430,7 +431,7 @@ protected:
     DerivativeValueType * st_DerivativePointer;
     DerivativeValueType   st_NormalizationFactor;
   };
-  mutable MultiThreaderParameterType m_ThreaderMetricParameters;
+  mutable MultiThreaderParameterType m_ThreaderMetricParameters{};
 
   /** Most metrics will perform multi-threading by letting
    * each thread compute a part of the value and derivative.
@@ -441,17 +442,6 @@ protected:
    * these member variables are mutable.
    */
 
-  // test per thread struct with padding and alignment
-  struct GetValuePerThreadStruct
-  {
-    SizeValueType st_NumberOfPixelsCounted;
-    MeasureType   st_Value;
-  };
-  itkPadStruct(ITK_CACHE_LINE_ALIGNMENT, GetValuePerThreadStruct, PaddedGetValuePerThreadStruct);
-  itkAlignedTypedef(ITK_CACHE_LINE_ALIGNMENT, PaddedGetValuePerThreadStruct, AlignedGetValuePerThreadStruct);
-  mutable std::unique_ptr<AlignedGetValuePerThreadStruct[]> m_GetValuePerThreadVariables{ nullptr };
-  mutable ThreadIdType                                      m_GetValuePerThreadVariablesSize{ 0 };
-
   // test per thread struct with padding and alignment
   struct GetValueAndDerivativePerThreadStruct
   {
@@ -488,14 +478,14 @@ protected:
 
   /** Check if enough samples have been found to compute a reliable
    * estimate of the value/derivative; throws an exception if not. */
-  virtual void
+  void
   CheckNumberOfSamples(unsigned long wanted, unsigned long found) const;
 
   /** Methods for image derivative evaluation support **********/
 
   /** Initialize variables for image derivative computation; this
    * method is called by Initialize. */
-  virtual void
+  void
   CheckForBSplineInterpolator();
 
   /** Compute the image value (and possibly derivative) at a transformed point.
@@ -540,11 +530,11 @@ protected:
    * If so, we can speed up derivative calculations by only inspecting
    * the parameters in the support region of a point.
    */
-  virtual void
+  void
   CheckForAdvancedTransform();
 
   /** Check if the transform is a B-spline. Called by Initialize. */
-  virtual void
+  void
   CheckForBSplineTransform() const;
 
   /** Transform a point from FixedImage domain to MovingImage domain. */
@@ -557,7 +547,7 @@ protected:
    * The m_NonZeroJacobianIndices contains the indices that are nonzero.
    * The length of NonZeroJacobianIndices is set in the CheckForAdvancedTransform
    * function. */
-  virtual bool
+  bool
   EvaluateTransformJacobian(const FixedImagePointType &  fixedImagePoint,
                             TransformJacobianType &      jacobian,
                             NonZeroJacobianIndicesType & nzji) const;
@@ -568,7 +558,7 @@ protected:
 
   /** Initialize the {Fixed,Moving}[True]{Max,Min}[Limit] and the {Fixed,Moving}ImageLimiter
    * Only does something when Use{Fixed,Moving}Limiter is set to true; */
-  virtual void
+  void
   InitializeLimiters();
 
   /** Inheriting classes can specify whether they use the image limiter functionality
@@ -579,6 +569,34 @@ protected:
   double m_FixedLimitRangeRatio{ 0.01 };
   double m_MovingLimitRangeRatio{ 0.01 };
 
+  // Prevent accidentally calling SetFixedImageMask or SetMovingImageMask through the ITK ImageToImageMetric interface.
+  void
+  SetFixedImageMask(typename Superclass::FixedImageMaskType *) final
+  {
+    itkExceptionMacro("Intentionally left unimplemented!");
+  }
+
+  void
+  SetFixedImageMask(const typename Superclass::FixedImageMaskType *) final
+  {
+    itkExceptionMacro("Intentionally left unimplemented!");
+  }
+
+  void
+  SetMovingImageMask(typename Superclass::MovingImageMaskType *) final
+  {
+    itkExceptionMacro("Intentionally left unimplemented!");
+  }
+
+  void
+  SetMovingImageMask(const typename Superclass::MovingImageMaskType *) final
+  {
+    itkExceptionMacro("Intentionally left unimplemented!");
+  }
+
+  // Protected using-declaration, to avoid `-Woverloaded-virtual` warnings from GCC (GCC 11.4) or clang (macos-12).
+  using Superclass::SetTransform;
+
 private:
   template <typename... TOptionalThreadId>
   bool
@@ -587,7 +605,15 @@ private:
                                                             MovingImageDerivativeType *  gradient,
                                                             const TOptionalThreadId... optionalThreadId) const;
 
-  /** Private member variables. */
+  /** Private member variables for limiters and for image derivative computation. */
+  FixedImageLimiterPointer          m_FixedImageLimiter{ nullptr };
+  MovingImageLimiterPointer         m_MovingImageLimiter{ nullptr };
+  LinearInterpolatorPointer         m_LinearInterpolator{ nullptr };
+  BSplineInterpolatorPointer        m_BSplineInterpolator{ nullptr };
+  BSplineInterpolatorFloatPointer   m_BSplineInterpolatorFloat{ nullptr };
+  ReducedBSplineInterpolatorPointer m_ReducedBSplineInterpolator{ nullptr };
+
+  /** Other private member variables. */
   bool   m_UseImageSampler{ false };
   bool   m_UseFixedImageLimiter{ false };
   bool   m_UseMovingImageLimiter{ false };
@@ -596,6 +622,16 @@ private:
   bool   m_ScaleGradientWithRespectToMovingImageOrientation{ false };
 
   MovingImageDerivativeScalesType m_MovingImageDerivativeScales{ MovingImageDerivativeScalesType::Filled(1.0) };
+
+  // Private using-declarations, to avoid `-Woverloaded-virtual` warnings from GCC (GCC 11.4) or clang (macos-12).
+  using Superclass::TransformPoint;
+
+  struct DummyMask
+  {};
+
+  // Prevent accidentally accessing m_FixedImageMask or m_MovingImageMask directly from the ITK's ImageToImageMetric.
+  static constexpr DummyMask m_FixedImageMask{};
+  static constexpr DummyMask m_MovingImageMask{};
 };
 
 } // end namespace itk
