@@ -72,8 +72,6 @@ public:
   using typename Superclass::GradientPixelType;
   using typename Superclass::GradientImageType;
   using typename Superclass::GradientImagePointer;
-  using typename Superclass::GradientImageFilterType;
-  using typename Superclass::GradientImageFilterPointer;
   using typename Superclass::FixedImageMaskType;
   using typename Superclass::FixedImageMaskPointer;
   using typename Superclass::MovingImageMaskType;
@@ -224,7 +222,7 @@ public:
   Initialize();
 
 protected:
-  ImageToImageMetricWithFeatures();
+  ImageToImageMetricWithFeatures() = default;
   virtual ~ImageToImageMetricWithFeatures() {}
   void
   PrintSelf(std::ostream & os, Indent indent) const;
@@ -238,15 +236,15 @@ protected:
   using typename Superclass::MovingImageContinuousIndexType;
 
   /** Member variables. */
-  unsigned int                        m_NumberOfFixedFeatureImages;
-  unsigned int                        m_NumberOfMovingFeatureImages;
-  FixedFeatureImageVectorType         m_FixedFeatureImages;
-  MovingFeatureImageVectorType        m_MovingFeatureImages;
-  FixedFeatureInterpolatorVectorType  m_FixedFeatureInterpolators;
-  MovingFeatureInterpolatorVectorType m_MovingFeatureInterpolators;
+  unsigned int                        m_NumberOfFixedFeatureImages{ 0 };
+  unsigned int                        m_NumberOfMovingFeatureImages{ 0 };
+  FixedFeatureImageVectorType         m_FixedFeatureImages{};
+  MovingFeatureImageVectorType        m_MovingFeatureImages{};
+  FixedFeatureInterpolatorVectorType  m_FixedFeatureInterpolators{};
+  MovingFeatureInterpolatorVectorType m_MovingFeatureInterpolators{};
 
-  std::vector<bool>                    m_FeatureInterpolatorsIsBSpline;
-  BSplineFeatureInterpolatorVectorType m_MovingFeatureBSplineInterpolators;
+  std::vector<bool>                    m_FeatureInterpolatorsIsBSpline{};
+  BSplineFeatureInterpolatorVectorType m_MovingFeatureBSplineInterpolators{};
 
   /** Initialize variables for image derivative computation; this
    * method is called by Initialize.
