@@ -107,8 +107,6 @@ public:
   using typename Superclass::GradientPixelType;
   using typename Superclass::GradientImageType;
   using typename Superclass::GradientImagePointer;
-  using typename Superclass::GradientImageFilterType;
-  using typename Superclass::GradientImageFilterPointer;
   using typename Superclass::FixedImageMaskType;
   using typename Superclass::FixedImageMaskPointer;
   using typename Superclass::MovingImageMaskType;
@@ -128,7 +126,6 @@ public:
   using typename Superclass::FixedImageLimiterOutputType;
   using typename Superclass::MovingImageLimiterOutputType;
   using typename Superclass::MovingImageDerivativeScalesType;
-  using typename Superclass::ThreaderType;
   using typename Superclass::ThreadInfoType;
 
   /** The fixed image dimension. */
@@ -238,7 +235,6 @@ protected:
   using typename Superclass::MovingImageContinuousIndexType;
   using typename Superclass::BSplineInterpolatorType;
   using typename Superclass::MovingImageDerivativeType;
-  using typename Superclass::CentralDifferenceGradientFilterType;
   using typename Superclass::NonZeroJacobianIndicesType;
 
   /** Typedefs for the PDFs and PDF derivatives. */
@@ -269,33 +265,33 @@ protected:
   /** Protected variables **************************** */
 
   /** Variables for Alpha (the normalization factor of the histogram). */
-  mutable double         m_Alpha;
-  mutable DerivativeType m_PerturbedAlphaRight;
-  mutable DerivativeType m_PerturbedAlphaLeft;
+  mutable double         m_Alpha{ 0.0 };
+  mutable DerivativeType m_PerturbedAlphaRight{};
+  mutable DerivativeType m_PerturbedAlphaLeft{};
 
   /** Variables for the pdfs (actually: histograms). */
-  mutable MarginalPDFType       m_FixedImageMarginalPDF;
-  mutable MarginalPDFType       m_MovingImageMarginalPDF;
-  JointPDFPointer               m_JointPDF;
-  JointPDFDerivativesPointer    m_JointPDFDerivatives;
-  JointPDFDerivativesPointer    m_IncrementalJointPDFRight;
-  JointPDFDerivativesPointer    m_IncrementalJointPDFLeft;
-  IncrementalMarginalPDFPointer m_FixedIncrementalMarginalPDFRight;
-  IncrementalMarginalPDFPointer m_MovingIncrementalMarginalPDFRight;
-  IncrementalMarginalPDFPointer m_FixedIncrementalMarginalPDFLeft;
-  IncrementalMarginalPDFPointer m_MovingIncrementalMarginalPDFLeft;
-  mutable JointPDFRegionType    m_JointPDFWindow; // no need for mutable anymore?
-  double                        m_MovingImageNormalizedMin;
-  double                        m_FixedImageNormalizedMin;
-  double                        m_FixedImageBinSize;
-  double                        m_MovingImageBinSize;
-  double                        m_FixedParzenTermToIndexOffset;
-  double                        m_MovingParzenTermToIndexOffset;
+  mutable MarginalPDFType       m_FixedImageMarginalPDF{};
+  mutable MarginalPDFType       m_MovingImageMarginalPDF{};
+  JointPDFPointer               m_JointPDF{ nullptr };
+  JointPDFDerivativesPointer    m_JointPDFDerivatives{ nullptr };
+  JointPDFDerivativesPointer    m_IncrementalJointPDFRight{};
+  JointPDFDerivativesPointer    m_IncrementalJointPDFLeft{};
+  IncrementalMarginalPDFPointer m_FixedIncrementalMarginalPDFRight{ nullptr };
+  IncrementalMarginalPDFPointer m_MovingIncrementalMarginalPDFRight{ nullptr };
+  IncrementalMarginalPDFPointer m_FixedIncrementalMarginalPDFLeft{ nullptr };
+  IncrementalMarginalPDFPointer m_MovingIncrementalMarginalPDFLeft{ nullptr };
+  mutable JointPDFRegionType    m_JointPDFWindow{}; // no need for mutable anymore?
+  double                        m_MovingImageNormalizedMin{ 0.0 };
+  double                        m_FixedImageNormalizedMin{ 0.0 };
+  double                        m_FixedImageBinSize{ 0.0 };
+  double                        m_MovingImageBinSize{ 0.0 };
+  double                        m_FixedParzenTermToIndexOffset{ 0.5 };
+  double                        m_MovingParzenTermToIndexOffset{ -1.0 };
 
   /** Kernels for computing Parzen histograms and derivatives. */
-  KernelFunctionPointer m_FixedKernel;
-  KernelFunctionPointer m_MovingKernel;
-  KernelFunctionPointer m_DerivativeMovingKernel;
+  KernelFunctionPointer m_FixedKernel{ nullptr };
+  KernelFunctionPointer m_MovingKernel{ nullptr };
+  KernelFunctionPointer m_DerivativeMovingKernel{ nullptr };
 
   /** Initialize threading related parameters. */
   void
@@ -320,21 +316,20 @@ protected:
   /** Compute the Parzen values given an image value and a starting histogram index
    * Compute the values at (parzenWindowIndex - parzenWindowTerm + k) for
    * k = 0 ... kernelsize-1
-   * Returns the values in a ParzenValueContainer, which is supposed to have
-   * the right size already.
+   * Places the values in a buffer, which is supposed to have the right size already.
    */
-  void
+  static void
   EvaluateParzenValues(double                     parzenWindowTerm,
                        OffsetValueType            parzenWindowIndex,
-                       const KernelFunctionType * kernel,
-                       ParzenValueContainerType & parzenValues) const;
+                       const KernelFunctionType & kernel,
+                       PDFValueType *             parzenValues);
 
   /** Update the joint PDF with a pixel pair; on demand also updates the
    * pdf derivatives (if the Jacobian pointers are nonzero).
    */
   virtual void
-  UpdateJointPDFAndDerivatives(const RealType &                   fixedImageValue,
-                               const RealType &                   movingImageValue,
+  UpdateJointPDFAndDerivatives(const RealType                     fixedImageValue,
+                               const RealType                     movingImageValue,
                                const DerivativeType *             imageJacobian,
                                const NonZeroJacobianIndicesType * nzji,
                                JointPDFType *                     jointPDF) const;
@@ -474,7 +469,7 @@ protected:
 
 private:
   /** Threading related parameters. */
-  mutable std::vector<JointPDFPointer> m_ThreaderJointPDFs;
+  mutable std::vector<JointPDFPointer> m_ThreaderJointPDFs{};
 
   /** Helper structs that multi-threads the computation of
    * the metric derivative using ITK threads.
@@ -483,7 +478,7 @@ private:
   {
     Self * m_Metric;
   };
-  ParzenWindowHistogramMultiThreaderParameterType m_ParzenWindowHistogramThreaderParameters;
+  ParzenWindowHistogramMultiThreaderParameterType m_ParzenWindowHistogramThreaderParameters{};
 
   struct ParzenWindowHistogramGetValueAndDerivativePerThreadStruct
   {
@@ -500,14 +495,14 @@ private:
     m_ParzenWindowHistogramGetValueAndDerivativePerThreadVariables;
 
   /** Variables that can/should be accessed by their Set/Get functions. */
-  unsigned long m_NumberOfFixedHistogramBins;
-  unsigned long m_NumberOfMovingHistogramBins;
-  unsigned int  m_FixedKernelBSplineOrder;
-  unsigned int  m_MovingKernelBSplineOrder;
-  bool          m_UseDerivative;
-  bool          m_UseExplicitPDFDerivatives;
-  bool          m_UseFiniteDifferenceDerivative;
-  double        m_FiniteDifferencePerturbation;
+  unsigned long m_NumberOfFixedHistogramBins{ 32 };
+  unsigned long m_NumberOfMovingHistogramBins{ 32 };
+  unsigned int  m_FixedKernelBSplineOrder{ 0 };
+  unsigned int  m_MovingKernelBSplineOrder{ 3 };
+  bool          m_UseDerivative{ false };
+  bool          m_UseExplicitPDFDerivatives{ true };
+  bool          m_UseFiniteDifferenceDerivative{ false };
+  double        m_FiniteDifferencePerturbation{ 1.0 };
 };
 
 } // end namespace itk
