@@ -26,14 +26,7 @@ namespace itk
  * **************** Constructor *****************************
  */
 
-ScaledSingleValuedCostFunction::ScaledSingleValuedCostFunction()
-{
-  this->m_UnscaledCostFunction = nullptr;
-  this->m_UseScales = false;
-  this->m_NegateCostFunction = false;
-
-} // end Constructor
-
+ScaledSingleValuedCostFunction::ScaledSingleValuedCostFunction() = default;
 
 /**
  * ******************** GetValue *****************************
@@ -48,10 +41,10 @@ ScaledSingleValuedCostFunction::GetValue(const ParametersType & parameters) cons
   const unsigned int numberOfParameters = this->GetNumberOfParameters();
   if (parameters.GetSize() != numberOfParameters)
   {
-    itkExceptionMacro(<< "Number of parameters is not like the unscaled cost function expects.");
+    itkExceptionMacro("Number of parameters is not like the unscaled cost function expects.");
   }
 
-  MeasureType returnvalue = NumericTraits<MeasureType>::Zero;
+  MeasureType returnvalue{};
 
   if (this->m_UseScales)
   {
@@ -86,7 +79,7 @@ ScaledSingleValuedCostFunction::GetDerivative(const ParametersType & parameters,
   const unsigned int numberOfParameters = this->GetNumberOfParameters();
   if (parameters.GetSize() != numberOfParameters)
   {
-    itkExceptionMacro(<< "Number of parameters is not like the unscaled cost function expects.");
+    itkExceptionMacro("Number of parameters is not like the unscaled cost function expects.");
   }
 
   if (this->m_UseScales)
@@ -130,7 +123,7 @@ ScaledSingleValuedCostFunction::GetValueAndDerivative(const ParametersType & par
   const unsigned int numberOfParameters = this->GetNumberOfParameters();
   if (parameters.GetSize() != numberOfParameters)
   {
-    itkExceptionMacro(<< "Number of parameters is not like the unscaled cost function expects.");
+    itkExceptionMacro("Number of parameters is not like the unscaled cost function expects.");
   }
 
   if (this->m_UseScales)
@@ -169,7 +162,7 @@ ScaledSingleValuedCostFunction::GetNumberOfParameters() const
 {
   if (this->m_UnscaledCostFunction.IsNull())
   {
-    itkExceptionMacro(<< "UnscaledCostFunction has not been set!");
+    itkExceptionMacro("UnscaledCostFunction has not been set!");
   }
   return this->m_UnscaledCostFunction->GetNumberOfParameters();
 
@@ -227,7 +220,7 @@ ScaledSingleValuedCostFunction::ConvertScaledToUnscaledParameters(ParametersType
     const ScalesType & scales = this->GetScales();
     if (scales.GetSize() != numberOfParameters)
     {
-      itkExceptionMacro(<< "Number of scales is not correct.");
+      itkExceptionMacro("Number of scales is not correct.");
     }
 
     for (unsigned int i = 0; i < numberOfParameters; ++i)
@@ -253,7 +246,7 @@ ScaledSingleValuedCostFunction::ConvertUnscaledToScaledParameters(ParametersType
     const ScalesType & scales = this->GetScales();
     if (scales.GetSize() != numberOfParameters)
     {
-      itkExceptionMacro(<< "Number of scales is not correct.");
+      itkExceptionMacro("Number of scales is not correct.");
     }
 
     for (unsigned int i = 0; i < numberOfParameters; ++i)
