@@ -18,6 +18,7 @@
 
 // First include the header file to be tested:
 #include "elxConversion.h"
+#include "elxDefaultConstruct.h"
 
 #include "itkParameterFileParser.h"
 #include "itkParameterMapInterface.h"
@@ -57,7 +58,7 @@ const ParameterMapType parameterMap = { { "Direction", { "0", "0", "0", "0" } },
                                         { "FixedInternalImagePixelType", { "float" } },
                                         { "HowToCombineTransforms", { "Compose" } },
                                         { "Index", { "0", "0" } },
-                                        { "InitialTransformParametersFileName", { "NoInitialTransform" } },
+                                        { "InitialTransformParameterFileName", { "NoInitialTransform" } },
                                         { "MovingImageDimension", { "2" } },
                                         { "MovingInternalImagePixelType", { "float" } },
                                         { "NumberOfParameters", { "2" } },
@@ -73,7 +74,7 @@ const std::string parameterMapTextString = R"((Direction 0 0 0 0)
 (FixedInternalImagePixelType "float")
 (HowToCombineTransforms "Compose")
 (Index 0 0)
-(InitialTransformParametersFileName "NoInitialTransform")
+(InitialTransformParameterFileName "NoInitialTransform")
 (MovingImageDimension 2)
 (MovingInternalImagePixelType "float")
 (NumberOfParameters 2)
@@ -240,12 +241,34 @@ Expect_parameter_with_decimal_point_and_non_zero_trailing_chars_can_not_be_read_
   }
 }
 
+
+template <typename TSignedInteger>
+void
+Expect_negative_parameter_value_can_not_be_read_as_unsigned()
+{
+  static_assert(std::is_signed_v<TSignedInteger>, "Must be a signed integer type!");
+
+  for (TSignedInteger integer : { std::numeric_limits<TSignedInteger>::min(), TSignedInteger{ -1 } })
+  {
+    const std::string parameterName("Key");
+    const std::string parameterStringValue = std::to_string(integer);
+
+    elx::DefaultConstruct<itk::ParameterMapInterface> parameterMapInterface;
+    parameterMapInterface.SetParameterMap({ { parameterName, { parameterStringValue } } });
+
+    std::make_unsigned_t<TSignedInteger> actualParameterValue{};
+    std::string                          errorMessage;
+    EXPECT_THROW(parameterMapInterface.ReadParameter(actualParameterValue, parameterName, 0, errorMessage),
+                 itk::ExceptionObject);
+  }
+}
+
+
 template <typename TFloatingPoint>
 void
 Expect_lossless_round_trip_of_floating_point_parameter_values()
 {
-  static_assert(std::is_floating_point<TFloatingPoint>::value,
-                "This function is only meant to test floating point types!");
+  static_assert(std::is_floating_point_v<TFloatingPoint>, "This function is only meant to test floating point types!");
 
   using NumericLimits = std::numeric_limits<TFloatingPoint>;
 
@@ -349,7 +372,7 @@ GTEST_TEST(Conversion, ToString)
   // Note that this is different from std::to_string(0.5), which returns "0.500000"
   EXPECT_EQ(Conversion::ToString(0.5), "0.5");
 
-  constexpr auto expectedPrecision = 16;
+  static constexpr auto expectedPrecision = 16;
   static_assert(expectedPrecision == std::numeric_limits<double>::digits10 + 1,
                 "The expected precision for double floating point numbers");
   const auto expectedString = "0." + std::string(expectedPrecision, '3');
@@ -421,6 +444,23 @@ GTEST_TEST(Conversion, ToString)
 }
 
 
+// Tests that conversion of itk::Object pointers to string and back is lossless.
+GTEST_TEST(Conversion, LosslessRoundTripOfObjectPointers)
+{
+  const auto expectLosslessRoundTrip = [](itk::Object * const ptr) {
+    itk::Object * actualPtr{};
+    EXPECT_TRUE(Conversion::StringToValue(Conversion::ObjectPtrToString(ptr), actualPtr));
+    EXPECT_EQ(actualPtr, ptr);
+  };
+
+  expectLosslessRoundTrip(nullptr);
+  expectLosslessRoundTrip(itk::Object::New());
+
+  elx::DefaultConstruct<itk::Object> localVariable{};
+  expectLosslessRoundTrip(&localVariable);
+}
+
+
 GTEST_TEST(Conversion, ToVectorOfStrings)
 {
   using VectorOfStrings = std::vector<std::string>;
@@ -557,15 +597,15 @@ GTEST_TEST(Conversion, ToNativePathNameSeparators)
   EXPECT_EQ(Conversion::ToNativePathNameSeparators(std::string{}), std::string{});
   EXPECT_EQ(Conversion::ToNativePathNameSeparators(" "), std::string{ " " });
 
-  constexpr bool isBackslashNativeSeparator =
+  static constexpr bool isBackslashNativeSeparator =
 #ifdef _WIN32
     true;
 #else
     false;
 #endif
 
-  constexpr char nativeSeparator = isBackslashNativeSeparator ? '\\' : '/';
-  constexpr char nonNativeSeparator = isBackslashNativeSeparator ? '/' : '\\';
+  static constexpr char nativeSeparator = isBackslashNativeSeparator ? '\\' : '/';
+  static constexpr char nonNativeSeparator = isBackslashNativeSeparator ? '/' : '\\';
 
   EXPECT_EQ(Conversion::ToNativePathNameSeparators({ nativeSeparator }), std::string{ nativeSeparator });
   EXPECT_EQ(Conversion::ToNativePathNameSeparators({ nonNativeSeparator }), std::string{ nativeSeparator });
@@ -591,3 +631,11 @@ GTEST_TEST(ParameterMapInterface, ParameterWithDecimalPointAndNonZeroTrailingCha
 {
   Expect_parameter_with_decimal_point_and_non_zero_trailing_chars_can_not_be_read_as_integer<int>();
 }
+
+
+GTEST_TEST(ParameterMapInterface, NegativeParameterValueCannotNotBeReadAsUnsigned)
+{
+  Expect_negative_parameter_value_can_not_be_read_as_unsigned<int>();
+  Expect_negative_parameter_value_can_not_be_read_as_unsigned<std::int8_t>();
+  Expect_negative_parameter_value_can_not_be_read_as_unsigned<std::intmax_t>();
+}
