@@ -16,14 +16,11 @@
  *
  *=========================================================================*/
 
-#define _USE_MATH_DEFINES // For M_PI_4.
-
 // First include the header file to be tested:
 #include "elxTransformIO.h"
 
 #include "elxConversion.h"
 #include "elxDefaultConstruct.h"
-#include "elxElastixMain.h" // For xoutManager.
 #include "elxElastixTemplate.h"
 #include "elxGTestUtilities.h"
 #include "../Core/Main/GTesting/elxCoreMainGTestUtilities.h"
@@ -105,9 +102,9 @@ struct WithDimension
       using ItkCompositeTransformType = itk::CompositeTransform<double, NDimension>;
 
       static_assert(
-        std::is_base_of<itk::Transform<double, NDimension, NDimension>, TExpectedCorrespondingItkTransform>::value,
+        std::is_base_of_v<itk::Transform<double, NDimension, NDimension>, TExpectedCorrespondingItkTransform>,
         "TExpectedCorrespondingItkTransform should be derived from the expected `itk::Transform` specialization!");
-      static_assert(!std::is_base_of<ItkCompositeTransformType, TExpectedCorrespondingItkTransform>::value,
+      static_assert(!std::is_base_of_v<ItkCompositeTransformType, TExpectedCorrespondingItkTransform>,
                     "TExpectedCorrespondingItkTransform should not be derived from `itk::CompositeTransform`!");
 
       const auto elxTransform = CheckNew<ElastixTransformType>();
@@ -118,9 +115,8 @@ struct WithDimension
 
       const auto compositeTransform = elx::TransformIO::ConvertToItkCompositeTransform(*elxTransform);
       ASSERT_NE(compositeTransform, nullptr);
-      static_assert(
-        std::is_same<const itk::SmartPointer<ItkCompositeTransformType>, decltype(compositeTransform)>::value,
-        "`ConvertToItkCompositeTransform` should have the expected `SmartPointer` return type!");
+      static_assert(std::is_same_v<const itk::SmartPointer<ItkCompositeTransformType>, decltype(compositeTransform)>,
+                    "`ConvertToItkCompositeTransform` should have the expected `SmartPointer` return type!");
 
       const auto & transformQueue = compositeTransform->GetTransformQueue();
       ASSERT_EQ(transformQueue.size(), 1);
@@ -146,8 +142,11 @@ struct WithDimension
     Expect_default_elastix_FixedParameters_are_all_zero()
     {
       const auto fixedParameters = CheckNew<ElastixTransformType>()->GetFixedParameters();
-      ASSERT_EQ(fixedParameters.size(), NDimension);
-      ASSERT_EQ(fixedParameters, vnl_vector<double>(NDimension, 0.0));
+
+      for (const auto fixedParameter : fixedParameters)
+      {
+        EXPECT_EQ(fixedParameter, 0.0);
+      }
     }
 
 
@@ -236,15 +235,13 @@ struct WithDimension
 
 
     static void
-    Test_CreateTransformParametersMap_for_default_transform(const ParameterMapType & expectedDerivedParameterMap)
+    Test_CreateTransformParameterMap_for_default_transform(const ParameterMapType & expectedDerivedParameterMap)
     {
       SCOPED_TRACE(std::string("Function = ")
                      .append(__func__)
                      .append("\n  ElastixTransformType = ")
                      .append(typeid(ElastixTransformType).name()));
 
-      const elx::xoutManager manager("", false, false);
-
       const auto elxTransform = CheckNew<ElastixTransformType>();
       const auto elastixObject = CreateDefaultElastixObject<ElastixType<NDimension>>();
 
@@ -262,7 +259,7 @@ struct WithDimension
       elxTransform->SetReadWriteTransformParameters(true);
 
       ParameterMapType actualParameterMap;
-      elxTransform->CreateTransformParametersMap(itk::OptimizerParameters<double>{}, actualParameterMap);
+      elxTransform->CreateTransformParameterMap(itk::OptimizerParameters<double>{}, actualParameterMap);
 
       const std::string expectedImageDimension{ char{ '0' + NDimension } };
       const std::string expectedInternalImagePixelType = "float";
@@ -275,7 +272,7 @@ struct WithDimension
         { "FixedInternalImagePixelType", { expectedInternalImagePixelType } },
         { "HowToCombineTransforms", { "Compose" } },
         { "Index", { ParameterValuesType(NDimension, expectedZero) } },
-        { "InitialTransformParametersFileName", { "NoInitialTransform" } },
+        { "InitialTransformParameterFileName", { "NoInitialTransform" } },
         { "MovingImageDimension", { expectedImageDimension } },
         { "MovingInternalImagePixelType", { expectedInternalImagePixelType } },
         { "NumberOfParameters", { expectedZero } },
@@ -292,13 +289,11 @@ struct WithDimension
     }
 
     static void
-    Test_CreateTransformParametersMap_double_precision()
+    Test_CreateTransformParameterMap_double_precision()
     {
-      const elx::xoutManager manager("", false, false);
-
       // Use 0.3333333333333333... as test value.
-      constexpr auto testValue = 1.0 / 3.0;
-      constexpr auto expectedPrecision = 16;
+      static constexpr auto testValue = 1.0 / 3.0;
+      static constexpr auto expectedPrecision = 16;
       static_assert(expectedPrecision == std::numeric_limits<double>::digits10 + 1,
                     "The expected precision for double floating point numbers");
       const auto expectedString = "0." + std::string(expectedPrecision, '3');
@@ -321,7 +316,7 @@ struct WithDimension
 
       ParameterMapType parameterMap;
 
-      elxTransform->CreateTransformParametersMap(itk::OptimizerParameters<double>(2U, testValue), parameterMap);
+      elxTransform->CreateTransformParameterMap(itk::OptimizerParameters<double>(2U, testValue), parameterMap);
 
       for (const auto key : { "TransformParameters", "Origin", "Spacing" })
       {
@@ -335,10 +330,8 @@ struct WithDimension
     }
 
     static void
-    Test_CreateTransformParametersMap_SetUseAddition()
+    Test_CreateTransformParameterMap_SetUseAddition()
     {
-      const elx::xoutManager manager("", false, false);
-
       const auto elxTransform = CheckNew<ElastixTransformType>();
 
       const auto elastixObject = CreateDefaultElastixObject<ElastixType<NDimension>>();
@@ -350,7 +343,7 @@ struct WithDimension
 
       const auto expectHowToCombineTransforms = [&elxTransform](const char * const expectedParameterValue) {
         ParameterMapType parameterMap;
-        elxTransform->CreateTransformParametersMap({}, parameterMap);
+        elxTransform->CreateTransformParameterMap({}, parameterMap);
 
         const auto found = parameterMap.find("HowToCombineTransforms");
         ASSERT_NE(found, end(parameterMap));
@@ -390,7 +383,7 @@ struct WithDimension
   }
 
   static void
-  Test_CreateTransformParametersMap_for_default_transform()
+  Test_CreateTransformParameterMap_for_default_transform()
   {
     // Converts the specified string to an std::vector<std::string>. Each vector element contains a character of the
     // specified string.
@@ -426,9 +419,9 @@ struct WithDimension
 
     using namespace elx;
 
-    WithElastixTransform<AdvancedAffineTransformElastix>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<AdvancedAffineTransformElastix>::Test_CreateTransformParameterMap_for_default_transform(
       { { "CenterOfRotationPoint", expectedZeros } });
-    WithElastixTransform<AdvancedBSplineTransform>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<AdvancedBSplineTransform>::Test_CreateTransformParameterMap_for_default_transform(
       { { "BSplineTransformSplineOrder", { "3" } },
         { "GridDirection", expectedGridDirection },
         { "GridIndex", expectedZeros },
@@ -436,45 +429,51 @@ struct WithDimension
         { "GridSize", expectedZeros },
         { "GridSpacing", expectedOnes },
         { "UseCyclicTransform", { "false" } } });
-    WithElastixTransform<AffineDTITransformElastix>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<AffineDTITransformElastix>::Test_CreateTransformParameterMap_for_default_transform(
       { { "CenterOfRotationPoint", expectedZeros }, { "MatrixTranslation", expectedMatrixTranslation } });
-    WithElastixTransform<AffineLogStackTransform>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<AffineLogStackTransform>::Test_CreateTransformParameterMap_for_default_transform(
       { { "CenterOfRotationPoint", ParameterValuesType(NDimension - 1, expectedZero) },
         { "NumberOfSubTransforms", { expectedZero } },
         { "StackOrigin", { expectedZero } },
         { "StackSpacing", { expectedOne } } });
-    WithElastixTransform<AffineLogTransformElastix>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<AffineLogTransformElastix>::Test_CreateTransformParameterMap_for_default_transform(
       { { "CenterOfRotationPoint", expectedZeros }, { "MatrixTranslation", expectedMatrixTranslation } });
 
     const auto skippedTest = [] {
       // Appears to crash when internally calling GetSubTransform(0) while m_SubTransformContainer is still empty.
-      WithElastixTransform<BSplineStackTransform>::Test_CreateTransformParametersMap_for_default_transform({});
+      WithElastixTransform<BSplineStackTransform>::Test_CreateTransformParameterMap_for_default_transform({});
     };
     (void)skippedTest;
 
-    WithElastixTransform<BSplineTransformWithDiffusion>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<BSplineTransformWithDiffusion>::Test_CreateTransformParameterMap_for_default_transform(
       { { "DeformationFieldFileName", { expectedDeformationFieldFileName } },
         { "GridIndex", expectedZeros },
         { "GridOrigin", expectedZeros },
         { "GridSize", expectedZeros },
         { "GridSpacing", expectedOnes } });
-    WithElastixTransform<DeformationFieldTransform>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<DeformationFieldTransform>::Test_CreateTransformParameterMap_for_default_transform(
       { { "DeformationFieldFileName", { expectedDeformationFieldFileName } },
         { "DeformationFieldInterpolationOrder", { expectedZero } } });
-    WithElastixTransform<EulerStackTransform>::Test_CreateTransformParametersMap_for_default_transform(
-      { { "CenterOfRotationPoint", ParameterValuesType(NDimension - 1, expectedZero) },
-        { "NumberOfSubTransforms", { expectedZero } },
-        { "StackOrigin", { expectedZero } },
-        { "StackSpacing", { expectedOne } } });
+    WithElastixTransform<EulerStackTransform>::Test_CreateTransformParameterMap_for_default_transform(
+      (NDimension == 4)
+        ? ParameterMapType{ { "CenterOfRotationPoint", ParameterValuesType(NDimension - 1, expectedZero) },
+                            { "ComputeZYX", { expectedFalse } },
+                            { "NumberOfSubTransforms", { expectedZero } },
+                            { "StackOrigin", { expectedZero } },
+                            { "StackSpacing", { expectedOne } } }
+        : ParameterMapType{ { "CenterOfRotationPoint", ParameterValuesType(NDimension - 1, expectedZero) },
+                            { "NumberOfSubTransforms", { expectedZero } },
+                            { "StackOrigin", { expectedZero } },
+                            { "StackSpacing", { expectedOne } } });
 
-    WithElastixTransform<EulerTransformElastix>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<EulerTransformElastix>::Test_CreateTransformParameterMap_for_default_transform(
       (NDimension == 3)
         ? ParameterMapType{ { "CenterOfRotationPoint", expectedZeros }, { "ComputeZYX", { expectedFalse } } }
         : ParameterMapType{ { "CenterOfRotationPoint", expectedZeros } });
 
     try
     {
-      WithElastixTransform<MultiBSplineTransformWithNormal>::Test_CreateTransformParametersMap_for_default_transform(
+      WithElastixTransform<MultiBSplineTransformWithNormal>::Test_CreateTransformParameterMap_for_default_transform(
         { { "GridIndex", expectedZeros },
           { "GridOrigin", expectedZeros },
           { "GridSize", expectedZeros },
@@ -482,7 +481,7 @@ struct WithDimension
           { "BSplineTransformSplineOrder", { "3" } },
           { "GridDirection", expectedGridDirection },
           { "MultiBSplineTransformWithNormalLabels", { itksys::SystemTools::GetCurrentWorkingDirectory() } } });
-      EXPECT_FALSE("MultiBSplineTransformWithNormal::CreateTransformParametersMap is expected to throw an exception!");
+      EXPECT_FALSE("MultiBSplineTransformWithNormal::CreateTransformParameterMap is expected to throw an exception!");
     }
     catch (const itk::ExceptionObject & exceptionObject)
     {
@@ -490,7 +489,7 @@ struct WithDimension
       EXPECT_NE(std::strstr(exceptionObject.GetDescription(), "ERROR: Missing -labels argument!"), nullptr);
     }
 
-    WithElastixTransform<RecursiveBSplineTransform>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<RecursiveBSplineTransform>::Test_CreateTransformParameterMap_for_default_transform(
       { { "BSplineTransformSplineOrder", { "3" } },
         { "GridDirection", expectedGridDirection },
         { "GridIndex", expectedZeros },
@@ -498,19 +497,19 @@ struct WithDimension
         { "GridSize", expectedZeros },
         { "GridSpacing", expectedOnes },
         { "UseCyclicTransform", { expectedFalse } } });
-    WithElastixTransform<SimilarityTransformElastix>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<SimilarityTransformElastix>::Test_CreateTransformParameterMap_for_default_transform(
       { { "CenterOfRotationPoint", expectedZeros } });
-    WithElastixTransform<SplineKernelTransform>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<SplineKernelTransform>::Test_CreateTransformParameterMap_for_default_transform(
       { { "FixedImageLandmarks", {} },
         { "SplineKernelType", { "unknown" } },
         { "SplinePoissonRatio", { "0.3" } },
         { "SplineRelaxationFactor", { expectedZero } } });
-    WithElastixTransform<TranslationStackTransform>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<TranslationStackTransform>::Test_CreateTransformParameterMap_for_default_transform(
       { { "NumberOfSubTransforms", { expectedZero } },
         { "StackOrigin", { expectedZero } },
         { "StackSpacing", { expectedOne } } });
-    WithElastixTransform<TranslationTransformElastix>::Test_CreateTransformParametersMap_for_default_transform({});
-    WithElastixTransform<WeightedCombinationTransformElastix>::Test_CreateTransformParametersMap_for_default_transform(
+    WithElastixTransform<TranslationTransformElastix>::Test_CreateTransformParameterMap_for_default_transform({});
+    WithElastixTransform<WeightedCombinationTransformElastix>::Test_CreateTransformParameterMap_for_default_transform(
       { { "NormalizeCombinationWeights", { expectedFalse } }, { "SubTransforms", {} } });
   }
 };
@@ -586,34 +585,34 @@ Expect_elx_TransformPoint_yields_same_point_as_ITK(const TITKTransform & itkTran
 
   using NumericLimits = std::numeric_limits<double>;
 
-  constexpr double testInputValues[] = { NumericLimits::lowest(),
-                                         -2.0,
-                                         -1.0,
-                                         -0.5,
-                                         -NumericLimits::min(),
-                                         -0.0,
-                                         0.0,
-                                         NumericLimits::min(),
-                                         0.5,
-                                         1.0 - (2 * NumericLimits::epsilon()), // Note: 1.0 fails on BSpline!!!
-                                         1.0 + 1.0e-14,
-                                         2.0,
-                                         NumericLimits::max() };
+  static constexpr double testInputValues[] = { NumericLimits::lowest(),
+                                                -2.0,
+                                                -1.0,
+                                                -0.5,
+                                                -NumericLimits::min(),
+                                                -0.0,
+                                                0.0,
+                                                NumericLimits::min(),
+                                                0.5,
+                                                1.0 - (2 * NumericLimits::epsilon()), // Note: 1.0 fails on BSpline!!!
+                                                1.0 + 1.0e-14,
+                                                2.0,
+                                                NumericLimits::max() };
 
-  constexpr auto numberOfTestInputValues = std::extent<decltype(testInputValues)>::value;
+  static constexpr auto numberOfTestInputValues = std::extent_v<decltype(testInputValues)>;
 
   // Use the test input values as coordinates.
   for (const auto index : itk::ZeroBasedIndexRange<Dimension>(itk::Size<Dimension>::Filled(numberOfTestInputValues)))
   {
     itk::Point<double, Dimension> inputPoint;
-    std::transform(index.begin(), index.end(), inputPoint.begin(), [&testInputValues](const itk::SizeValueType value) {
+    std::transform(index.begin(), index.end(), inputPoint.begin(), [](const itk::SizeValueType value) {
       return testInputValues[value];
     });
 
     const auto expectedOutputPoint = itkTransform.TransformPoint(inputPoint);
     const auto actualOutputPoint = elxTransform->TransformPoint(inputPoint);
 
-    static_assert(std::is_same<decltype(actualOutputPoint), decltype(expectedOutputPoint)>::value,
+    static_assert(std::is_same_v<decltype(actualOutputPoint), decltype(expectedOutputPoint)>,
                   "elxTransform->TransformPoint must have the expected return type!");
 
     if (expectedOutputPoint != inputPoint)
@@ -787,32 +786,9 @@ GTEST_TEST(TransformIO, CopyDefaultParametersToCorrespondingItkTransform)
 
     WithDimension<2>::WithElastixTransform<elx::SimilarityTransformElastix>::Test_copying_default_parameters<
       itk::Euler2DTransform<double>>(fixed);
+    WithDimension<3>::WithElastixTransform<elx::EulerTransformElastix>::Test_copying_default_parameters<
+      itk::Euler3DTransform<double>>(fixed);
   }
-  WithDimension<3>::WithElastixTransform<elx::EulerTransformElastix>::Test_copying_default_parameters<
-    itk::Euler3DTransform<double>>(false);
-  // See also CopyDefaultEulerTransformElastix3DFixedParametersToCorrespondingItkTransform
-}
-
-
-GTEST_TEST(TransformIO, CopyDefaultEulerTransformElastix3DFixedParametersToCorrespondingItkTransform)
-{
-  const auto elxTransform = CheckNew<elx::EulerTransformElastix<ElastixType<3>>>();
-  const auto compositeTransform = elx::TransformIO::ConvertToItkCompositeTransform(*elxTransform);
-  ASSERT_NE(compositeTransform, nullptr);
-  const auto & transformQueue = compositeTransform->GetTransformQueue();
-  ASSERT_EQ(transformQueue.size(), 1);
-  const auto & itkTransform = transformQueue.front();
-  ASSERT_NE(itkTransform, nullptr);
-
-  const auto elxFixedParameters = elxTransform->GetFixedParameters();
-  itkTransform->SetFixedParameters(elxFixedParameters);
-  const auto itkFixedParameters = itkTransform->GetFixedParameters();
-
-  // Note: ideally itkFixedParameters and elxFixedParameters should be equal!
-  EXPECT_NE(itkFixedParameters, elxFixedParameters);
-
-  ASSERT_GE(itkFixedParameters.size(), elxFixedParameters.size());
-  ASSERT_EQ(itkFixedParameters, vnl_vector<double>(4, 0));
 }
 
 
@@ -838,20 +814,21 @@ GTEST_TEST(TransformIO, CopyParametersToCorrespondingItkTransform)
 }
 
 
-GTEST_TEST(Transform, CreateTransformParametersMapForDefaultTransform)
+GTEST_TEST(Transform, CreateTransformParameterMapForDefaultTransform)
 {
-  WithDimension<2>::Test_CreateTransformParametersMap_for_default_transform();
-  WithDimension<3>::Test_CreateTransformParametersMap_for_default_transform();
+  WithDimension<2>::Test_CreateTransformParameterMap_for_default_transform();
+  WithDimension<3>::Test_CreateTransformParameterMap_for_default_transform();
+  WithDimension<4>::Test_CreateTransformParameterMap_for_default_transform();
 }
 
 
-GTEST_TEST(Transform, CreateTransformParametersMapDoublePrecision)
+GTEST_TEST(Transform, CreateTransformParameterMapDoublePrecision)
 {
   // Checks two different transform types, just to be sure.
   WithDimension<2>::WithElastixTransform<
-    elx::AdvancedAffineTransformElastix>::Test_CreateTransformParametersMap_double_precision();
+    elx::AdvancedAffineTransformElastix>::Test_CreateTransformParameterMap_double_precision();
   WithDimension<3>::WithElastixTransform<
-    elx::TranslationTransformElastix>::Test_CreateTransformParametersMap_double_precision();
+    elx::TranslationTransformElastix>::Test_CreateTransformParameterMap_double_precision();
 }
 
 
@@ -859,15 +836,15 @@ GTEST_TEST(Transform, CreateTransformParametersSetUseAddition)
 {
   // Checks two different transform types, just to be sure.
   WithDimension<2>::WithElastixTransform<
-    elx::AdvancedAffineTransformElastix>::Test_CreateTransformParametersMap_SetUseAddition();
+    elx::AdvancedAffineTransformElastix>::Test_CreateTransformParameterMap_SetUseAddition();
   WithDimension<3>::WithElastixTransform<
-    elx::TranslationTransformElastix>::Test_CreateTransformParametersMap_SetUseAddition();
+    elx::TranslationTransformElastix>::Test_CreateTransformParameterMap_SetUseAddition();
 }
 
 
 GTEST_TEST(Transform, TransformedPointSameAsITKTranslation2D)
 {
-  constexpr auto Dimension = 2U;
+  static constexpr auto Dimension = 2U;
 
   elx::DefaultConstruct<itk::TranslationTransform<double, Dimension>> itkTransform;
   itkTransform.SetOffset(itk::MakeVector(1.0, 2.0));
@@ -878,7 +855,7 @@ GTEST_TEST(Transform, TransformedPointSameAsITKTranslation2D)
 
 GTEST_TEST(Transform, TransformedPointSameAsITKTranslation3D)
 {
-  constexpr auto Dimension = 3U;
+  static constexpr auto Dimension = 3U;
 
   elx::DefaultConstruct<itk::TranslationTransform<double, Dimension>> itkTransform;
   itkTransform.SetOffset(itk::MakeVector(1.0, 2.0, 3.0));
@@ -889,7 +866,7 @@ GTEST_TEST(Transform, TransformedPointSameAsITKTranslation3D)
 
 GTEST_TEST(Transform, TransformedPointSameAsITKAffine2D)
 {
-  constexpr auto Dimension = 2U;
+  static constexpr auto Dimension = 2U;
 
   elx::DefaultConstruct<itk::AffineTransform<double, Dimension>> itkTransform;
   itkTransform.SetTranslation(itk::MakeVector(1.0, 2.0));
@@ -903,7 +880,7 @@ GTEST_TEST(Transform, TransformedPointSameAsITKAffine2D)
 
 GTEST_TEST(Transform, TransformedPointSameAsITKAffine3D)
 {
-  constexpr auto Dimension = 3U;
+  static constexpr auto Dimension = 3U;
 
   elx::DefaultConstruct<itk::AffineTransform<double, Dimension>> itkTransform;
   itkTransform.SetTranslation(itk::MakeVector(1.0, 2.0, 3.0));
@@ -928,12 +905,16 @@ GTEST_TEST(Transform, TransformedPointSameAsITKEuler2D)
 
 GTEST_TEST(Transform, TransformedPointSameAsITKEuler3D)
 {
-  elx::DefaultConstruct<itk::Euler3DTransform<double>> itkTransform;
-  itkTransform.SetTranslation(itk::MakeVector(1.0, 2.0, 3.0));
-  itkTransform.SetCenter(itk::MakePoint(3.0, 2.0, 1.0));
-  itkTransform.SetRotation(M_PI_2, M_PI_4, M_PI_4 / 2.0);
+  for (const bool computeZYX : { false, true })
+  {
+    elx::DefaultConstruct<itk::Euler3DTransform<double>> itkTransform;
+    itkTransform.SetTranslation(itk::MakeVector(1.0, 2.0, 3.0));
+    itkTransform.SetCenter(itk::MakePoint(3.0, 2.0, 1.0));
+    itkTransform.SetRotation(M_PI_2, M_PI_4, M_PI_4 / 2.0);
+    itkTransform.SetComputeZYX(computeZYX);
 
-  Expect_elx_TransformPoint_yields_same_point_as_ITK<elx::EulerTransformElastix>(itkTransform);
+    Expect_elx_TransformPoint_yields_same_point_as_ITK<elx::EulerTransformElastix>(itkTransform);
+  }
 }
 
 
