@@ -19,6 +19,7 @@
 #define itkImageGridSampler_h
 
 #include "itkImageSamplerBase.h"
+#include "elxMaskHasSameImageDomain.h"
 
 namespace itk
 {
@@ -70,7 +71,10 @@ public:
   using typename Superclass::ImageSampleType;
   using typename Superclass::ImageSampleContainerType;
   using typename Superclass::ImageSampleContainerPointer;
-  using typename Superclass::MaskType;
+
+  // Clang/macos-12/Xcode_14.2 does not like `using typename Superclass::MaskType`, saying "error: 'MaskType' is not a
+  // class, namespace, or enumeration"
+  using MaskType = typename Superclass::MaskType;
 
   /** The input image dimension. */
   itkStaticConstMacro(InputImageDimension, unsigned int, Superclass::InputImageDimension);
@@ -116,9 +120,7 @@ public:
   void
   SetNumberOfSamples(unsigned long nrofsamples) override;
 
-  /** Selecting new samples makes no sense if nothing changed. The same
-   * samples would be selected anyway.
-   */
+  /** Selecting new samples makes no sense if nothing changed. The same samples would be selected anyway. */
   bool
   SelectNewSamplesOnUpdate() override
   {
@@ -126,7 +128,7 @@ public:
   }
 
 
-  /** Returns whether the sampler supports SelectNewSamplesOnUpdate() */
+  /** Returns whether the sampler supports SelectNewSamplesOnUpdate(). */
   bool
   SelectingNewSamplesOnUpdateSupported() const override
   {
@@ -149,6 +151,98 @@ protected:
   void
   GenerateData() override;
 
+private:
+  struct WorkUnit
+  {
+    const SampleGridIndexType GridIndex{};
+    const SampleGridSizeType  GridSize{};
+
+    // Should point to the first sample for this specific work unit.
+    ImageSampleType * const Samples{};
+
+    // The number of samples retrieved by this work unit. Only used when a mask is specified.
+    size_t NumberOfSamples{};
+  };
+
+  struct UserData
+  {
+    ITK_DISALLOW_COPY_AND_MOVE(UserData);
+
+    const InputImageType &      InputImage;
+    const MaskType * const      Mask{};
+    const SampleGridSpacingType GridSpacing{};
+    std::vector<WorkUnit>       WorkUnits{};
+  };
+
+  template <elastix::MaskCondition VMaskCondition>
+  static ITK_THREAD_RETURN_FUNCTION_CALL_CONVENTION
+  ThreaderCallback(void * arg);
+
+  /** Retrieves the sample grid size along the axis, specified by VIndex */
+  template <unsigned int VIndex>
+  static unsigned int
+  GetGridSizeValue(const SampleGridSizeType & gridSize)
+  {
+    if constexpr (VIndex < InputImageDimension)
+    {
+      return gridSize[VIndex];
+    }
+    else
+    {
+      return 1;
+    }
+  }
+
+  /** Jumps to the next grid position along the axis, specified by VIndex */
+  template <unsigned int VIndex>
+  static void
+  JumpToNextGridPosition(SampleGridIndexType &         index,
+                         const SampleGridIndexType &   gridIndex,
+                         const SampleGridSpacingType & gridSpacing)
+  {
+    static_assert(VIndex > 0);
+
+    if constexpr (VIndex < InputImageDimension)
+    {
+      index[VIndex - 1] = gridIndex[VIndex - 1];
+      index[VIndex] += gridSpacing[VIndex];
+    }
+  }
+
+
+  /** Determine the grid. */
+  static std::pair<SampleGridIndexType, SampleGridSizeType>
+  DetermineGridIndexAndSize(const InputImageRegionType &  croppedInputImageRegion,
+                            const SampleGridSpacingType & gridSpacing);
+
+  /** Generates the work units, to be processed when doing multi-threading. */
+  static std::vector<WorkUnit>
+  GenerateWorkUnits(const ThreadIdType             numberOfWorkUnits,
+                    const InputImageRegionType &   croppedInputImageRegion,
+                    const SampleGridIndexType      gridIndex,
+                    const SampleGridSpacingType    gridSpacing,
+                    std::vector<ImageSampleType> & samples);
+
+  static void
+  SingleThreadedGenerateData(const TInputImage &            inputImage,
+                             const MaskType * const         mask,
+                             const InputImageRegionType &   croppedInputImageRegion,
+                             const SampleGridSpacingType &  gridSpacing,
+                             std::vector<ImageSampleType> & samples);
+  static void
+  MultiThreadedGenerateData(MultiThreaderBase &            multiThreader,
+                            const ThreadIdType             numberOfWorkUnits,
+                            const TInputImage &            inputImage,
+                            const MaskType * const         mask,
+                            const InputImageRegionType &   croppedInputImageRegion,
+                            const SampleGridSpacingType &  gridSpacing,
+                            std::vector<ImageSampleType> & samples);
+
+  /** Generates the data for one specific work unit. */
+  template <elastix::MaskCondition VMaskCondition>
+  static void
+  GenerateDataForWorkUnit(WorkUnit &, const InputImageType &, const MaskType *, const SampleGridSpacingType &);
+
   /** An array of integer spacing factors */
   SampleGridSpacingType m_SampleGridSpacing{ itk::MakeFilled<SampleGridSpacingType>(1) };
 
