@@ -94,15 +94,23 @@ protected:
   void
   GenerateData() override;
 
-  /** Multi-threaded functionality that does the work. */
-  void
-  BeforeThreadedGenerateData() override;
-
-  void
-  ThreadedGenerateData(const InputImageRegionType & inputRegionForThread, ThreadIdType threadId) override;
-
   RandomGeneratorPointer     m_RandomGenerator{ RandomGeneratorType::GetInstance() };
   InternalFullSamplerPointer m_InternalFullSampler{ InternalFullSamplerType::New() };
+
+private:
+  struct UserData
+  {
+    ITK_DISALLOW_COPY_AND_MOVE(UserData);
+
+    const std::vector<ImageSampleType> & m_AllValidSamples;
+    const std::vector<size_t> &          m_RandomIndices;
+    std::vector<ImageSampleType> &       m_Samples;
+  };
+
+  std::vector<size_t> m_RandomIndices{};
+
+  static ITK_THREAD_RETURN_FUNCTION_CALL_CONVENTION
+  ThreaderCallback(void * arg);
 };
 
 } // end namespace itk
