@@ -19,6 +19,7 @@
 #define itkImageSample_h
 
 #include "itkNumericTraits.h"
+#include "itkMath.h"
 
 namespace itk
 {
@@ -28,16 +29,13 @@ namespace itk
  * \brief A class that defines an image sample, which is
  * the coordinates of a point and its value.
  *
+ * Its constructors, assignment operators, and destructor are implicitly defaulted, following the C++ "Rule of Zero".
  */
 
 template <class TImage>
 class ITK_TEMPLATE_EXPORT ImageSample
 {
 public:
-  // ImageSample():m_ImageValue(0.0){};
-  ImageSample() = default;
-  ~ImageSample() = default;
-
   /** Typedef's. */
   using ImageType = TImage;
   using PointType = typename ImageType::PointType;
@@ -47,6 +45,18 @@ public:
   /** Member variables. */
   PointType m_ImageCoordinates;
   RealType  m_ImageValue;
+
+  friend bool
+  operator==(const ImageSample & lhs, const ImageSample & rhs)
+  {
+    return lhs.m_ImageCoordinates == rhs.m_ImageCoordinates && Math::ExactlyEquals(lhs.m_ImageValue, rhs.m_ImageValue);
+  }
+
+  friend bool
+  operator!=(const ImageSample & lhs, const ImageSample & rhs)
+  {
+    return !(lhs == rhs);
+  }
 };
 
 } // end namespace itk
