@@ -68,10 +68,13 @@ public:
   GraftNthOutput(unsigned int idx, DataObject * output);
 
   /** Make a DataObject of the correct type to used as the specified output. */
-  virtual DataObjectPointer
-  MakeOutput(unsigned int idx);
+  DataObjectPointer
+  MakeOutput(ProcessObject::DataObjectPointerArraySizeType idx) override;
 
 protected:
+  // Protected using-declaration, to avoid `-Woverloaded-virtual` warnings from GCC (GCC 11.4) or clang (macos-12).
+  using ProcessObject::MakeOutput;
+
   /** The constructor. */
   VectorContainerSource();
   /** The destructor. */
@@ -83,8 +86,8 @@ protected:
 
 private:
   /** Member variables. */
-  int m_GenerateDataRegion;
-  int m_GenerateDataNumberOfRegions;
+  int m_GenerateDataRegion{};
+  int m_GenerateDataNumberOfRegions{};
 };
 
 } // end namespace itk
