@@ -39,6 +39,7 @@
 
 #include "itkDataObject.h"
 #include "itkObjectFactory.h"
+#include "itkVectorContainer.h"
 
 #include <utility>
 #include <vector>
@@ -71,7 +72,7 @@ namespace itk
 template <typename TElementIdentifier, typename TElement>
 class ITK_TEMPLATE_EXPORT VectorDataContainer
   : public DataObject
-  , public std::vector<TElement>
+  , private std::vector<TElement>
 {
 public:
   /** Standard class typedefs. */
@@ -127,15 +128,11 @@ public:
   /** Standard part of every itk Object. */
   itkTypeMacro(VectorDataContainer, DataObject);
 
-  /** Convenient typedefs for the iterator and const iterator. */
-  class Iterator;
-  class ConstIterator;
-
   /** Cast the container to a STL container type */
   STLContainerType &
   CastToSTLContainer()
   {
-    return dynamic_cast<STLContainerType &>(*this);
+    return *this;
   }
 
 
@@ -143,224 +140,57 @@ public:
   const STLContainerType &
   CastToSTLConstContainer() const
   {
-    return dynamic_cast<const STLContainerType &>(*this);
+    return *this;
   }
 
+  using STLContainerType::begin;
+  using STLContainerType::end;
+  using STLContainerType::rbegin;
+  using STLContainerType::rend;
+  using STLContainerType::cbegin;
+  using STLContainerType::cend;
+  using STLContainerType::crbegin;
+  using STLContainerType::crend;
 
-  /** Friends to this class. */
-  friend class Iterator;
-  friend class ConstIterator;
+  using STLContainerType::size;
+  using STLContainerType::max_size;
+  using STLContainerType::resize;
+  using STLContainerType::capacity;
+  using STLContainerType::empty;
+  using STLContainerType::reserve;
+  using STLContainerType::shrink_to_fit;
 
-  /** Simulate STL-map style iteration where dereferencing the iterator
-   * gives access to both the index and the value. */
-  class Iterator
-  {
-  public:
-    Iterator() = default;
-    Iterator(size_type d, const VectorIterator & i)
-      : m_Pos(d)
-      , m_Iter(i)
-    {}
+  using STLContainerType::operator[];
+  using STLContainerType::at;
+  using STLContainerType::front;
+  using STLContainerType::back;
 
-    Iterator & operator*() { return *this; }
-    Iterator * operator->() { return this; }
-    Iterator &
-    operator++()
-    {
-      ++m_Pos;
-      ++m_Iter;
-      return *this;
-    }
-    Iterator
-    operator++(int)
-    {
-      Iterator temp(*this);
-      ++m_Pos;
-      ++m_Iter;
-      return temp;
-    }
-    Iterator
-    operator+=(int j)
-    {
-      m_Pos += j;
-      m_Iter += j;
-      return *this;
-    }
-    Iterator
-    operator-=(int j)
-    {
-      m_Pos -= j;
-      m_Iter -= j;
-      return *this;
-    }
-    Iterator &
-    operator--()
-    {
-      --m_Pos;
-      --m_Iter;
-      return *this;
-    }
-    Iterator
-    operator--(int)
-    {
-      Iterator temp(*this);
-      --m_Pos;
-      --m_Iter;
-      return temp;
-    }
+  using STLContainerType::assign;
+  using STLContainerType::push_back;
+  using STLContainerType::pop_back;
+  using STLContainerType::insert;
+  using STLContainerType::erase;
+  using STLContainerType::swap;
+  using STLContainerType::clear;
 
-    bool
-    operator==(const Iterator & r) const
-    {
-      return m_Iter == r.m_Iter;
-    }
-    bool
-    operator!=(const Iterator & r) const
-    {
-      return m_Iter != r.m_Iter;
-    }
-    bool
-    operator==(const ConstIterator & r) const
-    {
-      return m_Iter == r.m_Iter;
-    }
-    bool
-    operator!=(const ConstIterator & r) const
-    {
-      return m_Iter != r.m_Iter;
-    }
+  using STLContainerType::get_allocator;
 
-    /** Get the index into the VectorDataContainer associated with this iterator.   */
-    ElementIdentifier
-    Index() const
-    {
-      return static_cast<ElementIdentifier>(m_Pos);
-    }
+  using typename STLContainerType::reference;
+  using typename STLContainerType::const_reference;
+  using typename STLContainerType::iterator;
+  using typename STLContainerType::const_iterator;
+  // already declared before
+  // using STLContainerType::size_type;
+  using typename STLContainerType::difference_type;
+  using typename STLContainerType::value_type;
+  using typename STLContainerType::allocator_type;
+  using typename STLContainerType::pointer;
+  using typename STLContainerType::const_pointer;
+  using typename STLContainerType::reverse_iterator;
+  using typename STLContainerType::const_reverse_iterator;
 
-    /** Get the value at this iterator's location in the VectorDataContainer.   */
-    Element &
-    Value() const
-    {
-      return *m_Iter;
-    }
-
-  private:
-    size_type      m_Pos;
-    VectorIterator m_Iter;
-    friend class ConstIterator;
-  };
-
-  /** Simulate STL-map style const iteration where dereferencing the iterator
-   * gives read access to both the index and the value. */
-  class ConstIterator
-  {
-  public:
-    ConstIterator() = default;
-    ConstIterator(size_type d, const VectorConstIterator & i)
-      : m_Pos(d)
-      , m_Iter(i)
-    {}
-    ConstIterator(const Iterator & r)
-    {
-      m_Pos = r.m_Pos;
-      m_Iter = r.m_Iter;
-    }
-
-    ConstIterator & operator*() { return *this; }
-    ConstIterator * operator->() { return this; }
-    ConstIterator &
-    operator++()
-    {
-      ++m_Pos;
-      ++m_Iter;
-      return *this;
-    }
-    ConstIterator
-    operator++(int)
-    {
-      ConstIterator temp(*this);
-      ++m_Pos;
-      ++m_Iter;
-      return temp;
-    }
-    ConstIterator
-    operator+=(int j)
-    {
-      m_Pos += j;
-      m_Iter += j;
-      return *this;
-    }
-    ConstIterator
-    operator-=(int j)
-    {
-      m_Pos -= j;
-      m_Iter -= j;
-      return *this;
-    }
-    ConstIterator &
-    operator--()
-    {
-      --m_Pos;
-      --m_Iter;
-      return *this;
-    }
-    ConstIterator
-    operator--(int)
-    {
-      ConstIterator temp(*this);
-      --m_Pos;
-      --m_Iter;
-      return temp;
-    }
-
-    ConstIterator &
-    operator=(const Iterator & r)
-    {
-      m_Pos = r.m_Pos;
-      m_Iter = r.m_Iter;
-      return *this;
-    }
-
-    bool
-    operator==(const Iterator & r) const
-    {
-      return m_Iter == r.m_Iter;
-    }
-    bool
-    operator!=(const Iterator & r) const
-    {
-      return m_Iter != r.m_Iter;
-    }
-    bool
-    operator==(const ConstIterator & r) const
-    {
-      return m_Iter == r.m_Iter;
-    }
-    bool
-    operator!=(const ConstIterator & r) const
-    {
-      return m_Iter != r.m_Iter;
-    }
-
-    /** Get the index into the VectorDataContainer associated with this iterator.   */
-    ElementIdentifier
-    Index() const
-    {
-      return static_cast<ElementIdentifier>(m_Pos);
-    }
-
-    /** Get the value at this iterator's location in the VectorDataContainer.   */
-    const Element &
-    Value() const
-    {
-      return *m_Iter;
-    }
-
-  private:
-    size_type           m_Pos;
-    VectorConstIterator m_Iter;
-    friend class Iterator;
-  };
+  using Iterator = typename VectorContainer<TElementIdentifier, TElement>::Iterator;
+  using ConstIterator = typename VectorContainer<TElementIdentifier, TElement>::ConstIterator;
 
   /* Declare the public interface routines. */
 
