@@ -29,7 +29,7 @@ namespace itk
 
 MoreThuenteLineSearchOptimizer::MoreThuenteLineSearchOptimizer()
 {
-  this->m_f = NumericTraits<MeasureType>::Zero;
+  this->m_f = MeasureType{};
   this->m_dg = 0.0;
   this->m_InitialDerivativeProvided = false;
   this->m_InitialValueProvided = false;
@@ -192,34 +192,34 @@ MoreThuenteLineSearchOptimizer::CheckSettings()
 {
   if (this->GetCostFunction() == nullptr)
   {
-    itkExceptionMacro(<< "CostFunction has not been set!");
+    itkExceptionMacro("CostFunction has not been set!");
   }
 
   const unsigned int numberOfParameters = this->GetCostFunction()->GetNumberOfParameters();
 
   if (this->GetInitialPosition().GetSize() != numberOfParameters)
   {
-    itkExceptionMacro(<< "InitialPosition has incorrect dimension!");
+    itkExceptionMacro("InitialPosition has incorrect dimension!");
   }
 
   if (this->GetLineSearchDirection().GetSize() != numberOfParameters)
   {
-    itkExceptionMacro(<< "LineSearchDirection has incorrect dimension!");
+    itkExceptionMacro("LineSearchDirection has incorrect dimension!");
   }
 
   if (this->GetMinimumStepLength() <= 0.0)
   {
-    itkExceptionMacro(<< "MinimumStepLength must be higher than zero!");
+    itkExceptionMacro("MinimumStepLength must be higher than zero!");
   }
 
   if (this->GetMinimumStepLength() > this->GetMaximumStepLength())
   {
-    itkExceptionMacro(<< "MinimumStepLength must be smaller than MaximumStepLength!");
+    itkExceptionMacro("MinimumStepLength must be smaller than MaximumStepLength!");
   }
 
   if (this->GetGradientTolerance() < this->GetValueTolerance())
   {
-    itkExceptionMacro(<< "GradientTolerance must be greater than ValueTolerance!");
+    itkExceptionMacro("GradientTolerance must be greater than ValueTolerance!");
   }
   return 0;
 
@@ -868,8 +868,7 @@ MoreThuenteLineSearchOptimizer::SafeGuardedStep(double &     stx,
 
   /*     COMPUTE THE NEW STEP AND SAFEGUARD IT. */
 
-  stpf = std::min(stpmax, stpf);
-  stpf = std::max(stpmin, stpf);
+  stpf = std::clamp(stpf, stpmin, stpmax);
   stp = stpf;
   if (brackt && bound)
   {
