@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkGPUImageBase_h
-#define __itkGPUImageBase_h
+#ifndef itkGPUImageBase_h
+#define itkGPUImageBase_h
 
 #include "itkMacro.h"
 
@@ -35,7 +35,7 @@ namespace itk
  */
 
 /** Create a helper GPU Kernel class for itkGPUImageBase */
-itkGPUKernelClassMacro( GPUImageBaseKernel );
+itkGPUKernelClassMacro(GPUImageBaseKernel);
 } // end namespace itk
 
 #endif /* itkGPUImageBase_h */
