@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkGPUImageFunction_h
-#define __itkGPUImageFunction_h
+#ifndef itkGPUImageFunction_h
+#define itkGPUImageFunction_h
 
 #include "itkMacro.h"
 
@@ -35,7 +35,7 @@ namespace itk
  */
 
 /** Create a helper GPU Kernel class for itkGPUImageFunction */
-itkGPUKernelClassMacro( GPUImageFunctionKernel );
+itkGPUKernelClassMacro(GPUImageFunctionKernel);
 } // end namespace itk
 
 #endif /* itkGPUImageFunction_h */
