@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkGPUInterpolateImageFunction_h
-#define __itkGPUInterpolateImageFunction_h
+#ifndef itkGPUInterpolateImageFunction_h
+#define itkGPUInterpolateImageFunction_h
 
 #include "itkInterpolateImageFunction.h"
 #include "itkGPUInterpolatorBase.h"
@@ -34,52 +34,49 @@ namespace itk
  *
  * \ingroup GPUCommon
  */
-template< typename TInputImage, typename TCoordRep = float, typename TParentInterpolateImageFunction
-                                                   = InterpolateImageFunction< TInputImage, TCoordRep > >
-class ITK_EXPORT GPUInterpolateImageFunction :
-  public         TParentInterpolateImageFunction, public GPUInterpolatorBase
+template <typename TInputImage,
+          typename TCoordRep = float,
+          typename TParentInterpolateImageFunction = InterpolateImageFunction<TInputImage, TCoordRep>>
+class ITK_TEMPLATE_EXPORT GPUInterpolateImageFunction
+  : public TParentInterpolateImageFunction
+  , public GPUInterpolatorBase
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(GPUInterpolateImageFunction);
 
   /** Standard class typedefs. */
-  typedef GPUInterpolateImageFunction     Self;
-  typedef TParentInterpolateImageFunction CPUSuperclass;
-  typedef GPUInterpolatorBase             GPUSuperclass;
-  typedef SmartPointer< Self >            Pointer;
-  typedef SmartPointer< const Self >      ConstPointer;
+  using Self = GPUInterpolateImageFunction;
+  using CPUSuperclass = TParentInterpolateImageFunction;
+  using GPUSuperclass = GPUInterpolatorBase;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( GPUInterpolateImageFunction, TParentInterpolateImageFunction );
+  itkTypeMacro(GPUInterpolateImageFunction, TParentInterpolateImageFunction);
 
   /** ImageDimension constants */
-  itkStaticConstMacro( InputImageDimension, unsigned int,
-    TInputImage::ImageDimension );
+  itkStaticConstMacro(InputImageDimension, unsigned int, TInputImage::ImageDimension);
 
   /** Superclass typedef support. */
-  typedef typename CPUSuperclass::InputImageType      InputImageType;
-  typedef typename CPUSuperclass::ContinuousIndexType ContinuousIndexType;
-  typedef typename CPUSuperclass::CoordRepType        CoordRepType;
+  using InputImageType = typename CPUSuperclass::InputImageType;
+  using ContinuousIndexType = typename CPUSuperclass::ContinuousIndexType;
+  using CoordRepType = typename CPUSuperclass::CoordRepType;
 
 protected:
-
   GPUInterpolateImageFunction();
-  ~GPUInterpolateImageFunction() override {}
-  void PrintSelf( std::ostream & os, Indent indent ) const override;
+  ~GPUInterpolateImageFunction() override = default;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
   /** Returns data manager that stores all settings for the transform. */
-  GPUDataManager::Pointer GetParametersDataManager( void ) const override;
-
-private:
-
-  GPUInterpolateImageFunction( const Self & ); // purposely not implemented
-  void operator=( const Self & );              // purposely not implemented
-
+  GPUDataManager::Pointer
+  GetParametersDataManager() const override;
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkGPUInterpolateImageFunction.hxx"
+#  include "itkGPUInterpolateImageFunction.hxx"
 #endif
 
-#endif /* __itkGPUInterpolateImageFunction_h */
+#endif /* itkGPUInterpolateImageFunction_h */
