@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkGPUMath_h
-#define __itkGPUMath_h
+#ifndef itkGPUMath_h
+#define itkGPUMath_h
 
 #include "itkMacro.h"
 
@@ -35,7 +35,7 @@ namespace itk
  */
 
 /** Create a helper GPU Kernel class for itkGPUMath */
-itkGPUKernelClassMacro( GPUMathKernel );
+itkGPUKernelClassMacro(GPUMathKernel);
 } // end namespace itk
 
 #endif /* itkGPUMath_h */
