@@ -16,22 +16,22 @@
  *
  *=========================================================================*/
 /*=========================================================================
-*
-*  Copyright Insight Software Consortium
-*
-*  Licensed under the Apache License, Version 2.0 (the "License");
-*  you may not use this file except in compliance with the License.
-*  You may obtain a copy of the License at
-*
-*         http://www.apache.org/licenses/LICENSE-2.0.txt
-*
-*  Unless required by applicable law or agreed to in writing, software
-*  distributed under the License is distributed on an "AS IS" BASIS,
-*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-*  See the License for the specific language governing permissions and
-*  limitations under the License.
-*
-*=========================================================================*/
+ *
+ *  Copyright Insight Software Consortium
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 #include "itkGPUDataManager.h"
 
 namespace itk
@@ -39,7 +39,7 @@ namespace itk
 // constructor
 GPUDataManager::GPUDataManager()
 {
-  m_Context   = OpenCLContext::GetInstance();
+  m_Context = OpenCLContext::GetInstance();
   m_GPUBuffer = nullptr;
   m_CPUBuffer = nullptr;
 
@@ -53,20 +53,20 @@ GPUDataManager::GPUDataManager()
 //------------------------------------------------------------------------------
 GPUDataManager::~GPUDataManager()
 {
-  if( m_GPUBuffer )
+  if (m_GPUBuffer)
   {
-#if ( defined( _WIN32 ) && defined( _DEBUG ) ) || !defined( NDEBUG )
-    std::cout << "clReleaseMemObject" << "..." << std::endl;
+#if (defined(_WIN32) && defined(_DEBUG)) || !defined(NDEBUG)
+    std::cout << "clReleaseMemObject..." << std::endl;
 #endif
-    cl_int errid = clReleaseMemObject( m_GPUBuffer );
-    m_Context->ReportError( errid, __FILE__, __LINE__, ITK_LOCATION );
+    cl_int errid = clReleaseMemObject(m_GPUBuffer);
+    m_Context->ReportError(errid, __FILE__, __LINE__, ITK_LOCATION);
   }
 }
 
 
 //------------------------------------------------------------------------------
 void
-GPUDataManager::SetBufferSize( unsigned int num )
+GPUDataManager::SetBufferSize(unsigned int num)
 {
   m_BufferSize = num;
 }
@@ -74,7 +74,7 @@ GPUDataManager::SetBufferSize( unsigned int num )
 
 //------------------------------------------------------------------------------
 void
-GPUDataManager::SetBufferFlag( cl_mem_flags flags )
+GPUDataManager::SetBufferFlag(cl_mem_flags flags)
 {
   m_MemFlags = flags;
 }
@@ -84,23 +84,21 @@ GPUDataManager::SetBufferFlag( cl_mem_flags flags )
 void
 GPUDataManager::Allocate()
 {
-  if( this->m_GPUBufferLock )
+  if (this->m_GPUBufferLock)
   {
     return;
   }
 
   cl_int errid;
 
-  if( m_BufferSize > 0 )
+  if (m_BufferSize > 0)
   {
-#if ( defined( _WIN32 ) && defined( _DEBUG ) ) || !defined( NDEBUG )
-    std::cout << "clCreateBuffer, "
-              << this <<  "::Allocate Create GPU buffer of size "
-              << m_BufferSize << " Bytes" << std::endl;
+#if (defined(_WIN32) && defined(_DEBUG)) || !defined(NDEBUG)
+    std::cout << "clCreateBuffer, " << this << "::Allocate Create GPU buffer of size " << m_BufferSize << " Bytes"
+              << std::endl;
 #endif
-    m_GPUBuffer = clCreateBuffer( m_Context->GetContextId(),
-      m_MemFlags, m_BufferSize, nullptr, &errid );
-    m_Context->ReportError( errid, __FILE__, __LINE__, ITK_LOCATION );
+    m_GPUBuffer = clCreateBuffer(m_Context->GetContextId(), m_MemFlags, m_BufferSize, nullptr, &errid);
+    m_Context->ReportError(errid, __FILE__, __LINE__, ITK_LOCATION);
     m_IsGPUBufferDirty = true;
   }
 }
@@ -108,7 +106,7 @@ GPUDataManager::Allocate()
 
 //------------------------------------------------------------------------------
 void
-GPUDataManager::SetCPUBufferPointer( void * ptr )
+GPUDataManager::SetCPUBufferPointer(void * ptr)
 {
   m_CPUBuffer = ptr;
 }
@@ -116,7 +114,7 @@ GPUDataManager::SetCPUBufferPointer( void * ptr )
 
 //------------------------------------------------------------------------------
 void
-GPUDataManager::SetCPUDirtyFlag( bool isDirty )
+GPUDataManager::SetCPUDirtyFlag(bool isDirty)
 {
   m_IsCPUBufferDirty = isDirty;
 }
@@ -124,7 +122,7 @@ GPUDataManager::SetCPUDirtyFlag( bool isDirty )
 
 //------------------------------------------------------------------------------
 void
-GPUDataManager::SetGPUDirtyFlag( bool isDirty )
+GPUDataManager::SetGPUDirtyFlag(bool isDirty)
 {
   m_IsGPUBufferDirty = isDirty;
 }
@@ -152,34 +150,46 @@ GPUDataManager::SetCPUBufferDirty()
 void
 GPUDataManager::UpdateCPUBuffer()
 {
-  if( this->m_CPUBufferLock )
+  if (this->m_CPUBufferLock)
   {
     return;
   }
 
-  MutexHolderType holder( m_Mutex );
+  MutexHolderType holder(m_Mutex);
 
-  if( m_IsCPUBufferDirty && m_GPUBuffer != nullptr && m_CPUBuffer != nullptr )
+  if (m_IsCPUBufferDirty && m_GPUBuffer != nullptr && m_CPUBuffer != nullptr)
   {
-#if ( defined( _WIN32 ) && defined( _DEBUG ) ) || !defined( NDEBUG )
-    std::cout << "clEnqueueReadBuffer, " << this
-              << "::UpdateCPUBuffer GPU->CPU data copy "
-              << m_GPUBuffer << "->" << m_CPUBuffer << std::endl;
+#if (defined(_WIN32) && defined(_DEBUG)) || !defined(NDEBUG)
+    std::cout << "clEnqueueReadBuffer, " << this << "::UpdateCPUBuffer GPU->CPU data copy " << m_GPUBuffer << "->"
+              << m_CPUBuffer << std::endl;
 #endif
 
     cl_int errid;
 #ifdef OPENCL_PROFILING
     cl_event clEvent = NULL;
-    errid = clEnqueueReadBuffer( m_Context->GetCommandQueue().GetQueueId(), m_GPUBuffer, CL_TRUE, 0,
-      m_BufferSize, m_CPUBuffer, 0, nullptr,
-      &clEvent );
+    errid = clEnqueueReadBuffer(m_Context->GetCommandQueue().GetQueueId(),
+                                m_GPUBuffer,
+                                CL_TRUE,
+                                0,
+                                m_BufferSize,
+                                m_CPUBuffer,
+                                0,
+                                nullptr,
+                                &clEvent);
 #else
-    errid = clEnqueueReadBuffer( m_Context->GetCommandQueue().GetQueueId(), m_GPUBuffer, CL_TRUE, 0,
-      m_BufferSize, m_CPUBuffer, 0, nullptr, nullptr);
+    errid = clEnqueueReadBuffer(m_Context->GetCommandQueue().GetQueueId(),
+                                m_GPUBuffer,
+                                CL_TRUE,
+                                0,
+                                m_BufferSize,
+                                m_CPUBuffer,
+                                0,
+                                nullptr,
+                                nullptr);
 #endif
 
-    m_Context->ReportError( errid, __FILE__, __LINE__, ITK_LOCATION );
-    //m_ContextManager->OpenCLProfile(clEvent, "clEnqueueReadBuffer GPU->CPU");
+    m_Context->ReportError(errid, __FILE__, __LINE__, ITK_LOCATION);
+    // m_ContextManager->OpenCLProfile(clEvent, "clEnqueueReadBuffer GPU->CPU");
 
     m_IsCPUBufferDirty = false;
   }
@@ -190,33 +200,45 @@ GPUDataManager::UpdateCPUBuffer()
 void
 GPUDataManager::UpdateGPUBuffer()
 {
-  if( this->m_GPUBufferLock )
+  if (this->m_GPUBufferLock)
   {
     return;
   }
 
-  MutexHolderType holder( m_Mutex );
+  MutexHolderType holder(m_Mutex);
 
-  if( m_IsGPUBufferDirty && m_CPUBuffer != nullptr && m_GPUBuffer != nullptr )
+  if (m_IsGPUBufferDirty && m_CPUBuffer != nullptr && m_GPUBuffer != nullptr)
   {
-#if ( defined( _WIN32 ) && defined( _DEBUG ) ) || !defined( NDEBUG )
-    std::cout << "clEnqueueWriteBuffer, " << this << "::UpdateGPUBuffer CPU->GPU data copy "
-              << m_CPUBuffer << "->" << m_GPUBuffer << std::endl;
+#if (defined(_WIN32) && defined(_DEBUG)) || !defined(NDEBUG)
+    std::cout << "clEnqueueWriteBuffer, " << this << "::UpdateGPUBuffer CPU->GPU data copy " << m_CPUBuffer << "->"
+              << m_GPUBuffer << std::endl;
 #endif
 
     cl_int errid;
 #ifdef OPENCL_PROFILING
     cl_event clEvent = NULL;
-    errid = clEnqueueWriteBuffer(
-      m_Context->GetCommandQueue().GetQueueId(), m_GPUBuffer, CL_TRUE, 0, m_BufferSize, m_CPUBuffer, 0, nullptr,
-      &clEvent );
+    errid = clEnqueueWriteBuffer(m_Context->GetCommandQueue().GetQueueId(),
+                                 m_GPUBuffer,
+                                 CL_TRUE,
+                                 0,
+                                 m_BufferSize,
+                                 m_CPUBuffer,
+                                 0,
+                                 nullptr,
+                                 &clEvent);
 #else
-    errid = clEnqueueWriteBuffer(
-      m_Context->GetCommandQueue().GetQueueId(), m_GPUBuffer, CL_TRUE, 0, m_BufferSize, m_CPUBuffer, 0, nullptr,
-      nullptr );
+    errid = clEnqueueWriteBuffer(m_Context->GetCommandQueue().GetQueueId(),
+                                 m_GPUBuffer,
+                                 CL_TRUE,
+                                 0,
+                                 m_BufferSize,
+                                 m_CPUBuffer,
+                                 0,
+                                 nullptr,
+                                 nullptr);
 #endif
-    m_Context->ReportError( errid, __FILE__, __LINE__, ITK_LOCATION );
-    //m_ContextManager->OpenCLProfile(clEvent, "clEnqueueWriteBuffer CPU->GPU");
+    m_Context->ReportError(errid, __FILE__, __LINE__, ITK_LOCATION);
+    // m_ContextManager->OpenCLProfile(clEvent, "clEnqueueWriteBuffer CPU->GPU");
 
     m_IsGPUBufferDirty = false;
   }
@@ -245,9 +267,9 @@ GPUDataManager::GetCPUBufferPointer()
 bool
 GPUDataManager::Update()
 {
-  if( m_IsGPUBufferDirty && m_IsCPUBufferDirty )
+  if (m_IsGPUBufferDirty && m_IsCPUBufferDirty)
   {
-    itkExceptionMacro( "Cannot make up-to-date buffer because both CPU and GPU buffers are dirty" );
+    itkExceptionMacro("Cannot make up-to-date buffer because both CPU and GPU buffers are dirty");
     return false;
   }
 
@@ -262,27 +284,27 @@ GPUDataManager::Update()
 
 //------------------------------------------------------------------------------
 void
-GPUDataManager::Graft( const GPUDataManager * data )
+GPUDataManager::Graft(const GPUDataManager * data)
 {
-  if( data )
+  if (data)
   {
     m_BufferSize = data->m_BufferSize;
-    m_Context    = data->m_Context;
-    m_MemFlags   = data->m_MemFlags;
+    m_Context = data->m_Context;
+    m_MemFlags = data->m_MemFlags;
 
-    if( m_GPUBuffer )  // Decrease reference count to GPU memory
+    if (m_GPUBuffer) // Decrease reference count to GPU memory
     {
-#if ( defined( _WIN32 ) && defined( _DEBUG ) ) || !defined( NDEBUG )
-      std::cout << "clReleaseMemObject" << "..." << std::endl;
+#if (defined(_WIN32) && defined(_DEBUG)) || !defined(NDEBUG)
+      std::cout << "clReleaseMemObject..." << std::endl;
 #endif
-      clReleaseMemObject( m_GPUBuffer );
+      clReleaseMemObject(m_GPUBuffer);
     }
-    if( data->m_GPUBuffer )  // Increase reference count to GPU memory
+    if (data->m_GPUBuffer) // Increase reference count to GPU memory
     {
-#if ( defined( _WIN32 ) && defined( _DEBUG ) ) || !defined( NDEBUG )
-      std::cout << "clRetainMemObject" << "..." << std::endl;
+#if (defined(_WIN32) && defined(_DEBUG)) || !defined(NDEBUG)
+      std::cout << "clRetainMemObject..." << std::endl;
 #endif
-      clRetainMemObject( data->m_GPUBuffer );
+      clRetainMemObject(data->m_GPUBuffer);
     }
 
     m_GPUBuffer = data->m_GPUBuffer;
@@ -298,19 +320,19 @@ GPUDataManager::Graft( const GPUDataManager * data )
 void
 GPUDataManager::Initialize()
 {
-  if( m_GPUBuffer )  // Release GPU memory if exists
+  if (m_GPUBuffer) // Release GPU memory if exists
   {
-#if ( defined( _WIN32 ) && defined( _DEBUG ) ) || !defined( NDEBUG )
-    std::cout << "clReleaseMemObject" << "..." << std::endl;
+#if (defined(_WIN32) && defined(_DEBUG)) || !defined(NDEBUG)
+    std::cout << "clReleaseMemObject..." << std::endl;
 #endif
-    cl_int errid = clReleaseMemObject( m_GPUBuffer );
-    m_Context->ReportError( errid, __FILE__, __LINE__, ITK_LOCATION );
+    cl_int errid = clReleaseMemObject(m_GPUBuffer);
+    m_Context->ReportError(errid, __FILE__, __LINE__, ITK_LOCATION);
   }
 
-  m_BufferSize       = 0;
-  m_GPUBuffer        = nullptr;
-  m_CPUBuffer        = nullptr;
-  m_MemFlags         = CL_MEM_READ_WRITE; // default flag
+  m_BufferSize = 0;
+  m_GPUBuffer = nullptr;
+  m_CPUBuffer = nullptr;
+  m_MemFlags = CL_MEM_READ_WRITE; // default flag
   m_IsGPUBufferDirty = false;
   m_IsCPUBufferDirty = false;
 
@@ -321,7 +343,7 @@ GPUDataManager::Initialize()
 
 //------------------------------------------------------------------------------
 void
-GPUDataManager::PrintSelf( std::ostream & os, Indent indent ) const
+GPUDataManager::PrintSelf(std::ostream & os, Indent indent) const
 {
   os << indent << "GPUDataManager (" << this << ")" << std::endl;
   os << indent << "m_BufferSize: " << m_BufferSize << std::endl;
