@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkOpenCLSetup_h
-#define __itkOpenCLSetup_h
+#ifndef itkOpenCLSetup_h
+#define itkOpenCLSetup_h
 
 #include <string>
 
@@ -26,11 +26,12 @@
 namespace itk
 {
 /** Method that is used to create OpenCL context within elastix and transformix. */
-bool CreateOpenCLContext( std::string & errorMessage,
-  const std::string openCLDeviceType, const int openCLDeviceID );
+bool
+CreateOpenCLContext(std::string & errorMessage, const std::string openCLDeviceType, const int openCLDeviceID);
 
 /** Method that is used to create OpenCL logger within elastix and transformix. */
-void CreateOpenCLLogger( const std::string & prefixFileName, const std::string & outputDirectory );
+void
+CreateOpenCLLogger(const std::string & prefixFileName, const std::string & outputDirectory);
 
 } // end namespace itk
 
