@@ -74,8 +74,8 @@ bool
 ParameterMapInterface::ReadParameter(bool &              parameterValue,
                                      const std::string & parameterName,
                                      const unsigned int  entry_nr,
-                                     const bool          printThisErrorMessage,
-                                     std::string &       errorMessage) const
+                                     const bool          produceWarningMessage,
+                                     std::string &       warningMessage) const
 {
   /** Translate the default boolean to string. */
   std::string parameterValueString;
@@ -89,7 +89,8 @@ ParameterMapInterface::ReadParameter(bool &              parameterValue,
   }
 
   /** Read the boolean as a string. */
-  bool dummy = this->ReadParameter(parameterValueString, parameterName, entry_nr, printThisErrorMessage, errorMessage);
+  bool dummy =
+    this->ReadParameter(parameterValueString, parameterName, entry_nr, produceWarningMessage, warningMessage);
 
   /** Translate the read-in string to boolean. */
   parameterValue = false;
@@ -117,11 +118,11 @@ ParameterMapInterface::ReadParameter(std::vector<std::string> & parameterValues,
                                      const std::string &        parameterName,
                                      const unsigned int         entry_nr_start,
                                      const unsigned int         entry_nr_end,
-                                     const bool                 printThisErrorMessage,
-                                     std::string &              errorMessage) const
+                                     const bool                 produceWarningMessage,
+                                     std::string &              warningMessage) const
 {
-  /** Reset the error message. */
-  errorMessage = "";
+  /** Reset the warning message. */
+  warningMessage = "";
 
   /** Get the number of entries. */
   std::size_t numberOfEntries = this->CountNumberOfParameterEntries(parameterName);
@@ -129,13 +130,13 @@ ParameterMapInterface::ReadParameter(std::vector<std::string> & parameterValues,
   /** Check if the requested parameter exists. */
   if (numberOfEntries == 0)
   {
-    if (printThisErrorMessage && this->m_PrintErrorMessages)
+    if (produceWarningMessage && this->m_PrintErrorMessages)
     {
       std::ostringstream outputStringStream;
       outputStringStream << "WARNING: The parameter \"" << parameterName << "\", requested between entry numbers "
                          << entry_nr_start << " and " << entry_nr_end << ", does not exist at all.\n"
-                         << "  The default values are used instead.\n";
-      errorMessage = outputStringStream.str();
+                         << "  The default values are used instead.";
+      warningMessage = outputStringStream.str();
     }
     return false;
   }
