@@ -64,9 +64,9 @@ namespace itk
  * unsigned long parameterValue = 3;
  * unsigned int index = 2;
  * bool printWarning = true;
- * std::string errorMessage = "";
+ * std::string warningMessage = "";
  * bool success = p_interface->ReadParameter( parameterValue,
- *   "ParameterName", index, printWarning, errorMessage );
+ *   "ParameterName", index, printWarning, warningMessage );
  *
  *
  * Note that some of the templated functions are defined in the header to
@@ -138,11 +138,11 @@ public:
   ReadParameter(T &                 parameterValue,
                 const std::string & parameterName,
                 const unsigned int  entry_nr,
-                const bool          printThisErrorMessage,
-                std::string &       errorMessage) const
+                const bool          produceWarningMessage,
+                std::string &       warningMessage) const
   {
-    /** Reset the error message. */
-    errorMessage = "";
+    /** Reset the warning message. */
+    warningMessage = "";
 
     /** Get the number of entries. */
     std::size_t numberOfEntries = this->CountNumberOfParameterEntries(parameterName);
@@ -150,13 +150,13 @@ public:
     /** Check if the requested parameter exists. */
     if (numberOfEntries == 0)
     {
-      if (printThisErrorMessage && this->m_PrintErrorMessages)
+      if (produceWarningMessage && this->m_PrintErrorMessages)
       {
         std::ostringstream outputStringStream;
         outputStringStream << "WARNING: The parameter \"" << parameterName << "\", requested at entry number "
                            << entry_nr << ", does not exist at all.\n"
-                           << "  The default value \"" << parameterValue << "\" is used instead.\n";
-        errorMessage = outputStringStream.str();
+                           << "  The default value \"" << parameterValue << "\" is used instead.";
+        warningMessage = outputStringStream.str();
       }
 
       return false;
@@ -168,12 +168,12 @@ public:
     /** Check if it exists at the requested entry number. */
     if (entry_nr >= numberOfEntries)
     {
-      if (printThisErrorMessage && this->m_PrintErrorMessages)
+      if (produceWarningMessage && this->m_PrintErrorMessages)
       {
         std::ostringstream outputStringStream;
         outputStringStream << "WARNING: The parameter \"" << parameterName << "\" does not exist at entry number "
-                           << entry_nr << ".\n  The default value \"" << parameterValue << "\" is used instead.\n";
-        errorMessage = outputStringStream.str();
+                           << entry_nr << ".\n  The default value \"" << parameterValue << "\" is used instead.";
+        warningMessage = outputStringStream.str();
       }
       return false;
     }
@@ -200,20 +200,20 @@ public:
   ReadParameter(bool &              parameterValue,
                 const std::string & parameterName,
                 const unsigned int  entry_nr,
-                const bool          printThisErrorMessage,
-                std::string &       errorMessage) const;
+                const bool          produceWarningMessage,
+                std::string &       warningMessage) const;
 
   /** A shorter version of ReadParameter() that does not require the boolean
-   * printThisErrorMessage. Instead the default value true is used.
+   * produceWarningMessage. Instead the default value true is used.
    */
   template <class T>
   bool
   ReadParameter(T &                 parameterValue,
                 const std::string & parameterName,
                 const unsigned int  entry_nr,
-                std::string &       errorMessage) const
+                std::string &       warningMessage) const
   {
-    return this->ReadParameter(parameterValue, parameterName, entry_nr, true, errorMessage);
+    return this->ReadParameter(parameterValue, parameterName, entry_nr, true, warningMessage);
   }
 
 
@@ -229,8 +229,8 @@ public:
                 const std::string & prefix,
                 const unsigned int  entry_nr,
                 const int           default_entry_nr,
-                const bool          printThisErrorMessage,
-                std::string &       errorMessage) const
+                const bool          produceWarningMessage,
+                std::string &       warningMessage) const
   {
     std::string fullname = prefix + parameterName;
     bool        found = false;
@@ -256,9 +256,9 @@ public:
     /** If we haven't found anything, give a warning that the default value
      * provided by the caller is used.
      */
-    if (!found && printThisErrorMessage && this->m_PrintErrorMessages)
+    if (!found && produceWarningMessage && this->m_PrintErrorMessages)
     {
-      return this->ReadParameter(parameterValue, parameterName, entry_nr, true, errorMessage);
+      return this->ReadParameter(parameterValue, parameterName, entry_nr, true, warningMessage);
     }
 
     return found;
@@ -266,7 +266,7 @@ public:
 
 
   /** A shorter version of the extended ReadParameter() that does not require
-   * the boolean printThisErrorMessage. Instead the default value true is used.
+   * the boolean produceWarningMessage. Instead the default value true is used.
    */
   template <class T>
   bool
@@ -275,9 +275,9 @@ public:
                 const std::string & prefix,
                 const unsigned int  entry_nr,
                 const unsigned int  default_entry_nr,
-                std::string &       errorMessage) const
+                std::string &       warningMessage) const
   {
-    return this->ReadParameter(parameterValue, parameterName, prefix, entry_nr, default_entry_nr, true, errorMessage);
+    return this->ReadParameter(parameterValue, parameterName, prefix, entry_nr, default_entry_nr, true, warningMessage);
   }
 
 
@@ -288,11 +288,11 @@ public:
                 const std::string & parameterName,
                 const unsigned int  entry_nr_start,
                 const unsigned int  entry_nr_end,
-                const bool          printThisErrorMessage,
-                std::string &       errorMessage) const
+                const bool          produceWarningMessage,
+                std::string &       warningMessage) const
   {
-    /** Reset the error message. */
-    errorMessage = "";
+    /** Reset the warning message. */
+    warningMessage = "";
 
     /** Get the number of entries. */
     std::size_t numberOfEntries = this->CountNumberOfParameterEntries(parameterName);
@@ -300,13 +300,13 @@ public:
     /** Check if the requested parameter exists. */
     if (numberOfEntries == 0)
     {
-      if (printThisErrorMessage && this->m_PrintErrorMessages)
+      if (produceWarningMessage && this->m_PrintErrorMessages)
       {
         std::ostringstream outputStringStream;
         outputStringStream << "WARNING: The parameter \"" << parameterName << "\", requested between entry numbers "
                            << entry_nr_start << " and " << entry_nr_end << ", does not exist at all.\n"
-                           << "  The default values are used instead.\n";
-        errorMessage = outputStringStream.str();
+                           << "  The default values are used instead.";
+        warningMessage = outputStringStream.str();
       }
       return false;
     }
@@ -324,8 +324,8 @@ public:
     if (entry_nr_end >= numberOfEntries)
     {
       itkExceptionMacro("WARNING: The parameter \"" << parameterName << "\" does not exist at entry number "
-                                                    << entry_nr_end << ".\nThe default value \""
-                                                    << itk::NumericTraits<T>::Zero << "\" is used instead.\n");
+                                                    << entry_nr_end << ".\nThe default value \"" << T{}
+                                                    << "\" is used instead.");
     }
 
     /** Get the vector of parameters. */
@@ -334,7 +334,7 @@ public:
     /** The default is filled with zero's.
     parameterValues.clear();
     parameterValues.resize( entry_nr_end - entry_nr_start + 1,
-      itk::NumericTraits<T>::ZeroValue() );
+      T{} );
     */
 
     /** Get all parameters at once. */
@@ -365,8 +365,8 @@ public:
                 const std::string &        parameterName,
                 const unsigned int         entry_nr_start,
                 const unsigned int         entry_nr_end,
-                const bool                 printThisErrorMessage,
-                std::string &              errorMessage) const;
+                const bool                 produceWarningMessage,
+                std::string &              warningMessage) const;
 
 
   /** Returns the values of the specified parameter. */
@@ -404,8 +404,9 @@ public:
       else
       {
         const auto entry_nr = &str - found->second.data();
-        itkExceptionMacro(<< "Failed to cast parameter \"" << parameterName << "\" entry number " << entry_nr
-                          << " value \"" << str << "\" to type \"" << typeid(T).name() << "\"!");
+        itkExceptionMacro("Failed to cast parameter \"" << parameterName << "\" entry number " << entry_nr
+                                                        << " value \"" << str << "\" to type \"" << typeid(T).name()
+                                                        << "\"!");
       }
     }
     return std::make_unique<std::vector<T>>(std::move(result));
@@ -418,7 +419,7 @@ protected:
 
 private:
   /** Member variable to store the parameters. */
-  ParameterMapType m_ParameterMap;
+  ParameterMapType m_ParameterMap{};
 
   bool m_PrintErrorMessages{ true };
 };
