@@ -169,8 +169,7 @@ public:
   OutputVectorType
   TransformVector(const InputVectorType &) const override
   {
-    itkExceptionMacro(
-      << "TransformVector(const InputVectorType &) is not implemented for AdvancedCombinationTransform");
+    itkExceptionMacro("TransformVector(const InputVectorType &) is not implemented for AdvancedCombinationTransform");
   }
 
 
@@ -178,15 +177,15 @@ public:
   TransformVector(const InputVnlVectorType &) const override
   {
     itkExceptionMacro(
-      << "TransformVector(const InputVnlVectorType &) is not implemented for AdvancedCombinationTransform");
+      "TransformVector(const InputVnlVectorType &) is not implemented for AdvancedCombinationTransform");
   }
 
 
   OutputCovariantVectorType
   TransformCovariantVector(const InputCovariantVectorType &) const override
   {
-    itkExceptionMacro(<< "TransformCovariantVector(const InputCovariantVectorType &) is not implemented for "
-                         "AdvancedCombinationTransform");
+    itkExceptionMacro("TransformCovariantVector(const InputCovariantVectorType &) is not implemented for "
+                      "AdvancedCombinationTransform");
   }
 
 
@@ -547,8 +546,12 @@ protected:
                                                 NonZeroJacobianIndicesType &   nonZeroJacobianIndices) const;
 
 private:
+  // Private using-declarations, to avoid `-Woverloaded-virtual` warnings from GCC (GCC 11.4).
+  using Superclass::TransformCovariantVector;
+  using Superclass::TransformVector;
+
   /** Exception text. */
-  constexpr static const char * NoCurrentTransformSet = "No current transform set in the AdvancedCombinationTransform";
+  static constexpr const char * NoCurrentTransformSet = "No current transform set in the AdvancedCombinationTransform";
 
   /** Declaration of members. */
   InitialTransformPointer m_InitialTransform{ nullptr };
