@@ -304,8 +304,7 @@ protected:
     : AdvancedTransform<TScalarType, NDimensions, NDimensions>(NDimensions)
   {
     // The Jacobian is constant, therefore it can be initialized in the constructor.
-    this->m_LocalJacobian = JacobianType(NDimensions, 1);
-    this->m_LocalJacobian.Fill(0.0);
+    this->m_LocalJacobian = JacobianType(NDimensions, 1, 0.0);
 
     /** SpatialJacobian is also constant. */
     this->m_SpatialJacobian.SetIdentity();
@@ -327,12 +326,16 @@ protected:
   ~AdvancedIdentityTransform() override = default;
 
 private:
-  JacobianType                  m_LocalJacobian;
-  SpatialJacobianType           m_SpatialJacobian;
-  SpatialHessianType            m_SpatialHessian;
-  NonZeroJacobianIndicesType    m_NonZeroJacobianIndices;
-  JacobianOfSpatialJacobianType m_JacobianOfSpatialJacobian;
-  JacobianOfSpatialHessianType  m_JacobianOfSpatialHessian;
+  // Private using-declarations, to avoid `-Woverloaded-virtual` warnings from GCC (GCC 11.4).
+  using Superclass::TransformVector;
+  using Superclass::TransformCovariantVector;
+
+  JacobianType                  m_LocalJacobian{};
+  SpatialJacobianType           m_SpatialJacobian{};
+  SpatialHessianType            m_SpatialHessian{};
+  NonZeroJacobianIndicesType    m_NonZeroJacobianIndices{};
+  JacobianOfSpatialJacobianType m_JacobianOfSpatialJacobian{};
+  JacobianOfSpatialHessianType  m_JacobianOfSpatialHessian{};
 };
 
 } // end namespace itk
