@@ -22,7 +22,7 @@
 #include "itkBinaryThresholdImageFilter.h"
 #include "itkAffineTransform.h"
 #include "itkImage.h"
-#include "itkSpatialObject.h"
+#include "itkImageMaskSpatialObject.h"
 #include "itkImageGridSampler.h"
 #include "itkImageFullSampler.h"
 
@@ -30,7 +30,7 @@
 #include <vnl/vnl_matrix_fixed.h>
 #include <vnl/vnl_diag_matrix.h>
 
-#include "itkPlatformMultiThreader.h"
+#include "itkMultiThreaderBase.h"
 
 #include <vector>
 
@@ -90,7 +90,7 @@ public:
   using VectorType = Vector<ScalarType, Self::ImageDimension>;
 
   /** Spatial Object type within this class. */
-  using SpatialObjectType = SpatialObject<Self::ImageDimension>;
+  using SpatialObjectType = ImageMaskSpatialObject<Self::ImageDimension>;
 
   /** Spatial Object member types used within this class. */
   using SpatialObjectPointer = typename SpatialObjectType::Pointer;
@@ -124,7 +124,7 @@ public:
 
   /** Set the spatial object mask. */
   virtual void
-  SetSpatialObjectMask(const SpatialObject<Self::ImageDimension> * so)
+  SetSpatialObjectMask(const ImageMaskSpatialObject<Self::ImageDimension> * so)
   {
     if (m_SpatialObjectMask != so)
     {
@@ -256,9 +256,8 @@ protected:
   void
   PrintSelf(std::ostream & os, Indent indent) const override;
 
-  /** Typedefs for multi-threading. */
-  using ThreaderType = itk::PlatformMultiThreader;
-  using ThreadInfoType = ThreaderType::WorkUnitInfo;
+  /** Typedef for multi-threading. */
+  using ThreadInfoType = MultiThreaderBase::WorkUnitInfo;
 
   /** Launch MultiThread Compute. */
   void
@@ -308,30 +307,30 @@ private:
   void
   operator=(const Self &);
 
-  ThreaderType::Pointer m_Threader;
+  MultiThreaderBase::Pointer m_Threader{};
 
-  mutable MultiThreaderParameterType m_ThreaderParameters;
+  mutable MultiThreaderParameterType m_ThreaderParameters{};
 
-  mutable std::vector<AlignedComputePerThreadStruct> m_ComputePerThreadVariables;
-  bool                                               m_UseMultiThread;
-  SizeValueType                                      m_NumberOfPixelsCounted;
+  mutable std::vector<AlignedComputePerThreadStruct> m_ComputePerThreadVariables{};
+  bool                                               m_UseMultiThread{};
+  SizeValueType                                      m_NumberOfPixelsCounted{};
 
-  SizeValueType               m_NumberOfSamplesForCenteredTransformInitialization;
-  InputPixelType              m_LowerThresholdForCenterGravity;
-  bool                        m_CenterOfGravityUsesLowerThreshold;
-  ImageSampleContainerPointer m_SampleContainer;
+  SizeValueType               m_NumberOfSamplesForCenteredTransformInitialization{};
+  InputPixelType              m_LowerThresholdForCenterGravity{};
+  bool                        m_CenterOfGravityUsesLowerThreshold{};
+  ImageSampleContainerPointer m_SampleContainer{};
 
-  bool       m_Valid; // Have moments been computed yet?
-  ScalarType m_M0;    // Zeroth moment
-  VectorType m_M1;    // First moments about origin
-  MatrixType m_M2;    // Second moments about origin
-  VectorType m_Cg;    // Center of gravity (physical units)
-  MatrixType m_Cm;    // Second central moments (physical)
-  VectorType m_Pm;    // Principal moments (physical)
-  MatrixType m_Pa;    // Principal axes (physical)
+  bool       m_Valid{}; // Have moments been computed yet?
+  ScalarType m_M0{};    // Zeroth moment
+  VectorType m_M1{};    // First moments about origin
+  MatrixType m_M2{};    // Second moments about origin
+  VectorType m_Cg{};    // Center of gravity (physical units)
+  MatrixType m_Cm{};    // Second central moments (physical)
+  VectorType m_Pm{};    // Principal moments (physical)
+  MatrixType m_Pa{};    // Principal axes (physical)
 
-  ImageConstPointer         m_Image;
-  SpatialObjectConstPointer m_SpatialObjectMask;
+  ImageConstPointer         m_Image{};
+  SpatialObjectConstPointer m_SpatialObjectMask{};
 
 }; // class AdvancedImageMomentsCalculator
 } // end namespace itk
