@@ -101,11 +101,8 @@ public:
   void
   ComputeStartIndex(const ContinuousIndexType & index, IndexType & startIndex) const;
 
-  /** Get support region size. */
-  itkGetConstReferenceMacro(SupportSize, SizeType);
-
-  /** Get number of weights. */
-  itkGetConstMacro(NumberOfWeights, unsigned long);
+  /** The support region size: a hypercube of length SplineOrder + 1 */
+  static constexpr SizeType SupportSize{ SizeType::Filled(VSplineOrder + 1) };
 
 protected:
   BSplineInterpolationWeightFunctionBase();
@@ -120,9 +117,6 @@ protected:
   using SecondOrderDerivativeKernelPointer = typename SecondOrderDerivativeKernelType::Pointer;
   using WeightArrayType = typename KernelType::WeightArrayType;
 
-  /** Lookup table type. */
-  using TableType = Array2D<unsigned long>;
-
   /** Typedef for intermediary 1D weights.
    * The Matrix is at least twice as fast as std::vector< vnl_vector< double > >,
    * probably because of the fixed size at compile time.
@@ -140,15 +134,9 @@ protected:
   PrintSelf(std::ostream & os, Indent indent) const override;
 
   /** Member variables. */
-  unsigned long m_NumberOfWeights;
-  SizeType      m_SupportSize;
-  TableType     m_OffsetToIndexTable;
+  vnl_matrix<unsigned long> m_OffsetToIndexTable{};
 
 private:
-  /** Function to initialize the support region. */
-  void
-  InitializeSupport();
-
   /** Function to initialize the offset table.
    * The offset table is a convenience table, just to
    * keep track where is what.
