@@ -67,7 +67,6 @@ public:
   using SpacingType = typename ImageBaseType::SpacingType;
   using DirectionType = typename ImageBaseType::DirectionType;
   using SizeType = typename ImageBaseType::SizeType;
-  using SizeValueType = typename ImageBaseType::SizeValueType;
   using RegionType = typename ImageBaseType::RegionType;
   using GridSpacingFactorType = SpacingType;
   using VectorOriginType = std::vector<OriginType>;
@@ -86,7 +85,7 @@ public:
 
 protected:
   /** The constructor. */
-  CyclicGridScheduleComputer();
+  CyclicGridScheduleComputer() = default;
 
   /** The destructor. */
   ~CyclicGridScheduleComputer() override = default;
