@@ -21,6 +21,8 @@
 #include "itkAdvancedTransform.h"
 #include "itkIndex.h"
 
+#include <cassert>
+
 namespace itk
 {
 
@@ -120,8 +122,8 @@ public:
     const auto numberOfFixedParameters = fixedParameters.size();
     if (numberOfFixedParameters < NumberOfGeneralFixedParametersOfStack)
     {
-      itkExceptionMacro(<< "The number of FixedParameters (" << numberOfFixedParameters << ") should be at least "
-                        << NumberOfGeneralFixedParametersOfStack);
+      itkExceptionMacro("The number of FixedParameters (" << numberOfFixedParameters << ") should be at least "
+                                                          << NumberOfGeneralFixedParametersOfStack);
     }
 
     if (Superclass::m_FixedParameters != fixedParameters)
@@ -257,8 +259,8 @@ protected:
     }
     else
     {
-      itkExceptionMacro(<< "The FixedParameters element (" << numberOfSubTransforms
-                        << ") should be a valid number (the number of subtransforms).");
+      itkExceptionMacro("The FixedParameters element (" << numberOfSubTransforms
+                                                        << ") should be a valid number (the number of subtransforms).");
     }
 
     for (auto & subTransform : m_SubTransformContainer)
@@ -302,6 +304,10 @@ protected:
   }
 
 private:
+  // Private using-declarations, to avoid `-Woverloaded-virtual` warnings from GCC (GCC 11.4).
+  using Superclass::TransformCovariantVector;
+  using Superclass::TransformVector;
+
   /** Each override of this pure virtual member function should create a subtransform for the specific (derived) stack
    * transform type. For example, for an `TranslationStackTransform` it should create an `AdvancedTranslationTransform`,
    * and for an `EulerStackTransform` it should create an `EulerTransform`. */
@@ -381,7 +387,7 @@ private:
 
 
   // Transform container
-  std::vector<SubTransformPointer> m_SubTransformContainer;
+  std::vector<SubTransformPointer> m_SubTransformContainer{};
 
   // Stack spacing and origin of last dimension
   TScalarType m_StackSpacing{ 1.0 };
