@@ -91,26 +91,14 @@ public:
   void
   Compute(const ParametersType & mu, double & jacg, double & maxJJ, std::string method) override;
 
-  /** The main function that performs the computation.
-   * DO NOT USE.
-   */
-  virtual void
-  ComputeDistributionTermsUsingSearchDir(const ParametersType & mu, double & jacg, double & maxJJ, std::string methods);
-
-  /** The main function that performs the computation.
-   * B-spline specific thing we tried. Can be removed later.
-   */
-  void
-  ComputeForBSplineOnly(const ParametersType & mu, const double delta, double & maxJJ, ParametersType & preconditioner);
-
   /** The main function that performs the computation.
    * The aims to be a generic function, working for all transformations.
    */
   virtual void
   Compute(const ParametersType & mu, double & maxJJ, ParametersType & preconditioner);
 
-  virtual void
-  ComputeJacobiTypePreconditioner(const ParametersType & mu, double & maxJJ, ParametersType & preconditioner);
+  void
+  ComputeJacobiTypePreconditioner(double & maxJJ, ParametersType & preconditioner);
 
   /** Interpolate the preconditioner, for the non-visited entries. */
   virtual void
@@ -138,9 +126,9 @@ protected:
   using typename Superclass::CoordinateRepresentationType;
   using typename Superclass::NumberOfParametersType;
 
-  double m_MaximumStepLength;
-  double m_RegularizationKappa;
-  double m_ConditionNumber;
+  double m_MaximumStepLength{};
+  double m_RegularizationKappa{};
+  double m_ConditionNumber{};
 };
 
 } // end namespace itk
