@@ -142,8 +142,8 @@ protected:
   void
   GenerateData() override;
 
-  int
-  SplitRequestedRegion(int i, int num, OutputImageRegionType & splitRegion);
+  unsigned int
+  SplitRequestedRegion(unsigned int i, unsigned int num, OutputImageRegionType & splitRegion) override;
 
   void
   ThreadedGenerateData(const OutputImageRegionType & outputRegionForThread, ThreadIdType threadId) override;
@@ -153,14 +153,12 @@ protected:
   void
   EnlargeOutputRequestedRegion(DataObject * output) override;
 
-  bool m_UseImageSpacing;
+  bool m_UseImageSpacing{};
 
 private:
-  RadiusType                      m_Scale;
-  typename TInputImage::PixelType m_Extreme;
+  RadiusType m_Scale{};
 
-  int m_MagnitudeSign;
-  int m_CurrentDimension;
+  int m_CurrentDimension{};
 };
 
 } // end namespace itk
