@@ -111,8 +111,6 @@ public:
   using typename Superclass::GradientPixelType;
   using typename Superclass::GradientImageType;
   using typename Superclass::GradientImagePointer;
-  using typename Superclass::GradientImageFilterType;
-  using typename Superclass::GradientImageFilterPointer;
   using typename Superclass::FixedImageMaskType;
   using typename Superclass::FixedImageMaskPointer;
   using typename Superclass::MovingImageMaskType;
@@ -132,7 +130,6 @@ public:
   using typename Superclass::FixedImageLimiterOutputType;
   using typename Superclass::MovingImageLimiterOutputType;
   using typename Superclass::MovingImageDerivativeScalesType;
-  using typename Superclass::ThreaderType;
   using typename Superclass::ThreadInfoType;
 
   /** The fixed image dimension. */
@@ -166,7 +163,6 @@ protected:
   using typename Superclass::MovingImagePointType;
   using typename Superclass::MovingImageContinuousIndexType;
   using typename Superclass::BSplineInterpolatorType;
-  using typename Superclass::CentralDifferenceGradientFilterType;
   using typename Superclass::MovingImageDerivativeType;
   using typename Superclass::PDFValueType;
   using typename Superclass::PDFDerivativeValueType;
@@ -236,7 +232,7 @@ protected:
   {
     Self * m_Metric;
   };
-  ParzenWindowMutualInformationMultiThreaderParameterType m_ParzenWindowMutualInformationThreaderParameters;
+  ParzenWindowMutualInformationMultiThreaderParameterType m_ParzenWindowMutualInformationThreaderParameters{};
 
   /** Multi-threaded versions of the ComputePDF function. */
   void
@@ -257,11 +253,11 @@ protected:
 private:
   /** Helper array for storing the values of the JointPDF ratios. */
   using PRatioType = double;
-  using PRatioArrayType = Array2D<PRatioType>;
-  mutable PRatioArrayType m_PRatioArray;
+  using PRatioArrayType = vnl_matrix<PRatioType>;
+  mutable PRatioArrayType m_PRatioArray{};
 
   /** Setting */
-  bool m_UseJacobianPreconditioning;
+  bool m_UseJacobianPreconditioning{ false };
 
   /** Helper function to compute the derivative for the low memory variant. */
   void
@@ -272,8 +268,8 @@ private:
 
   /** Helper function to update the derivative for the low memory variant. */
   void
-  UpdateDerivativeLowMemory(const RealType &                   fixedImageValue,
-                            const RealType &                   movingImageValue,
+  UpdateDerivativeLowMemory(const RealType                     fixedImageValue,
+                            const RealType                     movingImageValue,
                             const DerivativeType &             imageJacobian,
                             const NonZeroJacobianIndicesType & nzji,
                             DerivativeType &                   derivative) const;
