@@ -16,8 +16,8 @@
  *
  *=========================================================================*/
 
-#ifndef __itkANNBinaryTreeCreator_h
-#define __itkANNBinaryTreeCreator_h
+#ifndef itkANNBinaryTreeCreator_h
+#define itkANNBinaryTreeCreator_h
 
 #include "itkObject.h"
 #include "itkObjectFactory.h"
@@ -38,27 +38,28 @@ namespace itk
 class ANNBinaryTreeCreator : public Object
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(ANNBinaryTreeCreator);
 
   /** Standard itk. */
-  typedef ANNBinaryTreeCreator       Self;
-  typedef Object                     Superclass;
-  typedef SmartPointer< Self >       Pointer;
-  typedef SmartPointer< const Self > ConstPointer;
+  using Self = ANNBinaryTreeCreator;
+  using Superclass = Object;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** New method for creating an object using a factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** ITK type info. */
-  itkTypeMacro( ANNBinaryTreeCreator, Object );
+  itkTypeMacro(ANNBinaryTreeCreator, Object);
 
   /** ANN typedef's. */
-  //typedef ANNpointSet     ANNTreeBaseType;
-  typedef ANNkd_tree    ANNkDTreeType;
-  typedef ANNbd_tree    ANNbdTreeType;
-  typedef ANNbruteForce ANNBruteForceTreeType;
-  typedef ANNpointArray ANNPointArrayType;
-  typedef ANNsplitRule  ANNSplitRuleType;
-  typedef ANNshrinkRule ANNShrinkRuleType;
+  // typedef ANNpointSet     ANNTreeBaseType;
+  using ANNkDTreeType = ANNkd_tree;
+  using ANNbdTreeType = ANNbd_tree;
+  using ANNBruteForceTreeType = ANNbruteForce;
+  using ANNPointArrayType = ANNpointArray;
+  using ANNSplitRuleType = ANNsplitRule;
+  using ANNShrinkRuleType = ANNshrinkRule;
 
   /** Static funtions to create and delete ANN trees.
    * We keep a reference count so that when no more trees
@@ -68,43 +69,47 @@ public:
    */
 
   /** Static function to create an ANN kDTree. */
-  static ANNkDTreeType * CreateANNkDTree( ANNPointArrayType pa, int n, int d, int bs = 1,
-    ANNSplitRuleType split = ANN_KD_SUGGEST );
+  static ANNkDTreeType *
+  CreateANNkDTree(ANNPointArrayType pa, int n, int d, int bs = 1, ANNSplitRuleType split = ANN_KD_SUGGEST);
 
   /** Static function to create an ANN bdTree. */
-  static ANNbdTreeType * CreateANNbdTree( ANNPointArrayType pa, int n, int d, int bs = 1,
-    ANNSplitRuleType split = ANN_KD_SUGGEST, ANNShrinkRuleType shrink = ANN_BD_SUGGEST );
+  static ANNbdTreeType *
+  CreateANNbdTree(ANNPointArrayType pa,
+                  int               n,
+                  int               d,
+                  int               bs = 1,
+                  ANNSplitRuleType  split = ANN_KD_SUGGEST,
+                  ANNShrinkRuleType shrink = ANN_BD_SUGGEST);
 
   /** Static function to create an ANN BruteForceTree. */
-  static ANNBruteForceTreeType * CreateANNBruteForceTree( ANNPointArrayType pa, int n, int d );
+  static ANNBruteForceTreeType *
+  CreateANNBruteForceTree(ANNPointArrayType pa, int n, int d);
 
   /** Static function to delete any ANN tree that inherits from kDTree (not brute force). */
-  static void DeleteANNkDTree( ANNkDTreeType * & tree );
+  static void
+  DeleteANNkDTree(ANNkDTreeType *& tree);
 
   /** Static function to delete an ANN BruteForceTree. */
-  static void DeleteANNBruteForceTree( ANNBruteForceTreeType * & tree );
+  static void
+  DeleteANNBruteForceTree(ANNBruteForceTreeType *& tree);
 
   /** Static function to increase the reference count to ANN trees. */
-  static void IncreaseReferenceCount( void );
+  static void
+  IncreaseReferenceCount();
 
   /** Static function to decrease the reference count to ANN trees. */
-  static void DecreaseReferenceCount( void );
+  static void
+  DecreaseReferenceCount();
 
 protected:
-
-  ANNBinaryTreeCreator(){}
-  ~ANNBinaryTreeCreator() override{}
+  ANNBinaryTreeCreator() = default;
+  ~ANNBinaryTreeCreator() override = default;
 
 private:
-
-  ANNBinaryTreeCreator( const Self & );   // purposely not implemented
-  void operator=( const Self & );         // purposely not implemented
-
   /** Member variables. */
   static unsigned int m_NumberOfANNBinaryTrees;
-
 };
 
 } // end namespace itk
 
-#endif // end #ifndef __itkANNBinaryTreeCreator_h
+#endif // end #ifndef itkANNBinaryTreeCreator_h
