@@ -15,11 +15,11 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkBinaryANNTreeBase_h
-#define __itkBinaryANNTreeBase_h
+#ifndef itkBinaryANNTreeBase_h
+#define itkBinaryANNTreeBase_h
 
 #include "itkBinaryTreeBase.h"
-#include <ANN/ANN.h>  // ANN declarations
+#include <ANN/ANN.h> // ANN declarations
 
 namespace itk
 {
@@ -33,51 +33,46 @@ namespace itk
  * \ingroup ANNwrap
  */
 
-template< class TListSample >
-class BinaryANNTreeBase : public BinaryTreeBase< TListSample >
+template <class TListSample>
+class ITK_TEMPLATE_EXPORT BinaryANNTreeBase : public BinaryTreeBase<TListSample>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(BinaryANNTreeBase);
 
   /** Standard itk. */
-  typedef BinaryANNTreeBase             Self;
-  typedef BinaryTreeBase< TListSample > Superclass;
-  typedef SmartPointer< Self >          Pointer;
-  typedef SmartPointer< const Self >    ConstPointer;
+  using Self = BinaryANNTreeBase;
+  using Superclass = BinaryTreeBase<TListSample>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** ITK type info. */
-  itkTypeMacro( BinaryANNTreeBase, BinaryTreeBase );
+  itkTypeMacro(BinaryANNTreeBase, BinaryTreeBase);
 
   /** Typedefs from Superclass. */
-  typedef typename Superclass::SampleType                 SampleType;
-  typedef typename Superclass::MeasurementVectorType      MeasurementVectorType;
-  typedef typename Superclass::MeasurementVectorSizeType  MeasurementVectorSizeType;
-  typedef typename Superclass::TotalAbsoluteFrequencyType TotalAbsoluteFrequencyType;
+  using typename Superclass::SampleType;
+  using typename Superclass::MeasurementVectorType;
+  using typename Superclass::MeasurementVectorSizeType;
+  using typename Superclass::TotalAbsoluteFrequencyType;
 
   /** Typedef */
-  typedef ANNpointSet ANNPointSetType;
+  using ANNPointSetType = ANNpointSet;
 
   /** Get the ANN tree. */
-  virtual ANNPointSetType * GetANNTree( void ) const = 0;
+  virtual ANNPointSetType *
+  GetANNTree() const = 0;
 
 protected:
-
   /** Constructor. */
-  BinaryANNTreeBase();
+  BinaryANNTreeBase() = default;
 
   /** Destructor. */
-  ~BinaryANNTreeBase() override {}
-
-private:
-
-  BinaryANNTreeBase( const Self & );  // purposely not implemented
-  void operator=( const Self & );     // purposely not implemented
-
+  ~BinaryANNTreeBase() override = default;
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkBinaryANNTreeBase.hxx"
+#  include "itkBinaryANNTreeBase.hxx"
 #endif
 
-#endif // end #ifndef __itkBinaryANNTreeBase_h
+#endif // end #ifndef itkBinaryANNTreeBase_h
