@@ -109,8 +109,6 @@ public:
   using typename Superclass::GradientPixelType;
   using typename Superclass::GradientImageType;
   using typename Superclass::GradientImagePointer;
-  using typename Superclass::GradientImageFilterType;
-  using typename Superclass::GradientImageFilterPointer;
   using typename Superclass::FixedImageMaskType;
   using typename Superclass::FixedImageMaskPointer;
   using typename Superclass::MovingImageMaskType;
@@ -166,7 +164,7 @@ public:
   using IndexArrayType = typename BinaryKNNTreeSearchType::IndexArrayType;
   using DistanceArrayType = typename BinaryKNNTreeSearchType::DistanceArrayType;
 
-  using DerivativeValueType = typename DerivativeType::ValueType;
+  using typename Superclass::DerivativeValueType;
   using TransformJacobianValueType = typename TransformJacobianType::ValueType;
 
   /**
@@ -266,16 +264,16 @@ protected:
   PrintSelf(std::ostream & os, Indent indent) const override;
 
   /** Member variables. */
-  BinaryKNNTreePointer m_BinaryKNNTreeFixed;
-  BinaryKNNTreePointer m_BinaryKNNTreeMoving;
-  BinaryKNNTreePointer m_BinaryKNNTreeJoint;
+  BinaryKNNTreePointer m_BinaryKNNTreeFixed{ nullptr };
+  BinaryKNNTreePointer m_BinaryKNNTreeMoving{ nullptr };
+  BinaryKNNTreePointer m_BinaryKNNTreeJoint{ nullptr };
 
-  BinaryKNNTreeSearchPointer m_BinaryKNNTreeSearcherFixed;
-  BinaryKNNTreeSearchPointer m_BinaryKNNTreeSearcherMoving;
-  BinaryKNNTreeSearchPointer m_BinaryKNNTreeSearcherJoint;
+  BinaryKNNTreeSearchPointer m_BinaryKNNTreeSearcherFixed{ nullptr };
+  BinaryKNNTreeSearchPointer m_BinaryKNNTreeSearcherMoving{ nullptr };
+  BinaryKNNTreeSearchPointer m_BinaryKNNTreeSearcherJoint{ nullptr };
 
-  double m_Alpha;
-  double m_AvoidDivisionBy;
+  double m_Alpha{ 0.99 };
+  double m_AvoidDivisionBy{ 1e-10 };
 
 private:
   /** Typedef's for the computation of the derivative. */
@@ -286,7 +284,7 @@ private:
   using TransformJacobianContainerType = std::vector<TransformJacobianType>;
   // typedef std::vector<ParameterIndexArrayType>           TransformJacobianIndicesContainerType;
   using TransformJacobianIndicesContainerType = std::vector<NonZeroJacobianIndicesType>;
-  using SpatialDerivativeType = Array2D<double>;
+  using SpatialDerivativeType = vnl_matrix<double>;
   using SpatialDerivativeContainerType = std::vector<SpatialDerivativeType>;
 
   /** This function takes the fixed image samples from the ImageSampler
