@@ -153,7 +153,7 @@ public:
   SetTransformParameters(const TransformParametersType & parameters) const;
 
 protected:
-  NormalizedGradientCorrelationImageToImageMetric();
+  NormalizedGradientCorrelationImageToImageMetric() = default;
   ~NormalizedGradientCorrelationImageToImageMetric() override = default;
   void
   PrintSelf(std::ostream & os, Indent indent) const override;
@@ -173,34 +173,34 @@ protected:
   using MovedSobelFilter = NeighborhoodOperatorImageFilter<MovedGradientImageType, MovedGradientImageType>;
 
 private:
-  ScalesType                  m_Scales;
-  double                      m_DerivativeDelta;
-  CombinationTransformPointer m_CombinationTransform;
+  ScalesType                  m_Scales{};
+  double                      m_DerivativeDelta{ 0.001 };
+  CombinationTransformPointer m_CombinationTransform{ CombinationTransformType::New() };
 
   /** The mean of the moving image gradients. */
-  mutable MovedGradientPixelType m_MeanMovedGradient[MovedImageDimension];
+  mutable MovedGradientPixelType m_MeanMovedGradient[MovedImageDimension]{};
 
   /** The mean of the fixed image gradients. */
-  mutable FixedGradientPixelType m_MeanFixedGradient[FixedImageDimension];
+  mutable FixedGradientPixelType m_MeanFixedGradient[FixedImageDimension]{};
 
   /** The filter for transforming the moving images. */
-  TransformMovingImageFilterPointer m_TransformMovingImageFilter;
+  TransformMovingImageFilterPointer m_TransformMovingImageFilter{ TransformMovingImageFilterType::New() };
 
   /** The Sobel gradients of the fixed image */
-  CastFixedImageFilterPointer m_CastFixedImageFilter;
+  CastFixedImageFilterPointer m_CastFixedImageFilter{ CastFixedImageFilterType::New() };
 
-  SobelOperator<FixedGradientPixelType, Self::FixedImageDimension> m_FixedSobelOperators[FixedImageDimension];
+  SobelOperator<FixedGradientPixelType, Self::FixedImageDimension> m_FixedSobelOperators[FixedImageDimension]{};
 
-  typename FixedSobelFilter::Pointer m_FixedSobelFilters[Self::FixedImageDimension];
+  typename FixedSobelFilter::Pointer m_FixedSobelFilters[Self::FixedImageDimension]{};
 
-  ZeroFluxNeumannBoundaryCondition<MovedGradientImageType> m_MovedBoundCond;
-  ZeroFluxNeumannBoundaryCondition<FixedGradientImageType> m_FixedBoundCond;
+  ZeroFluxNeumannBoundaryCondition<MovedGradientImageType> m_MovedBoundCond{};
+  ZeroFluxNeumannBoundaryCondition<FixedGradientImageType> m_FixedBoundCond{};
 
   /** The Sobel gradients of the moving image */
-  CastMovedImageFilterPointer                                      m_CastMovedImageFilter;
-  SobelOperator<MovedGradientPixelType, Self::MovedImageDimension> m_MovedSobelOperators[MovedImageDimension];
+  CastMovedImageFilterPointer m_CastMovedImageFilter{ CastMovedImageFilterType::New() };
+  SobelOperator<MovedGradientPixelType, Self::MovedImageDimension> m_MovedSobelOperators[MovedImageDimension]{};
 
-  typename MovedSobelFilter::Pointer m_MovedSobelFilters[Self::MovedImageDimension];
+  typename MovedSobelFilter::Pointer m_MovedSobelFilters[Self::MovedImageDimension]{};
 };
 
 } // end namespace itk
