@@ -75,7 +75,7 @@ public:
   itkSetMacro(NumSamplesLastDimension, unsigned int);
   itkSetMacro(NumAdditionalSamplesFixed, unsigned int);
   itkSetMacro(ReducedDimensionIndex, unsigned int);
-  itkSetMacro(SubtractMean, bool);
+  itkSetMacro(UseZeroAverageDisplacementConstraint, bool);
   itkSetMacro(GridSize, FixedImageSizeType);
   itkSetMacro(TransformIsStackTransform, bool);
 
@@ -102,14 +102,13 @@ public:
   using typename Superclass::GradientPixelType;
   using typename Superclass::GradientImageType;
   using typename Superclass::GradientImagePointer;
-  using typename Superclass::GradientImageFilterType;
-  using typename Superclass::GradientImageFilterPointer;
   using typename Superclass::FixedImageMaskType;
   using typename Superclass::FixedImageMaskPointer;
   using typename Superclass::MovingImageMaskType;
   using typename Superclass::MovingImageMaskPointer;
   using typename Superclass::MeasureType;
   using typename Superclass::DerivativeType;
+  using typename Superclass::DerivativeValueType;
   using typename Superclass::ParametersType;
   using typename Superclass::FixedImagePixelType;
   using typename Superclass::MovingImageRegionType;
@@ -167,7 +166,6 @@ protected:
   using typename Superclass::MovingImagePointType;
   using typename Superclass::MovingImageContinuousIndexType;
   using typename Superclass::BSplineInterpolatorType;
-  using typename Superclass::CentralDifferenceGradientFilterType;
   using typename Superclass::MovingImageDerivativeType;
   using typename Superclass::NonZeroJacobianIndicesType;
 
@@ -187,17 +185,17 @@ private:
   /** Variables to control random sampling in last dimension. */
   bool         m_SampleLastDimensionRandomly{ false };
   unsigned int m_NumSamplesLastDimension{ 10 };
-  unsigned int m_NumAdditionalSamplesFixed;
-  unsigned int m_ReducedDimensionIndex;
+  unsigned int m_NumAdditionalSamplesFixed{};
+  unsigned int m_ReducedDimensionIndex{};
 
   /** Bool to determine if we want to subtract the mean derivate from the derivative elements. */
-  bool m_SubtractMean{ false };
+  bool m_UseZeroAverageDisplacementConstraint{ true };
 
   /** Initial variance in last dimension, used as normalization factor. */
-  float m_InitialVariance;
+  float m_InitialVariance{};
 
   /** GridSize of B-spline transform. */
-  FixedImageSizeType m_GridSize;
+  FixedImageSizeType m_GridSize{};
 
   /** Bool to indicate if the transform used is a stacktransform. Set by elx files. */
   bool m_TransformIsStackTransform{ false };
