@@ -66,7 +66,7 @@ namespace elastix
  * [3] Y. Qiao, B. van Lew, B.P.F. Lelieveldt and M. Staring
  * "Fast Automatic Step Size Estimation for Gradient Descent Optimization of Image Registration,"
  * IEEE Transactions on Medical Imaging, vol. 35, no. 2, pp. 391 - 403, February 2016.
- * http://elastix.lumc.nl/marius/publications/2016_j_TMIa.php
+ * http://elastix.dev/marius/publications/2016_j_TMIa.php
  *
  * The parameters used in this class are:
  * \parameter Optimizer: Select this optimizer as follows:\n
@@ -305,11 +305,8 @@ protected:
   using TransformType = typename itkRegistrationType::TransformType;
   using JacobianType = typename TransformType::JacobianType;
   using JacobianValueType = typename JacobianType::ValueType;
-  struct SettingsType
-  {
-    double a, A, alpha, fmax, fmin, omega;
-  };
-  using SettingsVectorType = typename std::vector<SettingsType>;
+  using typename Superclass2::SettingsType;
+  using typename Superclass2::SettingsVectorType;
   using OutputImageType = typename ElastixType::FixedImageType;
 
   using PreconditionerEstimationType =
@@ -336,8 +333,6 @@ protected:
   /** Other protected typedefs */
   using RandomGeneratorType = itk::Statistics::MersenneTwisterRandomVariateGenerator;
   using RandomGeneratorPointer = typename RandomGeneratorType::Pointer;
-  using ProgressCommandType = ProgressCommand;
-  using ProgressCommandPointer = typename ProgressCommand::Pointer;
 
   /** Typedefs for support of sparse Jacobians and AdvancedTransforms. */
   using TransformJacobianType = JacobianType;
@@ -376,10 +371,6 @@ protected:
   double m_RegularizationKappa;
   double m_ConditionNumber;
 
-  /** Print the contents of the settings vector to elxout. */
-  virtual void
-  PrintSettingsVector(const SettingsVectorType & settings) const;
-
   /** Select different method to estimate some reasonable values for the parameters
    * SP_a, SP_alpha (=1), SigmoidMin, SigmoidMax (=1), and
    * SigmoidScale.
