@@ -63,7 +63,7 @@ namespace elastix
  * [3] Y. Qiao, B. van Lew, B.P.F. Lelieveldt and M. Staring
  * "Fast Automatic Step Size Estimation for Gradient Descent Optimization of Image Registration,"
  * IEEE Transactions on Medical Imaging, vol. 35, no. 2, pp. 391 - 403, February 2016.
- * http://elastix.lumc.nl/marius/publications/2016_j_TMIa.php
+ * http://elastix.dev/marius/publications/2016_j_TMIa.php
  *
  * The parameters used in this class are:
  * \parameter Optimizer: Select this optimizer as follows:\n
@@ -300,12 +300,8 @@ protected:
   using JacobianType = typename TransformType::JacobianType;
   using ComputeJacobianTermsType = itk::ComputeJacobianTerms<FixedImageType, TransformType>;
   using JacobianValueType = typename JacobianType::ValueType;
-  struct SettingsType
-  {
-    double a, A, alpha, fmax, fmin, omega;
-  };
-  using SettingsVectorType = typename std::vector<SettingsType>;
-
+  using typename Superclass2::SettingsType;
+  using typename Superclass2::SettingsVectorType;
   using ComputeDisplacementDistributionType = itk::ComputeDisplacementDistribution<FixedImageType, TransformType>;
 
   /** Samplers: */
@@ -323,8 +319,6 @@ protected:
   /** Other protected typedefs */
   using RandomGeneratorType = itk::Statistics::MersenneTwisterRandomVariateGenerator;
   using RandomGeneratorPointer = typename RandomGeneratorType::Pointer;
-  using ProgressCommandType = ProgressCommand;
-  using ProgressCommandPointer = typename ProgressCommand::Pointer;
 
   /** Typedefs for support of sparse Jacobians and AdvancedTransforms. */
   using TransformJacobianType = JacobianType;
@@ -355,10 +349,6 @@ protected:
 
   double m_SigmoidScaleFactor;
 
-  /** Print the contents of the settings vector to elxout. */
-  virtual void
-  PrintSettingsVector(const SettingsVectorType & settings) const;
-
   /** Select different method to estimate some reasonable values for the parameters
    * SP_a, SP_alpha (=1), SigmoidMin, SigmoidMax (=1), and
    * SigmoidScale.
