@@ -26,7 +26,7 @@
 #include "itkMersenneTwisterRandomVariateGenerator.h"
 #include "itkComputeJacobianTerms.h"
 #include "itkComputeDisplacementDistribution.h"
-#include "itkPlatformMultiThreader.h"
+#include "itkMultiThreaderBase.h"
 #include "itkImageRandomSampler.h"
 #include "itkLineSearchOptimizer.h"
 #include "itkMoreThuenteLineSearchOptimizer.h"
@@ -243,12 +243,8 @@ protected:
   using JacobianType = typename TransformType::JacobianType;
   using ComputeJacobianTermsType = itk::ComputeJacobianTerms<FixedImageType, TransformType>;
   using JacobianValueType = typename JacobianType::ValueType;
-  struct SettingsType
-  {
-    double a, A, alpha, fmax, fmin, omega;
-  };
-  using SettingsVectorType = typename std::vector<SettingsType>;
-
+  using typename Superclass2::SettingsType;
+  using typename Superclass2::SettingsVectorType;
   using ComputeDisplacementDistributionType = itk::ComputeDisplacementDistribution<FixedImageType, TransformType>;
 
   /** Samplers: */
@@ -272,10 +268,8 @@ protected:
   using ImageSampleContainerType = typename ImageGridSamplerType::ImageSampleContainerType;
   using ImageSampleContainerPointer = typename ImageSampleContainerType::Pointer;
 
-  /** Other protected typedefs */
+  /** Other protected typedef */
   using RandomGeneratorType = itk::Statistics::MersenneTwisterRandomVariateGenerator;
-  using ProgressCommandType = ProgressCommand;
-  using ProgressCommandPointer = typename ProgressCommand::Pointer;
 
   /** Typedefs for support of sparse Jacobians and AdvancedTransforms. */
   using TransformJacobianType = JacobianType;
@@ -311,10 +305,6 @@ protected:
 
   double m_SigmoidScaleFactor;
 
-  /** Print the contents of the settings vector to elxout. */
-  virtual void
-  PrintSettingsVector(const SettingsVectorType & settings) const;
-
   /** Select different method to estimate some reasonable values for the parameters
    * SP_a, SP_alpha (=1), SigmoidMin, SigmoidMax (=1), and
    * SigmoidScale.
