@@ -106,7 +106,7 @@ CMAEvolutionStrategyOptimizer::StartOptimization()
   itkDebugMacro("StartOptimization");
 
   /** Reset some variables */
-  this->m_CurrentValue = NumericTraits<MeasureType>::Zero;
+  this->m_CurrentValue = MeasureType{};
   this->m_CurrentIteration = 0;
   this->m_Stop = false;
   this->m_StopCondition = Unknown;
@@ -292,7 +292,7 @@ CMAEvolutionStrategyOptimizer::InitializeConstants()
   this->m_EffectiveMu = 1.0 / this->m_RecombinationWeights.squared_magnitude();
   if (this->m_EffectiveMu >= lambdad)
   {
-    itkExceptionMacro(<< "The RecombinationWeights have unreasonable values!");
+    itkExceptionMacro("The RecombinationWeights have unreasonable values!");
   }
   /** alias: */
   const double mueff = this->m_EffectiveMu;
@@ -420,13 +420,13 @@ CMAEvolutionStrategyOptimizer::InitializeBCD()
     const unsigned int N = numberOfParameters;
 
     /** Resize */
-    this->m_B.SetSize(N, N);
-    this->m_C.SetSize(N, N);
+    this->m_B.set_size(N, N);
+    this->m_C.set_size(N, N);
     this->m_D.set_size(N);
 
     /** Initialize */
-    this->m_B.Fill(0.0);
-    this->m_C.Fill(0.0);
+    this->m_B.fill(0.0);
+    this->m_C.fill(0.0);
     this->m_B.fill_diagonal(1.0);
     this->m_C.fill_diagonal(1.0);
     this->m_D.fill(1.0);
@@ -434,8 +434,8 @@ CMAEvolutionStrategyOptimizer::InitializeBCD()
   else
   {
     /** Clear */
-    this->m_B.SetSize(0, 0);
-    this->m_C.SetSize(0, 0);
+    this->m_B.set_size(0, 0);
+    this->m_C.set_size(0, 0);
     this->m_D.clear();
   }
 
@@ -801,7 +801,7 @@ CMAEvolutionStrategyOptimizer::UpdateBD()
   returncode = eigenAnalysis.ComputeEigenValuesAndVectors(this->m_C, this->m_D, this->m_B);
   if (returncode != 0)
   {
-    itkExceptionMacro(<< "EigenAnalysis failed while computing eigenvalue nr: " << returncode);
+    itkExceptionMacro("EigenAnalysis failed while computing eigenvalue nr: " << returncode);
   }
 
   /** itk eigen analysis returns eigen vectors in rows... */
