@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxPowell_h
-#define __elxPowell_h
+#ifndef elxPowell_h
+#define elxPowell_h
 
 #include "elxIncludes.h" // include first to avoid MSVS warning
 #include "itkPowellOptimizer.h"
@@ -37,84 +37,81 @@ namespace elastix
  * \ingroup Optimizers
  */
 
-template< class TElastix >
-class Powell :
-  public
-  itk::PowellOptimizer,
-  public
-  OptimizerBase< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT Powell
+  : public itk::PowellOptimizer
+  , public OptimizerBase<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(Powell);
 
   /** Standard ITK.*/
-  typedef Powell                          Self;
-  typedef PowellOptimizer                 Superclass1;
-  typedef OptimizerBase< TElastix >       Superclass2;
-  typedef itk::SmartPointer< Self >       Pointer;
-  typedef itk::SmartPointer< const Self > ConstPointer;
+  using Self = Powell;
+  using Superclass1 = PowellOptimizer;
+  using Superclass2 = OptimizerBase<TElastix>;
+  using Pointer = itk::SmartPointer<Self>;
+  using ConstPointer = itk::SmartPointer<const Self>;
 
   /** Method for creation through the object factory. */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( Powell, PowellOptimizer );
+  itkTypeMacro(Powell, PowellOptimizer);
 
   /** Name of this class.
    * Use this name in the parameter file to select this specific optimizer. \n
    * example: <tt>(Optimizer "Powell")</tt>\n
    */
-  elxClassNameMacro( "Powell" );
+  elxClassNameMacro("Powell");
 
   /** Typedef's inherited from Superclass1.*/
-  typedef Superclass1::CostFunctionType    CostFunctionType;
-  typedef Superclass1::CostFunctionPointer CostFunctionPointer;
+  using Superclass1::CostFunctionType;
+  using Superclass1::CostFunctionPointer;
 
   /** Typedef's inherited from Elastix.*/
-  typedef typename Superclass2::ElastixType          ElastixType;
-  typedef typename Superclass2::ElastixPointer       ElastixPointer;
-  typedef typename Superclass2::ConfigurationType    ConfigurationType;
-  typedef typename Superclass2::ConfigurationPointer ConfigurationPointer;
-  typedef typename Superclass2::RegistrationType     RegistrationType;
-  typedef typename Superclass2::RegistrationPointer  RegistrationPointer;
-  typedef typename Superclass2::ITKBaseType          ITKBaseType;
+  using typename Superclass2::ElastixType;
+  using typename Superclass2::RegistrationType;
+  using ITKBaseType = typename Superclass2::ITKBaseType;
 
   /** Typedef for the ParametersType. */
-  typedef typename Superclass1::ParametersType ParametersType;
+  using typename Superclass1::ParametersType;
 
   /** Methods invoked by elastix, in which parameters can be set and
    * progress information can be printed. */
-  void BeforeRegistration( void ) override;
+  void
+  BeforeRegistration() override;
 
-  void BeforeEachResolution( void ) override;
+  void
+  BeforeEachResolution() override;
 
-  void AfterEachResolution( void ) override;
+  void
+  AfterEachResolution() override;
 
-  void AfterEachIteration( void ) override;
+  void
+  AfterEachIteration() override;
 
-  void AfterRegistration( void ) override;
+  void
+  AfterRegistration() override;
 
   /** Override the SetInitialPosition.
    * Override the implementation in itkOptimizer.h, to
    * ensure that the scales array and the parameters
    * array have the same size. */
-  void SetInitialPosition( const ParametersType & param ) override;
+  void
+  SetInitialPosition(const ParametersType & param) override;
 
 protected:
-
-  Powell(){}
-  ~Powell() override {}
+  Powell() = default;
+  ~Powell() override = default;
 
 private:
-
-  Powell( const Self & );         // purposely not implemented
-  void operator=( const Self & ); // purposely not implemented
-
+  elxOverrideGetSelfMacro;
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxPowell.hxx"
+#  include "elxPowell.hxx"
 #endif
 
-#endif // end #ifndef __elxPowell_h
+#endif // end #ifndef elxPowell_h
