@@ -131,9 +131,9 @@ protected:
   UpdateCurrentTime() override;
 
   /** The PreviousGradient, necessary for the CruzAcceleration */
-  DerivativeType m_PreviousSearchDirection;
-  ParametersType m_PreconditionVector;
-  std::string    m_StepSizeStrategy;
+  DerivativeType m_PreviousSearchDirection{};
+  ParametersType m_PreconditionVector{};
+  std::string    m_StepSizeStrategy{};
 
 private:
   /** Settings */
