@@ -83,7 +83,7 @@ public:
 
   using LineSearchOptimizerPointer = LineSearchOptimizerType::Pointer;
 
-  enum StopConditionType
+  enum class StopConditionType
   {
     MetricError,
     LineSearchError,
@@ -139,22 +139,22 @@ protected:
 
   // \todo: should be implemented
   void
-  PrintSelf(std::ostream & os, Indent indent) const override
+  PrintSelf(std::ostream &, Indent) const override
   {}
 
-  DerivativeType    m_CurrentGradient;
+  DerivativeType    m_CurrentGradient{};
   MeasureType       m_CurrentValue{ 0.0 };
   unsigned long     m_CurrentIteration{ 0 };
-  StopConditionType m_StopCondition{ Unknown };
+  StopConditionType m_StopCondition{ StopConditionType::Unknown };
   bool              m_Stop{ false };
   double            m_CurrentStepLength{ 0.0 };
 
   /** Is true when the LineSearchOptimizer has been started. */
   bool m_InLineSearch{ false };
 
-  RhoType m_Rho;
-  SType   m_S;
-  YType   m_Y;
+  RhoType m_Rho{};
+  SType   m_S{};
+  YType   m_Y{};
 
   unsigned int m_Point{ 0 };
   unsigned int m_PreviousPoint{ 0 };
