@@ -21,15 +21,14 @@
 #include "itkEventObject.h"
 #include "itkMacro.h"
 
-#ifdef ELASTIX_USE_OPENMP
-#  include <omp.h>
-#endif
-
 #ifdef ELASTIX_USE_EIGEN
 #  include <Eigen/Dense>
 #  include <Eigen/Core>
 #endif
 
+#include <algorithm> // For min.
+#include <cassert>
+
 namespace itk
 {
 
@@ -107,7 +106,7 @@ StochasticGradientDescentOptimizer::ResumeOptimization()
   this->m_PreviousPosition = this->GetPreviousPosition();
 
   const unsigned int spaceDimension = this->GetScaledCostFunction()->GetNumberOfParameters();
-  this->m_Gradient = DerivativeType(spaceDimension); // check this
+  this->m_Gradient.set_size(spaceDimension); // check this
 
   DerivativeType currentPositionGradient;
   DerivativeType previousPositionGradient;
@@ -200,95 +199,14 @@ StochasticGradientDescentOptimizer::AdvanceOneStep()
   ParametersType & newPosition = this->m_ScaledCurrentPosition;
 
   /** Advance one step. */
-  // single-threadedly
-  if (!this->m_UseMultiThread || true) // for now force single-threaded since it is fastest most of the times
-  // if( !this->m_UseMultiThread && false ) // force multi-threaded
+  // for now force single-threaded since it is fastest most of the times
+  /** Get a reference to the current position. */
+  const ParametersType & currentPosition = this->GetScaledCurrentPosition();
+
+  /** Update the new position. */
+  for (unsigned int j = 0; j < spaceDimension; ++j)
   {
-    /** Get a reference to the current position. */
-    const ParametersType & currentPosition = this->GetScaledCurrentPosition();
-
-    /** Update the new position. */
-    for (unsigned int j = 0; j < spaceDimension; ++j)
-    {
-      newPosition[j] = currentPosition[j] - this->m_LearningRate * this->m_Gradient[j];
-    }
-  }
-#ifdef ELASTIX_USE_OPENMP
-  else if (this->m_UseOpenMP && !this->m_UseEigen)
-  {
-    /** Get a reference to the current position. */
-    const ParametersType & currentPosition = this->GetScaledCurrentPosition();
-
-    /** Update the new position. */
-    const int nthreads = static_cast<int>(this->m_Threader->GetNumberOfWorkUnits());
-    omp_set_num_threads(nthreads);
-#  pragma omp parallel for
-    for (int j = 0; j < static_cast<int>(spaceDimension); ++j)
-    {
-      newPosition[j] = currentPosition[j] - this->m_LearningRate * this->m_Gradient[j];
-    }
-  }
-#endif
-#ifdef ELASTIX_USE_EIGEN
-  else if (!this->m_UseOpenMP && this->m_UseEigen)
-  {
-    /** Get a reference to the current position. */
-    const ParametersType & currentPosition = this->GetScaledCurrentPosition();
-    const double           learningRate = this->m_LearningRate;
-
-    /** Wrap itk::Arrays into Eigen jackets. */
-    using ParametersTypeEigen = Eigen::VectorXd;
-    Eigen::Map<ParametersTypeEigen>       newPositionE(newPosition.data_block(), spaceDimension);
-    Eigen::Map<const ParametersTypeEigen> currentPositionE(currentPosition.data_block(), spaceDimension);
-    Eigen::Map<ParametersTypeEigen>       gradientE(this->m_Gradient.data_block(), spaceDimension);
-
-    /** Update the new position. */
-    newPositionE = currentPositionE - learningRate * gradientE;
-  }
-#endif
-#if defined(ELASTIX_USE_OPENMP) && defined(ELASTIX_USE_EIGEN)
-  else if (this->m_UseOpenMP && this->m_UseEigen)
-  {
-    /** Get a reference to the current position. */
-    const ParametersType & currentPosition = this->GetScaledCurrentPosition();
-    const double           learningRate = this->m_LearningRate;
-
-    /** Wrap itk::Arrays into Eigen jackets. */
-    using ParametersTypeEigen = Eigen::VectorXd;
-    Eigen::Map<ParametersTypeEigen>       newPositionE(newPosition.data_block(), spaceDimension);
-    Eigen::Map<const ParametersTypeEigen> currentPositionE(currentPosition.data_block(), spaceDimension);
-    Eigen::Map<ParametersTypeEigen>       gradientE(this->m_Gradient.data_block(), spaceDimension);
-
-    /** Update the new position. */
-    const int spaceDim = static_cast<int>(spaceDimension);
-    const int nthreads = static_cast<int>(this->m_Threader->GetNumberOfWorkUnits());
-    omp_set_num_threads(nthreads);
-#  pragma omp parallel for
-    for (int i = 0; i < nthreads; i += 1)
-    {
-      int threadId = omp_get_thread_num();
-      int chunk = (spaceDimension + nthreads - 1) / nthreads;
-      int jmin = threadId * chunk;
-      int jmax = (threadId + 1) * chunk < spaceDim ? (threadId + 1) * chunk : spaceDim;
-      int subSize = jmax - jmin;
-
-      newPositionE.segment(jmin, subSize) =
-        currentPositionE.segment(jmin, subSize) - learningRate * gradientE.segment(jmin, subSize);
-    }
-  }
-#endif
-  else
-  {
-    /** Fill the threader parameter struct with information. */
-    MultiThreaderParameterType temp;
-    temp.t_NewPosition = &newPosition;
-    temp.t_Optimizer = this;
-
-    /** Call multi-threaded AdvanceOneStep(). */
-    auto local_threader = ThreaderType::New();
-    local_threader->SetNumberOfWorkUnits(this->m_Threader->GetNumberOfWorkUnits());
-    local_threader->SetSingleMethod(AdvanceOneStepThreaderCallback, &temp);
-    local_threader->SingleMethodExecute();
+    newPosition[j] = currentPosition[j] - this->m_LearningRate * this->m_Gradient[j];
   }
 
   this->InvokeEvent(IterationEvent());
@@ -304,14 +222,17 @@ ITK_THREAD_RETURN_FUNCTION_CALL_CONVENTION
 StochasticGradientDescentOptimizer::AdvanceOneStepThreaderCallback(void * arg)
 {
   /** Get the current thread id and user data. */
-  ThreadInfoType *             infoStruct = static_cast<ThreadInfoType *>(arg);
-  ThreadIdType                 threadID = infoStruct->WorkUnitID;
-  MultiThreaderParameterType * temp = static_cast<MultiThreaderParameterType *>(infoStruct->UserData);
+  assert(arg);
+  const auto & infoStruct = *static_cast<ThreadInfoType *>(arg);
+  ThreadIdType threadID = infoStruct.WorkUnitID;
+
+  assert(infoStruct.UserData);
+  const auto & userData = *static_cast<MultiThreaderParameterType *>(infoStruct.UserData);
 
   /** Call the real implementation. */
-  temp->t_Optimizer->ThreadedAdvanceOneStep(threadID, *(temp->t_NewPosition));
+  userData.t_Optimizer->ThreadedAdvanceOneStep(threadID, *(userData.t_NewPosition));
 
-  return itk::ITK_THREAD_RETURN_DEFAULT_VALUE;
+  return ITK_THREAD_RETURN_DEFAULT_VALUE;
 
 } // end AdvanceOneStepThreaderCallback()
 
@@ -328,8 +249,7 @@ StochasticGradientDescentOptimizer::ThreadedAdvanceOneStep(ThreadIdType threadId
   const unsigned int subSize = static_cast<unsigned int>(
     std::ceil(static_cast<double>(spaceDimension) / static_cast<double>(this->m_Threader->GetNumberOfWorkUnits())));
   const unsigned int jmin = threadId * subSize;
-  unsigned int       jmax = (threadId + 1) * subSize;
-  jmax = (jmax > spaceDimension) ? spaceDimension : jmax;
+  const unsigned int jmax = std::min((threadId + 1) * subSize, spaceDimension);
 
   /** Get a reference to the current position. */
   const ParametersType & currentPosition = this->GetScaledCurrentPosition();
