@@ -19,7 +19,7 @@
 #define itkStochasticGradientDescentOptimizer_h
 
 #include "itkScaledSingleValuedNonLinearOptimizer.h"
-#include "itkPlatformMultiThreader.h"
+#include "itkMultiThreaderBase.h"
 
 namespace itk
 {
@@ -167,8 +167,6 @@ public:
   }
   // itkGetConstReferenceMacro( NumberOfThreads, ThreadIdType );
   itkSetMacro(UseMultiThread, bool);
-
-  itkSetMacro(UseOpenMP, bool);
   itkSetMacro(UseEigen, bool);
 
 protected:
@@ -177,29 +175,28 @@ protected:
   void
   PrintSelf(std::ostream & os, Indent indent) const override;
 
-  /** Typedefs for multi-threading. */
-  using ThreaderType = itk::PlatformMultiThreader;
-  using ThreadInfoType = ThreaderType::WorkUnitInfo;
+  /** Typedef for multi-threading. */
+  using ThreadInfoType = MultiThreaderBase::WorkUnitInfo;
 
   // made protected so subclass can access
-  double                m_Value{ 0.0 };
-  DerivativeType        m_Gradient;
-  ParametersType        m_SearchDir;
-  ParametersType        m_PreviousSearchDir;
-  ParametersType        m_PrePreviousSearchDir;
-  ParametersType        m_MeanSearchDir;
-  double                m_LearningRate{ 1.0 };
-  StopConditionType     m_StopCondition{ MaximumNumberOfIterations };
-  DerivativeType        m_PreviousGradient;
-  DerivativeType        m_PrePreviousGradient;
-  ParametersType        m_PreviousPosition;
-  ThreaderType::Pointer m_Threader{ ThreaderType::New() };
+  double                     m_Value{ 0.0 };
+  DerivativeType             m_Gradient{};
+  ParametersType             m_SearchDir{};
+  ParametersType             m_PreviousSearchDir{};
+  ParametersType             m_PrePreviousSearchDir{};
+  ParametersType             m_MeanSearchDir{};
+  double                     m_LearningRate{ 1.0 };
+  StopConditionType          m_StopCondition{ MaximumNumberOfIterations };
+  DerivativeType             m_PreviousGradient{};
+  DerivativeType             m_PrePreviousGradient{};
+  ParametersType             m_PreviousPosition{};
+  MultiThreaderBase::Pointer m_Threader{ MultiThreaderBase::New() };
 
   bool          m_Stop{ false };
   unsigned long m_NumberOfIterations{ 100 };
-  unsigned long m_NumberOfInnerIterations;
+  unsigned long m_NumberOfInnerIterations{};
   unsigned long m_CurrentIteration{ 0 };
-  unsigned long m_CurrentInnerIteration;
+  unsigned long m_CurrentInnerIteration{};
   unsigned long m_LBFGSMemory{ 0 };
 
 private:
@@ -211,7 +208,6 @@ private:
     Self *           t_Optimizer;
   };
 
-  bool m_UseOpenMP{ false };
   bool m_UseEigen{ false };
 
   /** The callback function. */
