@@ -99,8 +99,6 @@ public:
   using typename Superclass::GradientPixelType;
   using typename Superclass::GradientImageType;
   using typename Superclass::GradientImagePointer;
-  using typename Superclass::GradientImageFilterType;
-  using typename Superclass::GradientImageFilterPointer;
   using typename Superclass::FixedImageMaskType;
   using typename Superclass::FixedImageMaskPointer;
   using typename Superclass::MovingImageMaskType;
@@ -110,10 +108,6 @@ public:
   using typename Superclass::DerivativeValueType;
   using typename Superclass::ParametersType;
 
-  /** Some typedefs for computing the SelfHessian */
-  using typename Superclass::HessianValueType;
-  using typename Superclass::HessianType;
-
   /**
   using typename Superclass::ImageSamplerType;
   using typename Superclass::ImageSamplerPointer;
@@ -156,8 +150,7 @@ public:
                                                               CoordinateRepresentationType>>;
   using PointSetMetricType = SingleValuedPointSetToPointSetMetric<FixedPointSetType, MovingPointSetType>;
 
-  /** Typedefs for multi-threading. */
-  using typename Superclass::ThreaderType;
+  /** Typedef for multi-threading. */
   using typename Superclass::ThreadInfoType;
 
   /**
@@ -261,7 +254,15 @@ public:
   virtual const TransformType *
   GetTransform(unsigned int pos) const;
 
-  /** Return Transform 0 */
+  /** Get the first transform. */
+  TransformType *
+  GetTransform() override
+  {
+    const auto metric = dynamic_cast<ImageMetricType *>(this->GetMetric(0));
+    return metric ? metric->GetTransform() : nullptr;
+  }
+
+  /** Get the first transform. Const overload. */
   const TransformType *
   GetTransform() const override
   {
@@ -283,7 +284,15 @@ public:
   virtual const InterpolatorType *
   GetInterpolator(unsigned int pos) const;
 
-  /** Return Interpolator 0 */
+  /** Get the first interpolator. */
+  InterpolatorType *
+  GetInterpolator() override
+  {
+    const auto metric = dynamic_cast<ImageMetricType *>(this->GetMetric(0));
+    return metric ? metric->GetInterpolator() : nullptr;
+  }
+
+  /** Get the first interpolator. Const overload. */
   const InterpolatorType *
   GetInterpolator() const override
   {
@@ -315,11 +324,11 @@ public:
 
   /** Pass the fixed image mask to all sub metrics. */
   void
-  SetFixedImageMask(FixedImageMaskType * _arg) override;
+  SetFixedImageMask(const FixedImageMaskType * _arg) override;
 
   /** Pass a fixed image mask to a specific metric */
   virtual void
-  SetFixedImageMask(FixedImageMaskType * _arg, unsigned int pos);
+  SetFixedImageMask(const FixedImageMaskType * _arg, unsigned int pos);
 
   /** Returns the fixedImageMask set in a specific metric. If the
    * submetric is a singlevalued costfunction a zero pointer will
@@ -381,11 +390,11 @@ public:
 
   /** Pass the moving image mask to all sub metrics. */
   void
-  SetMovingImageMask(MovingImageMaskType * _arg) override;
+  SetMovingImageMask(const MovingImageMaskType * _arg) override;
 
   /** Pass a moving image mask to a specific metric */
   virtual void
-  SetMovingImageMask(MovingImageMaskType * _arg, unsigned int pos);
+  SetMovingImageMask(const MovingImageMaskType * _arg, unsigned int pos);
 
   /** Returns the movingImageMask set in a specific metric. If the
    * submetric is a singlevalued costfunction a zero pointer will
@@ -429,10 +438,6 @@ public:
                         MeasureType &          value,
                         DerivativeType &       derivative) const override;
 
-  /** Experimental feature: compute SelfHessian. */
-  void
-  GetSelfHessian(const TransformParametersType & parameters, HessianType & H) const override;
-
   /** Method to return the latest modified time of this object or any of its
    * cached ivars.
    */
@@ -446,22 +451,27 @@ protected:
   PrintSelf(std::ostream & os, Indent indent) const override;
 
   /** Store the metrics and the corresponding weights. */
-  unsigned int                                 m_NumberOfMetrics;
-  std::vector<SingleValuedCostFunctionPointer> m_Metrics;
-  std::vector<double>                          m_MetricWeights;
-  std::vector<double>                          m_MetricRelativeWeights;
-  bool                                         m_UseRelativeWeights;
-  std::vector<bool>                            m_UseMetric;
-  mutable std::vector<MeasureType>             m_MetricValues;
-  mutable std::vector<DerivativeType>          m_MetricDerivatives;
-  mutable std::vector<double>                  m_MetricDerivativesMagnitude;
-  mutable std::vector<double>                  m_MetricComputationTime;
+  unsigned int                                 m_NumberOfMetrics{ 0 };
+  std::vector<SingleValuedCostFunctionPointer> m_Metrics{};
+  std::vector<double>                          m_MetricWeights{};
+  std::vector<double>                          m_MetricRelativeWeights{};
+  bool                                         m_UseRelativeWeights{ false };
+  std::vector<bool>                            m_UseMetric{};
+  mutable std::vector<MeasureType>             m_MetricValues{};
+  mutable std::vector<DerivativeType>          m_MetricDerivatives{};
+  mutable std::vector<double>                  m_MetricDerivativesMagnitude{};
+  mutable std::vector<double>                  m_MetricComputationTime{};
 
   /** Dummy image region and derivatives. */
-  FixedImageRegionType m_NullFixedImageRegion;
-  DerivativeType       m_NullDerivative;
+  FixedImageRegionType m_NullFixedImageRegion{};
+  DerivativeType       m_NullDerivative{};
 
 private:
+  // Private using-declarations, to avoid `-Woverloaded-virtual` warnings from GCC (GCC 11.4) or clang (macos-12).
+  using Superclass::SetFixedImageMask;
+  using Superclass::SetMovingImageMask;
+  using Superclass::SetTransform;
+
   /** Initialize some multi-threading related parameters.
    * Overrides function in AdvancedImageToImageMetric, because
    * here we use other parameters.
