@@ -223,6 +223,13 @@ public:
   {
     return this->GetInterpolator(0);
   }
+
+  const InterpolatorType *
+  GetInterpolator() const override
+  {
+    return this->GetInterpolator(0);
+  }
+
   elxOverrideSimpleSetMacro(Interpolator, InterpolatorType *);
   itkSetNumberOfMacro(Interpolator);
   itkGetNumberOfMacro(Interpolator);
@@ -239,6 +246,13 @@ public:
   {
     return this->GetFixedImagePyramid(0);
   }
+
+  const FixedImagePyramidType *
+  GetFixedImagePyramid() const override
+  {
+    return this->GetFixedImagePyramid(0);
+  }
+
   elxOverrideSimpleSetMacro(FixedImagePyramid, FixedImagePyramidType *);
   itkSetNumberOfMacro(FixedImagePyramid);
   itkGetNumberOfMacro(FixedImagePyramid);
@@ -255,6 +269,13 @@ public:
   {
     return this->GetMovingImagePyramid(0);
   }
+
+  const MovingImagePyramidType *
+  GetMovingImagePyramid() const override
+  {
+    return this->GetMovingImagePyramid(0);
+  }
+
   elxOverrideSimpleSetMacro(MovingImagePyramid, MovingImagePyramidType *);
   itkSetNumberOfMacro(MovingImagePyramid);
   itkGetNumberOfMacro(MovingImagePyramid);
@@ -317,25 +338,25 @@ protected:
   CheckOnInitialize();
 
   /** Variables already defined in the superclass, but as private...  */
-  bool           m_Stop;
-  ParametersType m_LastTransformParameters;
+  bool           m_Stop{};
+  ParametersType m_LastTransformParameters{};
 
   /** A shortcut to m_Metric of type CombinationMetricPointer. */
-  CombinationMetricPointer m_CombinationMetric;
+  CombinationMetricPointer m_CombinationMetric{};
 
   /** Containers for the pointers supplied by the user. */
-  std::vector<FixedImageConstPointer>    m_FixedImages;
-  std::vector<MovingImageConstPointer>   m_MovingImages;
-  std::vector<FixedImageRegionType>      m_FixedImageRegions;
-  std::vector<FixedImagePyramidPointer>  m_FixedImagePyramids;
-  std::vector<MovingImagePyramidPointer> m_MovingImagePyramids;
-  std::vector<InterpolatorPointer>       m_Interpolators;
+  std::vector<FixedImageConstPointer>    m_FixedImages{};
+  std::vector<MovingImageConstPointer>   m_MovingImages{};
+  std::vector<FixedImageRegionType>      m_FixedImageRegions{};
+  std::vector<FixedImagePyramidPointer>  m_FixedImagePyramids{};
+  std::vector<MovingImagePyramidPointer> m_MovingImagePyramids{};
+  std::vector<InterpolatorPointer>       m_Interpolators{};
 
   /** This vector is filled by the PrepareAllPyramids function. */
-  std::vector<FixedImageRegionPyramidType> m_FixedImageRegionPyramids;
+  std::vector<FixedImageRegionPyramidType> m_FixedImageRegionPyramids{};
 
   /** Dummy image region. */
-  FixedImageRegionType m_NullFixedImageRegion;
+  FixedImageRegionType m_NullFixedImageRegion{};
 };
 
 } // end namespace itk
