@@ -181,6 +181,13 @@ public:
   {
     return this->GetFixedImagePyramid(0);
   }
+
+  const FixedImagePyramidType *
+  GetFixedImagePyramid() const override
+  {
+    return this->GetFixedImagePyramid(0);
+  }
+
   elxOverrideSimpleSetMacro(FixedImagePyramid, FixedImagePyramidType *);
   itkSetNumberOfMacro(FixedImagePyramid);
   itkGetNumberOfMacro(FixedImagePyramid);
@@ -213,6 +220,13 @@ public:
   {
     return this->GetMovingImagePyramid(0);
   }
+
+  const MovingImagePyramidType *
+  GetMovingImagePyramid() const override
+  {
+    return this->GetMovingImagePyramid(0);
+  }
+
   elxOverrideSimpleSetMacro(MovingImagePyramid, MovingImagePyramidType *);
   itkSetNumberOfMacro(MovingImagePyramid);
   itkGetNumberOfMacro(MovingImagePyramid);
@@ -229,6 +243,13 @@ public:
   {
     return this->GetInterpolator(0);
   }
+
+  const InterpolatorType *
+  GetInterpolator() const override
+  {
+    return this->GetInterpolator(0);
+  }
+
   elxOverrideSimpleSetMacro(Interpolator, InterpolatorType *);
   itkSetNumberOfMacro(Interpolator);
   itkGetNumberOfMacro(Interpolator);
@@ -301,22 +322,22 @@ protected:
   CheckOnInitialize();
 
   /** Containers for the pointers supplied by the user */
-  FixedImageVectorType             m_FixedImages;
-  MovingImageVectorType            m_MovingImages;
-  FixedImageRegionVectorType       m_FixedImageRegions;
-  FixedImagePyramidVectorType      m_FixedImagePyramids;
-  MovingImagePyramidVectorType     m_MovingImagePyramids;
-  InterpolatorVectorType           m_Interpolators;
-  FixedImageInterpolatorVectorType m_FixedImageInterpolators;
+  FixedImageVectorType             m_FixedImages{};
+  MovingImageVectorType            m_MovingImages{};
+  FixedImageRegionVectorType       m_FixedImageRegions{};
+  FixedImagePyramidVectorType      m_FixedImagePyramids{};
+  MovingImagePyramidVectorType     m_MovingImagePyramids{};
+  InterpolatorVectorType           m_Interpolators{};
+  FixedImageInterpolatorVectorType m_FixedImageInterpolators{};
 
   /** This vector is filled by the PreparePyramids function. */
-  FixedImageRegionPyramidVectorType m_FixedImageRegionPyramids;
+  FixedImageRegionPyramidVectorType m_FixedImageRegionPyramids{};
 
   /** Dummy image region */
-  FixedImageRegionType m_NullFixedImageRegion;
+  FixedImageRegionType m_NullFixedImageRegion{};
 
 private:
-  MultiInputMetricPointer m_MultiInputMetric;
+  MultiInputMetricPointer m_MultiInputMetric{};
 };
 
 } // end namespace itk
