@@ -215,7 +215,7 @@ private:
 
   /** Creates a map of the parameters specific for this (derived) transform type. */
   ParameterMapType
-  CreateDerivedTransformParametersMap() const override;
+  CreateDerivedTransformParameterMap() const override;
 
   const AffineTransformPointer m_AffineTransform{ AffineTransformType::New() };
 };
