@@ -157,9 +157,9 @@ protected:
   PrecomputeJacobianOfSpatialJacobian();
 
 private:
-  ScalarArrayType m_Angle;
-  ScalarArrayType m_Shear;
-  ScalarArrayType m_Scale;
+  ScalarArrayType m_Angle{};
+  ScalarArrayType m_Shear{};
+  ScalarArrayType m_Scale{};
 };
 
 } // namespace itk
