@@ -102,7 +102,7 @@ public:
   void
   SetParameters(const ParametersType &) override
   {
-    itkExceptionMacro(<< "ERROR: SetParameters() is not implemented for DeformationFieldInterpolatingTransform.\n"
+    itkExceptionMacro("ERROR: SetParameters() is not implemented for DeformationFieldInterpolatingTransform.\n"
                       << "Use SetDeformationField() instead.\n"
                       << "Note that this transform is NOT suited for image registration.\n"
                       << "Just use it as an (initial) fixed transform that is not optimized.");
@@ -137,7 +137,7 @@ public:
   TransformVector(const InputVectorType &) const override
   {
     itkExceptionMacro(
-      << "TransformVector(const InputVectorType &) is not implemented for DeformationFieldInterpolatingTransform");
+      "TransformVector(const InputVectorType &) is not implemented for DeformationFieldInterpolatingTransform");
   }
 
 
@@ -145,15 +145,15 @@ public:
   TransformVector(const InputVnlVectorType &) const override
   {
     itkExceptionMacro(
-      << "TransformVector(const InputVnlVectorType &) is not implemented for DeformationFieldInterpolatingTransform");
+      "TransformVector(const InputVnlVectorType &) is not implemented for DeformationFieldInterpolatingTransform");
   }
 
 
   OutputCovariantVectorType
   TransformCovariantVector(const InputCovariantVectorType &) const override
   {
-    itkExceptionMacro(<< "TransformCovariantVector(const InputCovariantVectorType &) is not implemented for "
-                         "DeformationFieldInterpolatingTransform");
+    itkExceptionMacro("TransformCovariantVector(const InputCovariantVectorType &) is not implemented for "
+                      "DeformationFieldInterpolatingTransform");
   }
 
 
@@ -182,63 +182,61 @@ public:
 
   /** Must be provided. */
   void
-  GetJacobian(const InputPointType &       inputPoint,
-              JacobianType &               j,
-              NonZeroJacobianIndicesType & nonZeroJacobianIndices) const override
+  GetJacobian(const InputPointType &, JacobianType &, NonZeroJacobianIndicesType &) const override
   {
-    itkExceptionMacro(<< "Not implemented for DeformationFieldInterpolatingTransform");
+    itkExceptionMacro("Not implemented for DeformationFieldInterpolatingTransform");
   }
 
 
   void
-  GetSpatialJacobian(const InputPointType & inputPoint, SpatialJacobianType & sj) const override
+  GetSpatialJacobian(const InputPointType &, SpatialJacobianType &) const override
   {
-    itkExceptionMacro(<< "Not implemented for DeformationFieldInterpolatingTransform");
+    itkExceptionMacro("Not implemented for DeformationFieldInterpolatingTransform");
   }
 
 
   void
-  GetSpatialHessian(const InputPointType & inputPoint, SpatialHessianType & sh) const override
+  GetSpatialHessian(const InputPointType &, SpatialHessianType &) const override
   {
-    itkExceptionMacro(<< "Not implemented for DeformationFieldInterpolatingTransform");
+    itkExceptionMacro("Not implemented for DeformationFieldInterpolatingTransform");
   }
 
 
   void
-  GetJacobianOfSpatialJacobian(const InputPointType &          inputPoint,
-                               JacobianOfSpatialJacobianType & jsj,
-                               NonZeroJacobianIndicesType &    nonZeroJacobianIndices) const override
+  GetJacobianOfSpatialJacobian(const InputPointType &,
+                               JacobianOfSpatialJacobianType &,
+                               NonZeroJacobianIndicesType &) const override
   {
-    itkExceptionMacro(<< "Not implemented for DeformationFieldInterpolatingTransform");
+    itkExceptionMacro("Not implemented for DeformationFieldInterpolatingTransform");
   }
 
 
   void
-  GetJacobianOfSpatialJacobian(const InputPointType &          inputPoint,
-                               SpatialJacobianType &           sj,
-                               JacobianOfSpatialJacobianType & jsj,
-                               NonZeroJacobianIndicesType &    nonZeroJacobianIndices) const override
+  GetJacobianOfSpatialJacobian(const InputPointType &,
+                               SpatialJacobianType &,
+                               JacobianOfSpatialJacobianType &,
+                               NonZeroJacobianIndicesType &) const override
   {
-    itkExceptionMacro(<< "Not implemented for DeformationFieldInterpolatingTransform");
+    itkExceptionMacro("Not implemented for DeformationFieldInterpolatingTransform");
   }
 
 
   void
-  GetJacobianOfSpatialHessian(const InputPointType &         inputPoint,
-                              JacobianOfSpatialHessianType & jsh,
-                              NonZeroJacobianIndicesType &   nonZeroJacobianIndices) const override
+  GetJacobianOfSpatialHessian(const InputPointType &,
+                              JacobianOfSpatialHessianType &,
+                              NonZeroJacobianIndicesType &) const override
   {
-    itkExceptionMacro(<< "Not implemented for DeformationFieldInterpolatingTransform");
+    itkExceptionMacro("Not implemented for DeformationFieldInterpolatingTransform");
   }
 
 
   void
-  GetJacobianOfSpatialHessian(const InputPointType &         inputPoint,
-                              SpatialHessianType &           sh,
-                              JacobianOfSpatialHessianType & jsh,
-                              NonZeroJacobianIndicesType &   nonZeroJacobianIndices) const override
+  GetJacobianOfSpatialHessian(const InputPointType &,
+                              SpatialHessianType &,
+                              JacobianOfSpatialHessianType &,
+                              NonZeroJacobianIndicesType &) const override
   {
-    itkExceptionMacro(<< "Not implemented for DeformationFieldInterpolatingTransform");
+    itkExceptionMacro("Not implemented for DeformationFieldInterpolatingTransform");
   }
 
 
@@ -254,9 +252,14 @@ protected:
   void
   PrintSelf(std::ostream & os, Indent indent) const override;
 
-  DeformationFieldPointer             m_DeformationField;
-  DeformationFieldPointer             m_ZeroDeformationField;
-  DeformationFieldInterpolatorPointer m_DeformationFieldInterpolator;
+  DeformationFieldPointer             m_DeformationField{};
+  DeformationFieldPointer             m_ZeroDeformationField{};
+  DeformationFieldInterpolatorPointer m_DeformationFieldInterpolator{};
+
+private:
+  // Private using-declarations, to avoid `-Woverloaded-virtual` warnings from GCC (GCC 11.4).
+  using Superclass::TransformCovariantVector;
+  using Superclass::TransformVector;
 };
 
 } // namespace itk
