@@ -194,7 +194,7 @@ public:
 
   using IndexType = typename RegionType::IndexType;
   using SizeType = typename RegionType::SizeType;
-  using SpacingType = typename ImageType::SpacingType;
+  using SpacingType = typename ImageBase<NDimensions>::SpacingType;
   using DirectionType = typename ImageType::DirectionType;
   using OriginType = typename ImageType::PointType;
   using GridOffsetType = IndexType;
@@ -265,7 +265,7 @@ public:
   OutputVectorType
   TransformVector(const InputVectorType &) const override
   {
-    itkExceptionMacro(<< "Method not applicable for deformable transform.");
+    itkExceptionMacro("Method not applicable for deformable transform.");
     return OutputVectorType();
   }
 
@@ -276,7 +276,7 @@ public:
   OutputVnlVectorType
   TransformVector(const InputVnlVectorType &) const override
   {
-    itkExceptionMacro(<< "Method not applicable for deformable transform. ");
+    itkExceptionMacro("Method not applicable for deformable transform. ");
     return OutputVnlVectorType();
   }
 
@@ -287,7 +287,7 @@ public:
   OutputCovariantVectorType
   TransformCovariantVector(const InputCovariantVectorType &) const override
   {
-    itkExceptionMacro(<< "Method not applicable for deformable transform. ");
+    itkExceptionMacro("Method not applicable for deformable transform. ");
     return OutputCovariantVectorType();
   }
 
@@ -319,25 +319,18 @@ public:
     return false;
   }
 
-  /** Get number of weights. */
-  virtual unsigned long
-  GetNumberOfWeights() const
-  {
-    return m_Trans[0]->m_WeightsFunction->GetNumberOfWeights();
-  }
-
 
   virtual unsigned int
   GetNumberOfAffectedWeights() const
   {
-    return m_Trans[0]->m_WeightsFunction->GetNumberOfWeights();
+    return NumberOfWeights;
   }
 
 
   NumberOfParametersType
   GetNumberOfNonZeroJacobianIndices() const override
   {
-    return m_Trans[0]->m_WeightsFunction->GetNumberOfWeights() * SpaceDimension;
+    return NumberOfWeights * SpaceDimension;
   }
 
 
@@ -404,12 +397,12 @@ public:
   GetSpatialHessian(const InputPointType & inputPoint, SpatialHessianType & sh) const override;
 
   void
-  GetJacobianOfSpatialHessian(const InputPointType &         inputPoint,
-                              JacobianOfSpatialHessianType & jsh,
-                              NonZeroJacobianIndicesType &   nonZeroJacobianIndices) const override
+  GetJacobianOfSpatialHessian(const InputPointType &,
+                              JacobianOfSpatialHessianType &,
+                              NonZeroJacobianIndicesType &) const override
   {
-    itkExceptionMacro(<< "ERROR: GetJacobianOfSpatialHessian() not yet implemented in the "
-                         "MultiBSplineDeformableTransformWithNormal class.");
+    itkExceptionMacro("ERROR: GetJacobianOfSpatialHessian() not yet implemented in the "
+                      "MultiBSplineDeformableTransformWithNormal class.");
   }
 
 
@@ -475,7 +468,7 @@ protected:
   // bool m_SplineOrderOdd;
 
   /** Keep a pointer to the input parameters. */
-  const ParametersType * m_InputParametersPointer;
+  const ParametersType * m_InputParametersPointer{};
 
   /** Jacobian as SpaceDimension number of images. */
   /*
@@ -483,7 +476,7 @@ protected:
   using JacobianImageType = Image< JacobianPixelType,
     itkGetStaticConstMacro( SpaceDimension ) >;
 
-  typename JacobianImageType::Pointer m_JacobianImage[ NDimensions ];
+  typename JacobianImageType::Pointer m_JacobianImage[ NDimensions ]{};
   */
 
   /** Keep track of last support region used in computing the Jacobian
@@ -495,20 +488,27 @@ protected:
   // ImagePointer    m_WrappedImage[ NDimensions ];
 
   /** Internal parameters buffer. */
-  ParametersType m_InternalParametersBuffer;
+  ParametersType m_InternalParametersBuffer{};
 
   using TransformType = AdvancedBSplineDeformableTransform<TScalarType, Self::SpaceDimension, VSplineOrder>;
 
-  unsigned char                                m_NbLabels;
-  ImageLabelPointer                            m_Labels;
-  ImageLabelInterpolatorPointer                m_LabelsInterpolator;
-  ImageVectorPointer                           m_LabelsNormals;
-  std::vector<typename TransformType::Pointer> m_Trans;
-  std::vector<ParametersType>                  m_Para;
-  mutable int                                  m_LastJacobian;
-  ImageBasePointer                             m_LocalBases;
+  unsigned char                                m_NbLabels{};
+  ImageLabelPointer                            m_Labels{};
+  ImageLabelInterpolatorPointer                m_LabelsInterpolator{};
+  ImageVectorPointer                           m_LabelsNormals{};
+  std::vector<typename TransformType::Pointer> m_Trans{};
+  std::vector<ParametersType>                  m_Para{};
+  mutable int                                  m_LastJacobian{};
+  ImageBasePointer                             m_LocalBases{};
 
 private:
+  // Private using-declarations, to avoid `-Woverloaded-virtual` warnings from GCC (GCC 11.4).
+  using Superclass::TransformCovariantVector;
+  using Superclass::TransformVector;
+
+  /** The number of weights. */
+  static constexpr unsigned NumberOfWeights = TransformType::NumberOfWeights;
+
   void
   DispatchParameters(const ParametersType & parameters);
 
