@@ -19,7 +19,6 @@
 
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkThinPlateSplineKernelTransform2.h,v $
-  Language:  C++
   Date:      $Date: 2006-11-28 14:22:18 $
   Version:   $Revision: 1.1 $
 
@@ -31,8 +30,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkThinPlateSplineKernelTransform2_h
-#define __itkThinPlateSplineKernelTransform2_h
+#ifndef itkThinPlateSplineKernelTransform2_h
+#define itkThinPlateSplineKernelTransform2_h
 
 #include "itkKernelTransform2.h"
 
@@ -46,63 +45,59 @@ namespace itk
  *
  * \ingroup Transforms
  */
-template< class TScalarType,         // Data type for scalars (float or double)
-unsigned int NDimensions = 3 >
+template <class TScalarType, // Data type for scalars (float or double)
+          unsigned int NDimensions = 3>
 // Number of dimensions
-class ThinPlateSplineKernelTransform2 :
-  public KernelTransform2< TScalarType, NDimensions >
+class ITK_TEMPLATE_EXPORT ThinPlateSplineKernelTransform2 : public KernelTransform2<TScalarType, NDimensions>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(ThinPlateSplineKernelTransform2);
 
   /** Standard class typedefs. */
-  typedef ThinPlateSplineKernelTransform2              Self;
-  typedef KernelTransform2< TScalarType, NDimensions > Superclass;
-  typedef SmartPointer< Self >                         Pointer;
-  typedef SmartPointer< const Self >                   ConstPointer;
+  using Self = ThinPlateSplineKernelTransform2;
+  using Superclass = KernelTransform2<TScalarType, NDimensions>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** New macro for creation of through a Smart Pointer */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( ThinPlateSplineKernelTransform2, KernelTransform2 );
+  itkTypeMacro(ThinPlateSplineKernelTransform2, KernelTransform2);
 
   /** Scalar type. */
-  typedef typename Superclass::ScalarType ScalarType;
+  using typename Superclass::ScalarType;
 
   /** Parameters type. */
-  typedef typename Superclass::ParametersType ParametersType;
+  using typename Superclass::ParametersType;
 
   /** Jacobian Type */
-  typedef typename Superclass::JacobianType JacobianType;
+  using typename Superclass::JacobianType;
 
   /** Dimension of the domain space. */
-  itkStaticConstMacro( SpaceDimension, unsigned int, Superclass::SpaceDimension );
+  itkStaticConstMacro(SpaceDimension, unsigned int, Superclass::SpaceDimension);
 
   /** These (rather redundant) typedefs are needed because on SGI, typedefs
    * are not inherited.
    */
-  typedef typename Superclass::InputPointType            InputPointType;
-  typedef typename Superclass::OutputPointType           OutputPointType;
-  typedef typename Superclass::InputVectorType           InputVectorType;
-  typedef typename Superclass::OutputVectorType          OutputVectorType;
-  typedef typename Superclass::InputCovariantVectorType  InputCovariantVectorType;
-  typedef typename Superclass::OutputCovariantVectorType OutputCovariantVectorType;
-  typedef typename Superclass::PointsIterator            PointsIterator;
+  using typename Superclass::InputPointType;
+  using typename Superclass::OutputPointType;
+  using typename Superclass::InputVectorType;
+  using typename Superclass::OutputVectorType;
+  using typename Superclass::InputCovariantVectorType;
+  using typename Superclass::OutputCovariantVectorType;
+  using typename Superclass::PointsIterator;
 
 protected:
-
-  ThinPlateSplineKernelTransform2()
-  {
-    this->m_FastComputationPossible = true;
-  }
+  ThinPlateSplineKernelTransform2() { this->m_FastComputationPossible = true; }
 
 
-  ~ThinPlateSplineKernelTransform2() override {}
+  ~ThinPlateSplineKernelTransform2() override = default;
 
   /** These (rather redundant) typedefs are needed because on SGI, typedefs
    * are not inherited.
    */
-  typedef typename Superclass::GMatrixType GMatrixType;
+  using typename Superclass::GMatrixType;
 
   /** Compute G(x)
    * For the thin plate spline, this is:
@@ -113,25 +108,20 @@ protected:
    * \f[ r(x) = \sqrt{ x_1^2 + x_2^2 + x_3^2 }  \f]
    * I = identity matrix.
    */
-  void ComputeG( const InputVectorType & x, GMatrixType & GMatrix ) const override;
+  void
+  ComputeG(const InputVectorType & x, GMatrixType & GMatrix) const override;
 
   /** Compute the contribution of the landmarks weighted by the kernel function
    * to the global deformation of the space.
    */
-  void ComputeDeformationContribution(
-    const InputPointType & inputPoint, OutputPointType & result ) const override;
-
-private:
-
-  ThinPlateSplineKernelTransform2( const Self & ); // purposely not implemented
-  void operator=( const Self & );                  // purposely not implemented
-
+  void
+  ComputeDeformationContribution(const InputPointType & inputPoint, OutputPointType & result) const override;
 };
 
 } // namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkThinPlateSplineKernelTransform2.hxx"
+#  include "itkThinPlateSplineKernelTransform2.hxx"
 #endif
 
-#endif // __itkThinPlateSplineKernelTransform2_h
+#endif // itkThinPlateSplineKernelTransform2_h
