@@ -19,7 +19,6 @@
 
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVolumeSplineKernelTransform2.h,v $
-  Language:  C++
   Date:      $Date: 2006/03/18 18:06:38 $
   Version:   $Revision: 1.8 $
 
@@ -31,8 +30,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkVolumeSplineKernelTransform2_h
-#define __itkVolumeSplineKernelTransform2_h
+#ifndef itkVolumeSplineKernelTransform2_h
+#define itkVolumeSplineKernelTransform2_h
 
 #include "itkKernelTransform2.h"
 
@@ -46,63 +45,57 @@ namespace itk
  *
  * \ingroup Transforms
  */
-template< class TScalarType,         // Data type for scalars (float or double)
-unsigned int NDimensions = 3 >
+template <class TScalarType, // Data type for scalars (float or double)
+          unsigned int NDimensions = 3>
 // Number of dimensions
-class VolumeSplineKernelTransform2 :
-  public KernelTransform2<   TScalarType, NDimensions >
+class ITK_TEMPLATE_EXPORT VolumeSplineKernelTransform2 : public KernelTransform2<TScalarType, NDimensions>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(VolumeSplineKernelTransform2);
 
   /** Standard class typedefs. */
-  typedef VolumeSplineKernelTransform2                 Self;
-  typedef KernelTransform2< TScalarType, NDimensions > Superclass;
-  typedef SmartPointer< Self >                         Pointer;
-  typedef SmartPointer< const Self >                   ConstPointer;
+  using Self = VolumeSplineKernelTransform2;
+  using Superclass = KernelTransform2<TScalarType, NDimensions>;
+  using Pointer = SmartPointer<Self>;
+  using ConstPointer = SmartPointer<const Self>;
 
   /** New macro for creation of through a Smart Pointer */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( VolumeSplineKernelTransform2, KernelTransform2 );
+  itkTypeMacro(VolumeSplineKernelTransform2, KernelTransform2);
 
   /** Scalar type. */
-  typedef typename Superclass::ScalarType ScalarType;
+  using typename Superclass::ScalarType;
 
   /** Parameters type. */
-  typedef typename Superclass::ParametersType ParametersType;
+  using typename Superclass::ParametersType;
 
   /** Jacobian Type */
-  typedef typename Superclass::JacobianType JacobianType;
+  using typename Superclass::JacobianType;
 
   /** Dimension of the domain space. */
-  itkStaticConstMacro( SpaceDimension, unsigned int, Superclass::SpaceDimension );
+  itkStaticConstMacro(SpaceDimension, unsigned int, Superclass::SpaceDimension);
 
   /** These (rather redundant) typedefs are needed because on SGI, typedefs
    * are not inherited */
-  typedef typename Superclass::InputPointType   InputPointType;
-  typedef typename Superclass::OutputPointType  OutputPointType;
-  typedef typename Superclass::InputVectorType  InputVectorType;
-  typedef typename Superclass::OutputVectorType OutputVectorType;
-  typedef typename Superclass::InputCovariantVectorType
-    InputCovariantVectorType;
-  typedef typename Superclass::OutputCovariantVectorType
-    OutputCovariantVectorType;
-  typedef typename Superclass::PointsIterator PointsIterator;
+  using typename Superclass::InputPointType;
+  using typename Superclass::OutputPointType;
+  using typename Superclass::InputVectorType;
+  using typename Superclass::OutputVectorType;
+  using typename Superclass::InputCovariantVectorType;
+  using typename Superclass::OutputCovariantVectorType;
+  using typename Superclass::PointsIterator;
 
 protected:
-
-  VolumeSplineKernelTransform2()
-  {
-    this->m_FastComputationPossible = true;
-  }
+  VolumeSplineKernelTransform2() { this->m_FastComputationPossible = true; }
 
 
-  ~VolumeSplineKernelTransform2() override {}
+  ~VolumeSplineKernelTransform2() override = default;
 
   /** These (rather redundant) typedefs are needed because on SGI, typedefs
    * are not inherited. */
-  typedef typename Superclass::GMatrixType GMatrixType;
+  using typename Superclass::GMatrixType;
 
   /** Compute G(x)
    * For the volume plate spline, this is:
@@ -112,24 +105,19 @@ protected:
    * r(x) = Euclidean norm = sqrt[x1^2 + x2^2 + x3^2]
    * \f[ r(x) = \sqrt{ x_1^2 + x_2^2 + x_3^2 }  \f]
    * I = identity matrix. */
-  void ComputeG( const InputVectorType & x, GMatrixType & GMatrix ) const override;
+  void
+  ComputeG(const InputVectorType & x, GMatrixType & GMatrix) const override;
 
   /** Compute the contribution of the landmarks weighted by the kernel funcion
       to the global deformation of the space  */
-  void ComputeDeformationContribution( const InputPointType & inputPoint,
-    OutputPointType & result ) const override;
-
-private:
-
-  VolumeSplineKernelTransform2( const Self & ); // purposely not implemented
-  void operator=( const Self & );               // purposely not implemented
-
+  void
+  ComputeDeformationContribution(const InputPointType & inputPoint, OutputPointType & result) const override;
 };
 
 } // namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkVolumeSplineKernelTransform2.hxx"
+#  include "itkVolumeSplineKernelTransform2.hxx"
 #endif
 
-#endif // __itkVolumeSplineKernelTransform2_h
+#endif // itkVolumeSplineKernelTransform2_h
