@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxFixedImagePyramidBase_h
-#define __elxFixedImagePyramidBase_h
+#ifndef elxFixedImagePyramidBase_h
+#define elxFixedImagePyramidBase_h
 
 /** Needed for the macros */
 #include "elxMacro.h"
@@ -54,88 +54,84 @@ namespace elastix
  * \ingroup ComponentBaseClasses
  */
 
-template< class TElastix >
-class FixedImagePyramidBase : public BaseComponentSE< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT FixedImagePyramidBase : public BaseComponentSE<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(FixedImagePyramidBase);
 
   /** Standard ITK-stuff. */
-  typedef FixedImagePyramidBase       Self;
-  typedef BaseComponentSE< TElastix > Superclass;
+  using Self = FixedImagePyramidBase;
+  using Superclass = BaseComponentSE<TElastix>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( FixedImagePyramidBase, BaseComponentSE );
+  itkTypeMacro(FixedImagePyramidBase, BaseComponentSE);
 
   /** Typedefs inherited from the superclass. */
-  typedef typename Superclass::ElastixType          ElastixType;
-  typedef typename Superclass::ElastixPointer       ElastixPointer;
-  typedef typename Superclass::ConfigurationType    ConfigurationType;
-  typedef typename Superclass::ConfigurationPointer ConfigurationPointer;
-  typedef typename Superclass::RegistrationType     RegistrationType;
-  typedef typename Superclass::RegistrationPointer  RegistrationPointer;
+  using typename Superclass::ElastixType;
+  using typename Superclass::RegistrationType;
 
   /** Typedefs inherited from Elastix. */
-  typedef typename ElastixType::FixedImageType InputImageType;
-  typedef typename ElastixType::FixedImageType OutputImageType;
+  using InputImageType = typename ElastixType::FixedImageType;
+  using OutputImageType = typename ElastixType::FixedImageType;
 
   /** Other typedef's. */
-  typedef itk::MultiResolutionPyramidImageFilter<
-    InputImageType, OutputImageType >                 ITKBaseType;
+  using ITKBaseType = itk::MultiResolutionPyramidImageFilter<InputImageType, OutputImageType>;
 
   /** Typedef's from ITKBaseType. */
-  typedef typename ITKBaseType::ScheduleType ScheduleType;
+  using ScheduleType = typename ITKBaseType::ScheduleType;
 
-  /** Cast to ITKBaseType. */
-  virtual ITKBaseType * GetAsITKBaseType( void )
+  /** Retrieves this object as ITKBaseType. */
+  ITKBaseType *
+  GetAsITKBaseType()
   {
-    return dynamic_cast< ITKBaseType * >( this );
+    return &(this->GetSelf());
   }
 
 
-  /** Cast to ITKBaseType, to use in const functions. */
-  virtual const ITKBaseType * GetAsITKBaseType( void ) const
+  /** Retrieves this object as ITKBaseType, to use in const functions. */
+  const ITKBaseType *
+  GetAsITKBaseType() const
   {
-    return dynamic_cast< const ITKBaseType * >( this );
+    return &(this->GetSelf());
   }
 
 
   /** Execute stuff before the actual registration:
    * \li Set the schedule of the fixed image pyramid.
    */
-  void BeforeRegistrationBase( void ) override;
+  void
+  BeforeRegistrationBase() override;
 
   /** Execute stuff before each resolution:
    * \li Write the pyramid image to file.
    */
-  void BeforeEachResolutionBase( void ) override;
+  void
+  BeforeEachResolutionBase() override;
 
   /** Method for setting the schedule. */
-  virtual void SetFixedSchedule( void );
+  virtual void
+  SetFixedSchedule();
 
   /** Method to write the pyramid image. */
-  virtual void WritePyramidImage( const std::string & filename,
-    const unsigned int & level ); // const;
+  void
+  WritePyramidImage(const std::string & filename,
+                    const unsigned int  level); // const;
 
 protected:
-
   /** The constructor. */
-  FixedImagePyramidBase() {}
+  FixedImagePyramidBase() = default;
   /** The destructor. */
-  ~FixedImagePyramidBase() override {}
+  ~FixedImagePyramidBase() override = default;
 
 private:
-
-  /** The private constructor. */
-  FixedImagePyramidBase( const Self & ); // purposely not implemented
-  /** The private copy constructor. */
-  void operator=( const Self & );        // purposely not implemented
-
+  elxDeclarePureVirtualGetSelfMacro(ITKBaseType);
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxFixedImagePyramidBase.hxx"
+#  include "elxFixedImagePyramidBase.hxx"
 #endif
 
-#endif // end #ifndef __elxFixedImagePyramidBase_h
+#endif // end #ifndef elxFixedImagePyramidBase_h
