@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxMetricBase_h
-#define __elxMetricBase_h
+#ifndef elxMetricBase_h
+#define elxMetricBase_h
 
 /** Needed for the macros. */
 #include "elxMacro.h"
@@ -68,79 +68,79 @@ namespace elastix
  * \ingroup ComponentBaseClasses
  */
 
-template< class TElastix >
-class MetricBase : public BaseComponentSE< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT MetricBase : public BaseComponentSE<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(MetricBase);
 
   /** Standard ITK stuff. */
-  typedef MetricBase                  Self;
-  typedef BaseComponentSE< TElastix > Superclass;
+  using Self = MetricBase;
+  using Superclass = BaseComponentSE<TElastix>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( MetricBase, BaseComponentSE );
+  itkTypeMacro(MetricBase, BaseComponentSE);
 
   /** Typedef's inherited from Elastix. */
-  typedef typename Superclass::ElastixType          ElastixType;
-  typedef typename Superclass::ElastixPointer       ElastixPointer;
-  typedef typename Superclass::ConfigurationType    ConfigurationType;
-  typedef typename Superclass::ConfigurationPointer ConfigurationPointer;
-  typedef typename Superclass::RegistrationType     RegistrationType;
-  typedef typename Superclass::RegistrationPointer  RegistrationPointer;
+  using typename Superclass::ElastixType;
+  using typename Superclass::RegistrationType;
 
   /** Other typedef's. */
-  typedef typename ElastixType::FixedImageType  FixedImageType;
-  typedef typename FixedImageType::PointType    FixedPointType;
-  typedef typename FixedPointType::ValueType    FixedPointValueType;
-  typedef typename ElastixType::MovingImageType MovingImageType;
-  typedef typename MovingImageType::PointType   MovingPointType;
-  typedef typename MovingPointType::ValueType   MovingPointValueType;
+  using FixedImageType = typename ElastixType::FixedImageType;
+  using FixedPointType = typename FixedImageType::PointType;
+  using FixedPointValueType = typename FixedPointType::ValueType;
+  using MovingImageType = typename ElastixType::MovingImageType;
+  using MovingPointType = typename MovingImageType::PointType;
+  using MovingPointValueType = typename MovingPointType::ValueType;
 
   /** ITKBaseType. */
-  typedef itk::SingleValuedCostFunction ITKBaseType;
-  typedef itk::AdvancedImageToImageMetric<
-    FixedImageType, MovingImageType >                 AdvancedMetricType;
-  typedef typename AdvancedMetricType::MovingImageDerivativeScalesType MovingImageDerivativeScalesType;
+  using ITKBaseType = itk::SingleValuedCostFunction;
+  using AdvancedMetricType = itk::AdvancedImageToImageMetric<FixedImageType, MovingImageType>;
+  using MovingImageDerivativeScalesType = typename AdvancedMetricType::MovingImageDerivativeScalesType;
 
   /** Get the dimension of the fixed image. */
-  itkStaticConstMacro( FixedImageDimension, unsigned int, FixedImageType::ImageDimension );
+  itkStaticConstMacro(FixedImageDimension, unsigned int, FixedImageType::ImageDimension);
   /** Get the dimension of the moving image. */
-  itkStaticConstMacro( MovingImageDimension, unsigned int, MovingImageType::ImageDimension );
+  itkStaticConstMacro(MovingImageDimension, unsigned int, MovingImageType::ImageDimension);
 
   /** Typedefs for point sets. */
-  typedef typename ITKBaseType::ParametersValueType CoordinateRepresentationType;
-  typedef itk::PointSet<
-    CoordinateRepresentationType, FixedImageDimension,
-    itk::DefaultStaticMeshTraits<
-    CoordinateRepresentationType,
-    FixedImageDimension, FixedImageDimension,
-    CoordinateRepresentationType, CoordinateRepresentationType,
-    CoordinateRepresentationType > >                FixedPointSetType;
-  typedef itk::PointSet<
-    CoordinateRepresentationType, MovingImageDimension,
-    itk::DefaultStaticMeshTraits<
-    CoordinateRepresentationType,
-    MovingImageDimension, MovingImageDimension,
-    CoordinateRepresentationType, CoordinateRepresentationType,
-    CoordinateRepresentationType > >                MovingPointSetType;
+  using CoordinateRepresentationType = typename ITKBaseType::ParametersValueType;
+  using FixedPointSetType = itk::PointSet<CoordinateRepresentationType,
+                                          FixedImageDimension,
+                                          itk::DefaultStaticMeshTraits<CoordinateRepresentationType,
+                                                                       FixedImageDimension,
+                                                                       FixedImageDimension,
+                                                                       CoordinateRepresentationType,
+                                                                       CoordinateRepresentationType,
+                                                                       CoordinateRepresentationType>>;
+  using MovingPointSetType = itk::PointSet<CoordinateRepresentationType,
+                                           MovingImageDimension,
+                                           itk::DefaultStaticMeshTraits<CoordinateRepresentationType,
+                                                                        MovingImageDimension,
+                                                                        MovingImageDimension,
+                                                                        CoordinateRepresentationType,
+                                                                        CoordinateRepresentationType,
+                                                                        CoordinateRepresentationType>>;
 
   /** Typedefs for sampler support. */
-  typedef typename AdvancedMetricType::ImageSamplerType ImageSamplerBaseType;
+  using ImageSamplerBaseType = typename AdvancedMetricType::ImageSamplerType;
 
   /** Return type of GetValue */
-  typedef typename ITKBaseType::MeasureType MeasureType;
+  using MeasureType = typename ITKBaseType::MeasureType;
 
-  /** Cast to ITKBaseType. */
-  virtual ITKBaseType * GetAsITKBaseType( void )
+  /** Retrieves this object as ITKBaseType. */
+  ITKBaseType *
+  GetAsITKBaseType()
   {
-    return dynamic_cast< ITKBaseType * >( this );
+    return &(this->GetSelf());
   }
 
 
-  /** Cast to ITKBaseType, to use in const functions. */
-  virtual const ITKBaseType * GetAsITKBaseType( void ) const
+  /** Retrieves this object as ITKBaseType, to use in const functions. */
+  const ITKBaseType *
+  GetAsITKBaseType() const
   {
-    return dynamic_cast< const ITKBaseType * >( this );
+    return &(this->GetSelf());
   }
 
 
@@ -148,57 +148,68 @@ public:
    * \li Check if the exact metric value should be computed
    * (to monitor the progress of the registration).
    */
-  void BeforeEachResolutionBase( void ) override;
+  void
+  BeforeEachResolutionBase() override;
 
   /** Execute stuff after each iteration:
    * \li Optionally compute the exact metric value and plot it to screen.
    */
-  void AfterEachIterationBase( void ) override;
+  void
+  AfterEachIterationBase() override;
 
   /** Force the metric to base its computation on a new subset of image samples.
    * Not every metric may have implemented this.
    */
-  virtual void SelectNewSamples( void );
+  virtual void
+  SelectNewSamples();
 
   /** Returns whether the metric uses a sampler. When the metric is not of
    * AdvancedMetricType, the function returns false immediately.
    */
-  virtual bool GetAdvancedMetricUseImageSampler( void ) const;
+  virtual bool
+  GetAdvancedMetricUseImageSampler() const;
 
   /** Method to set the image sampler. The image sampler is only used when
    * the metric is of type AdvancedMetricType, and has UseImageSampler set
    * to true. In other cases, the function does nothing.
    */
-  virtual void SetAdvancedMetricImageSampler( ImageSamplerBaseType * sampler );
+  virtual void
+  SetAdvancedMetricImageSampler(ImageSamplerBaseType * sampler);
 
   /** Methods to get the image sampler. The image sampler is only used when
    * the metric is of type AdvancedMetricType, and has UseImageSampler set
    * to true. In other cases, the function returns 0.
    */
-  virtual ImageSamplerBaseType * GetAdvancedMetricImageSampler( void ) const;
+  virtual ImageSamplerBaseType *
+  GetAdvancedMetricImageSampler() const;
 
   /** Get if the exact metric value is computed */
-  virtual bool GetShowExactMetricValue( void ) const
-  { return this->m_ShowExactMetricValue; }
+  virtual bool
+  GetShowExactMetricValue() const
+  {
+    return this->m_ShowExactMetricValue;
+  }
 
   /** Get the last computed exact metric value */
-  virtual MeasureType GetCurrentExactMetricValue( void ) const
-  { return this->m_CurrentExactMetricValue; }
+  virtual MeasureType
+  GetCurrentExactMetricValue() const
+  {
+    return this->m_CurrentExactMetricValue;
+  }
 
 protected:
-
   /** The parameters type. */
-  typedef typename ITKBaseType::ParametersType ParametersType;
+  using ParametersType = typename ITKBaseType::ParametersType;
 
   /** The full sampler used by the GetExactValue method. */
-  typedef itk::ImageGridSampler< FixedImageType >                     ExactMetricImageSamplerType;
-  typedef typename ExactMetricImageSamplerType::Pointer               ExactMetricImageSamplerPointer;
-  typedef typename ExactMetricImageSamplerType::SampleGridSpacingType ExactMetricSampleGridSpacingType;
+  using ExactMetricImageSamplerType = itk::ImageGridSampler<FixedImageType>;
+  using ExactMetricImageSamplerPointer = typename ExactMetricImageSamplerType::Pointer;
+  using ExactMetricSampleGridSpacingType = typename ExactMetricImageSamplerType::SampleGridSpacingType;
 
   /** The constructor. */
-  MetricBase();
+  MetricBase() = default;
   /** The destructor. */
-  ~MetricBase() override {}
+  ~MetricBase() override = default;
 
   /**  Get the exact value. Mutual information computed over all points.
    * It is meant in situations when you optimize using just a subset of pixels,
@@ -209,29 +220,26 @@ protected:
    * In other cases it returns 0. You may re-implement this method in
    * the elxYourMetric, if you like.
    */
-  virtual MeasureType GetExactValue( const ParametersType & parameters );
+  virtual MeasureType
+  GetExactValue(const ParametersType & parameters);
 
   /** \todo the method GetExactDerivative could as well be added here. */
 
-  bool                             m_ShowExactMetricValue;
-  ExactMetricImageSamplerPointer   m_ExactMetricSampler;
-  MeasureType                      m_CurrentExactMetricValue;
-  ExactMetricSampleGridSpacingType m_ExactMetricSampleGridSpacing;
-  unsigned int                     m_ExactMetricEachXNumberOfIterations;
+  bool                             m_ShowExactMetricValue{ false };
+  ExactMetricImageSamplerPointer   m_ExactMetricSampler{ nullptr };
+  MeasureType                      m_CurrentExactMetricValue{ 0.0 };
+  ExactMetricSampleGridSpacingType m_ExactMetricSampleGridSpacing{ itk::MakeFilled<ExactMetricSampleGridSpacingType>(
+    1) };
+  unsigned int                     m_ExactMetricEachXNumberOfIterations{ 1 };
 
 private:
-
-  /** The private constructor. */
-  MetricBase( const Self & );      // purposely not implemented
-  /** The private copy constructor. */
-  void operator=( const Self & );  // purposely not implemented
-
+  elxDeclarePureVirtualGetSelfMacro(ITKBaseType);
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxMetricBase.hxx"
+#  include "elxMetricBase.hxx"
 #endif
 
-#endif // end #ifndef __elxMetricBase_h
+#endif // end #ifndef elxMetricBase_h
