@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxRegistrationBase_h
-#define __elxRegistrationBase_h
+#ifndef elxRegistrationBase_h
+#define elxRegistrationBase_h
 
 /** Needed for the macros */
 #include "elxMacro.h"
@@ -71,53 +71,51 @@ namespace elastix
  * \ingroup ComponentBaseClasses
  */
 
-template< class TElastix >
-class RegistrationBase : public BaseComponentSE< TElastix >
+template <class TElastix>
+class ITK_TEMPLATE_EXPORT RegistrationBase : public BaseComponentSE<TElastix>
 {
 public:
+  ITK_DISALLOW_COPY_AND_MOVE(RegistrationBase);
 
   /** Standard ITK stuff. */
-  typedef RegistrationBase            Self;
-  typedef BaseComponentSE< TElastix > Superclass;
+  using Self = RegistrationBase;
+  using Superclass = BaseComponentSE<TElastix>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( RegistrationBase, BaseComponentSE );
+  itkTypeMacro(RegistrationBase, BaseComponentSE);
 
   /** Typedef's from Elastix. */
-  typedef typename Superclass::ElastixType          ElastixType;
-  typedef typename Superclass::ElastixPointer       ElastixPointer;
-  typedef typename Superclass::ConfigurationType    ConfigurationType;
-  typedef typename Superclass::ConfigurationPointer ConfigurationPointer;
-  typedef typename Superclass::RegistrationType     RegistrationType;
-  typedef typename Superclass::RegistrationPointer  RegistrationPointer;
+  using typename Superclass::ElastixType;
+  using typename Superclass::RegistrationType;
 
   /** Other typedef's. */
-  typedef typename ElastixType::FixedImageType  FixedImageType;
-  typedef typename ElastixType::MovingImageType MovingImageType;
+  using FixedImageType = typename ElastixType::FixedImageType;
+  using MovingImageType = typename ElastixType::MovingImageType;
 
   /** Get the dimension of the fixed image. */
-  itkStaticConstMacro( FixedImageDimension, unsigned int, FixedImageType::ImageDimension );
+  itkStaticConstMacro(FixedImageDimension, unsigned int, FixedImageType::ImageDimension);
   /** Get the dimension of the moving image. */
-  itkStaticConstMacro( MovingImageDimension, unsigned int, MovingImageType::ImageDimension );
+  itkStaticConstMacro(MovingImageDimension, unsigned int, MovingImageType::ImageDimension);
 
   /** Typedef for ITKBaseType. */
-  typedef itk::MultiResolutionImageRegistrationMethod2<
-    FixedImageType, MovingImageType >       ITKBaseType;
+  using ITKBaseType = itk::MultiResolutionImageRegistrationMethod2<FixedImageType, MovingImageType>;
 
   /** Typedef for mask erosion options */
-  typedef std::vector< bool > UseMaskErosionArrayType;
+  using UseMaskErosionArrayType = std::vector<bool>;
 
-  /** Cast to ITKBaseType. */
-  virtual ITKBaseType * GetAsITKBaseType( void )
+  /** Retrieves this object as ITKBaseType. */
+  ITKBaseType *
+  GetAsITKBaseType()
   {
-    return dynamic_cast< ITKBaseType * >( this );
+    return &(this->GetSelf());
   }
 
 
-  /** Cast to ITKBaseType, to use in const functions. */
-  virtual const ITKBaseType * GetAsITKBaseType( void ) const
+  /** Retrieves this object as ITKBaseType, to use in const functions. */
+  const ITKBaseType *
+  GetAsITKBaseType() const
   {
-    return dynamic_cast< const ITKBaseType * >( this );
+    return &(this->GetSelf());
   }
 
 
@@ -141,42 +139,37 @@ public:
    * All options can be specified for each resolution specifically, or at once for all
    * resolutions.
    */
-  virtual bool ReadMaskParameters(
-    UseMaskErosionArrayType & useMaskErosionArray,
-    const unsigned int nrOfMasks,
-    const std::string & whichMask,
-    const unsigned int level ) const;
+  virtual bool
+  ReadMaskParameters(UseMaskErosionArrayType & useMaskErosionArray,
+                     const unsigned int        nrOfMasks,
+                     const std::string &       whichMask,
+                     const unsigned int        level) const;
 
 protected:
-
   /** The constructor. */
-  RegistrationBase() {}
+  RegistrationBase() = default;
   /** The destructor. */
-  ~RegistrationBase() override {}
+  ~RegistrationBase() override = default;
 
   /** Typedef's for mask support. */
-  typedef typename ElastixType::MaskPixelType   MaskPixelType;
-  typedef typename ElastixType::FixedMaskType   FixedMaskImageType;
-  typedef typename ElastixType::MovingMaskType  MovingMaskImageType;
-  typedef typename FixedMaskImageType::Pointer  FixedMaskImagePointer;
-  typedef typename MovingMaskImageType::Pointer MovingMaskImagePointer;
-  typedef itk::ImageMaskSpatialObject<
-    itkGetStaticConstMacro( FixedImageDimension ) >          FixedMaskSpatialObjectType;
-  typedef itk::ImageMaskSpatialObject<
-    itkGetStaticConstMacro( MovingImageDimension ) >         MovingMaskSpatialObjectType;
-  typedef typename
-    FixedMaskSpatialObjectType::Pointer FixedMaskSpatialObjectPointer;
-  typedef typename
-    MovingMaskSpatialObjectType::Pointer MovingMaskSpatialObjectPointer;
+  using MaskPixelType = typename ElastixType::MaskPixelType;
+  using FixedMaskImageType = typename ElastixType::FixedMaskType;
+  using MovingMaskImageType = typename ElastixType::MovingMaskType;
+  using FixedMaskImagePointer = typename FixedMaskImageType::Pointer;
+  using MovingMaskImagePointer = typename MovingMaskImageType::Pointer;
+  using FixedMaskSpatialObjectType = itk::ImageMaskSpatialObject<Self::FixedImageDimension>;
+  using MovingMaskSpatialObjectType = itk::ImageMaskSpatialObject<Self::MovingImageDimension>;
+  using FixedMaskSpatialObjectPointer = typename FixedMaskSpatialObjectType::Pointer;
+  using MovingMaskSpatialObjectPointer = typename MovingMaskSpatialObjectType::Pointer;
 
-  typedef typename ITKBaseType::FixedImagePyramidType  FixedImagePyramidType;
-  typedef typename ITKBaseType::MovingImagePyramidType MovingImagePyramidType;
+  using FixedImagePyramidType = typename ITKBaseType::FixedImagePyramidType;
+  using MovingImagePyramidType = typename ITKBaseType::MovingImagePyramidType;
 
   /** Some typedef's used for eroding the masks */
-  typedef itk::ErodeMaskImageFilter< FixedMaskImageType >  FixedMaskErodeFilterType;
-  typedef typename FixedMaskErodeFilterType::Pointer       FixedMaskErodeFilterPointer;
-  typedef itk::ErodeMaskImageFilter< MovingMaskImageType > MovingMaskErodeFilterType;
-  typedef typename MovingMaskErodeFilterType::Pointer      MovingMaskErodeFilterPointer;
+  using FixedMaskErodeFilterType = itk::ErodeMaskImageFilter<FixedMaskImageType>;
+  using FixedMaskErodeFilterPointer = typename FixedMaskErodeFilterType::Pointer;
+  using MovingMaskErodeFilterType = itk::ErodeMaskImageFilter<MovingMaskImageType>;
+  using MovingMaskErodeFilterPointer = typename MovingMaskErodeFilterType::Pointer;
 
   /** Generate a spatial object from a mask image, possibly after eroding the image
    * Input:
@@ -190,9 +183,11 @@ protected:
    *
    * This function is used by the registration components
    */
-  FixedMaskSpatialObjectPointer GenerateFixedMaskSpatialObject(
-    const FixedMaskImageType * maskImage, bool useMaskErosion,
-    const FixedImagePyramidType * pyramid, unsigned int level ) const;
+  FixedMaskSpatialObjectPointer
+  GenerateFixedMaskSpatialObject(const FixedMaskImageType *    maskImage,
+                                 bool                          useMaskErosion,
+                                 const FixedImagePyramidType * pyramid,
+                                 unsigned int                  level) const;
 
   /** Generate a spatial object from a mask image, possibly after eroding the image
    * Input:
@@ -206,23 +201,20 @@ protected:
    *
    * This function is used by the registration components
    */
-  MovingMaskSpatialObjectPointer GenerateMovingMaskSpatialObject(
-    const MovingMaskImageType * maskImage, bool useMaskErosion,
-    const MovingImagePyramidType * pyramid, unsigned int level ) const;
+  MovingMaskSpatialObjectPointer
+  GenerateMovingMaskSpatialObject(const MovingMaskImageType *    maskImage,
+                                  bool                           useMaskErosion,
+                                  const MovingImagePyramidType * pyramid,
+                                  unsigned int                   level) const;
 
 private:
-
-  /** The private constructor. */
-  RegistrationBase( const Self & );   // purposely not implemented
-  /** The private copy constructor. */
-  void operator=( const Self & );     // purposely not implemented
-
+  elxDeclarePureVirtualGetSelfMacro(ITKBaseType);
 };
 
 } // end namespace elastix
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "elxRegistrationBase.hxx"
+#  include "elxRegistrationBase.hxx"
 #endif
 
-#endif // end #ifndef __elxRegistrationBase_h
+#endif // end #ifndef elxRegistrationBase_h
