@@ -23,6 +23,7 @@
 
 #include "elxBaseComponentSE.h"
 #include "elxDefaultConstruct.h"
+#include <itkDeref.h>
 #include "elxElastixBase.h"
 #include "itkAdvancedTransform.h"
 #include "itkAdvancedCombinationTransform.h"
@@ -102,14 +103,16 @@ namespace elastix
  * The number of entries is stored the NumberOfParameters entry.
  * \transformparameter NumberOfParameters: the length of the transform parameter vector.\n
  * example <tt>(NumberOfParameters 722)</tt>\n
- * \transformparameter InitialTransformParametersFileName: The location/name of an initial
+ * \transformparameter InitialTransformParameterFileName: The location/name of an initial
  * transform that will be loaded when loading the current transform parameter file. Note
  * that transform parameter file can also contain an initial transform. Recursively all
  * transforms are thus automatically loaded when loading the last transform parameter file.\n
- * example <tt>(InitialTransformParametersFileName "./res/TransformParameters.0.txt")</tt>\n
+ * example <tt>(InitialTransformParameterFileName "./res/TransformParameters.0.txt")</tt>\n
  * The location is relative to the path from where elastix/transformix is started!\n
  * Default: "NoInitialTransform", which (obviously) means that there is no initial transform
  * to be loaded.
+ * \transformparameter InitialTransformParametersFileName: legacy parameter name, replaced with
+ * "InitialTransformParameterFileName", and deprecated from June 2023.
  *
  * The command line arguments used by this class are:
  * \commandlinearg -t0: optional argument for elastix for specifying an initial transform
@@ -158,9 +161,6 @@ public:
   using ComponentDescriptionType = ComponentDatabase::ComponentDescriptionType;
   using PtrToCreator = ComponentDatabase::PtrToCreator;
 
-  /** Typedef for the ProgressCommand. */
-  using ProgressCommandType = elx::ProgressCommand;
-
   /** Get the dimension of the fixed image. */
   itkStaticConstMacro(FixedImageDimension, unsigned int, FixedImageType::ImageDimension);
 
@@ -187,7 +187,7 @@ public:
   /** Typedefs needed for AutomaticScalesEstimation function */
   using ITKRegistrationType = typename RegistrationType::ITKBaseType;
   using OptimizerType = typename ITKRegistrationType::OptimizerType;
-  using ScalesType = typename OptimizerType::ScalesType;
+  using ScalesType = itk::Optimizer::ScalesType;
 
   /** Typedefs for images of determinants of spatial Jacobian matrices, and images of spatial Jacobian matrices */
   using SpatialJacobianDeterminantImageType = itk::Image<float, FixedImageDimension>;
@@ -223,9 +223,9 @@ public:
   void
   SetInitialTransform(InitialTransformType * _arg);
 
-  /** Set the TransformParametersFileName. */
+  /** Set the TransformParameterFileName. */
   void
-  SetTransformParametersFileName(const char * filename);
+  SetTransformParameterFileName(const std::string & filename);
 
   /** Function to read transform-parameters from a file. */
   virtual void
@@ -233,13 +233,13 @@ public:
 
   /** Function to create transform-parameters map. */
   void
-  CreateTransformParametersMap(const ParametersType & param,
-                               ParameterMapType &     parameterMap,
-                               const bool             includeDerivedTransformParameters = true) const;
+  CreateTransformParameterMap(const ParametersType & param,
+                              ParameterMapType &     parameterMap,
+                              const bool             includeDerivedTransformParameters = true) const;
 
   /** Function to write transform-parameters to a file. */
   void
-  WriteToFile(xl::xoutsimple & transformationParameterInfo, const ParametersType & param) const;
+  WriteToFile(std::ostream & transformationParameterInfo, const ParametersType & param) const;
 
   /** Macro for reading and writing the transform parameters in WriteToFile or not. */
   void
@@ -247,7 +247,7 @@ public:
 
   /** Function to read the initial transform parameters from a file. */
   void
-  ReadInitialTransformFromFile(const char * transformParameterFileName);
+  ReadInitialTransformFromFile(const std::string & transformParameterFileName);
 
   /** Function to transform coordinates from fixed to moving image. */
   void
@@ -298,7 +298,8 @@ protected:
   bool
   HasITKTransformParameters() const
   {
-    return this->BaseComponentSE<TElastix>::m_Configuration->HasParameter("ITKTransformParameters");
+    const Configuration & configuration = itk::Deref(Superclass::GetConfiguration());
+    return configuration.HasParameter("ITKTransformParameters");
   }
 
   /** Estimate a scales vector
@@ -359,7 +360,7 @@ private:
     typename FixedImageType::DirectionType originalDirection;
     const bool                             retdc = this->m_Elastix->GetOriginalFixedImageDirection(originalDirection);
     infoChanger->SetOutputDirection(originalDirection);
-    infoChanger->SetChangeDirection(retdc & !this->m_Elastix->GetUseDirectionCosines());
+    infoChanger->SetChangeDirection(retdc && !this->m_Elastix->GetUseDirectionCosines());
     infoChanger->SetInput(image);
 
     return infoChanger;
@@ -369,7 +370,7 @@ private:
   /** Function to read the initial transform parameters from the specified configuration object.
    */
   void
-  ReadInitialTransformFromConfiguration(const Configuration::Pointer);
+  ReadInitialTransformFromConfiguration(const Configuration::ConstPointer);
 
   /** Execute stuff before everything else:
    * \li Check the appearance of an initial transform.
@@ -393,8 +394,8 @@ private:
   const InitialTransformType *
   GetInitialTransform() const;
 
-  /** Get the TransformParametersFileName. */
-  itkGetStringMacro(TransformParametersFileName);
+  /** Get the TransformParameterFileName. */
+  itkGetStringMacro(TransformParameterFileName);
 
   /** Function to transform coordinates from fixed to moving image. */
   void
@@ -422,19 +423,21 @@ private:
   TransformPointsAllPoints() const;
 
   std::string
-  GetInitialTransformParametersFileName() const
+  GetInitialTransformParameterFileName() const
   {
-    if (!this->GetInitialTransform())
+    const InitialTransformType * const initialTransform = this->GetInitialTransform();
+
+    if (!initialTransform)
     {
       return "NoInitialTransform";
     }
 
-    const Self * t0 = dynamic_cast<const Self *>(this->GetInitialTransform());
-    return t0->GetTransformParametersFileName();
+    const auto t0 = dynamic_cast<const Self *>(initialTransform);
+    return t0->GetTransformParameterFileName();
   }
 
   virtual ParameterMapType
-  CreateDerivedTransformParametersMap() const = 0;
+  CreateDerivedTransformParameterMap() const = 0;
 
   /** Allows a derived transform class to write its data to file, by overriding this member function. */
   virtual void
@@ -442,7 +445,7 @@ private:
   {}
 
   /** Member variables. */
-  std::string    m_TransformParametersFileName;
+  std::string    m_TransformParameterFileName;
   ParametersType m_TransformParameters;
   ParametersType m_FinalParameters;
 
