@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elxBaseComponent_h
-#define __elxBaseComponent_h
+#ifndef elxBaseComponent_h
+#define elxBaseComponent_h
 
 /**
  * ******************* elxBaseComponent.h *************************
@@ -26,18 +26,9 @@
  * each component is supposed to have.
  *
  * The namespace alias elx is defined in this file.
- *
- * Some header files are included that most components need.
  */
 
-/** Get rid of warnings about too long variable names. */
-#ifdef _MSC_VER
-#pragma warning ( disable : 4786 )
-#pragma warning ( disable : 4503 )
-#endif
-
 #include "itkMacro.h" // itkTypeMacroNoParent
-
 #include <string>
 
 /** All elastix components should be in namespace elastix. */
@@ -62,7 +53,7 @@ namespace elastix
 class BaseComponent
 {
 public:
-  ITK_DISALLOW_COPY_AND_ASSIGN(BaseComponent);
+  ITK_DISALLOW_COPY_AND_MOVE(BaseComponent);
 
   /**
    * Callback methods that each component of elastix is supposed
@@ -70,8 +61,16 @@ public:
    * (like MetricBase, TransformBase, etc.). In this way similar
    * behavior for a group of components can be implemented.
    */
-  virtual int BeforeAllBase( void ) { return 0; }
-  virtual int BeforeAll( void ) { return 0; }
+  virtual int
+  BeforeAllBase()
+  {
+    return 0;
+  }
+  virtual int
+  BeforeAll()
+  {
+    return 0;
+  }
 
   /**
    * Callback methods that each component of elastix is supposed
@@ -79,11 +78,21 @@ public:
    * (like MetricBase, TransformBase, etc.). In this way similar
    * behavior for a group of components can be implemented.
    */
-  virtual void BeforeRegistrationBase( void ) {}
-  virtual void BeforeEachResolutionBase( void ) {}
-  virtual void AfterEachResolutionBase( void ) {}
-  virtual void AfterEachIterationBase( void ) {}
-  virtual void AfterRegistrationBase( void ) {}
+  virtual void
+  BeforeRegistrationBase()
+  {}
+  virtual void
+  BeforeEachResolutionBase()
+  {}
+  virtual void
+  AfterEachResolutionBase()
+  {}
+  virtual void
+  AfterEachIterationBase()
+  {}
+  virtual void
+  AfterRegistrationBase()
+  {}
 
   /**
    * Callback methods that each component of elastix is supposed
@@ -91,20 +100,31 @@ public:
    * component (like MattesMutualInformationMetric) to achieve
    * behavior, specific for that single component.
    */
-  virtual void BeforeRegistration( void ) {}
-  virtual void BeforeEachResolution( void ) {}
-  virtual void AfterEachResolution( void ) {}
-  virtual void AfterEachIteration( void ) {}
-  virtual void AfterRegistration( void ) {}
+  virtual void
+  BeforeRegistration()
+  {}
+  virtual void
+  BeforeEachResolution()
+  {}
+  virtual void
+  AfterEachResolution()
+  {}
+  virtual void
+  AfterEachIteration()
+  {}
+  virtual void
+  AfterRegistration()
+  {}
 
   /**
    * The name of the component in the ComponentDatabase.
    * Override this function not directly, but with the
    * elxClassNameMacro("name").
    */
-  virtual const char * elxGetClassName( void ) const;
+  virtual const char *
+  elxGetClassName() const;
 
-  itkTypeMacroNoParent( BaseComponent );
+  itkTypeMacroNoParent(BaseComponent);
 
   /** Set the component label, which consists of a label
    * ( "Metric", "Transform") and an index number. In case
@@ -113,27 +133,35 @@ public:
    * parameter file for example, to distinguish between options
    * meant for Metric0 and for Metric1.
    */
-  void SetComponentLabel( const char * label, unsigned int idx );
+  void
+  SetComponentLabel(const char * label, unsigned int idx);
 
   /** Get the componentlabel as a string: "Metric0" for example. */
-  const char * GetComponentLabel( void ) const;
+  const char *
+  GetComponentLabel() const;
 
-  static bool IsElastixLibrary();
+  static bool
+  IsElastixLibrary();
 
-  static void InitializeElastixExecutable();
+  static void
+  InitializeElastixExecutable();
 
-  /** Convenience function to convert seconds to day, hour, minute, second format. */
-  static std::string ConvertSecondsToDHMS( const double totalSeconds, const unsigned int precision );
+  /** Similar to `dynamic_cast<ITKBaseType*>(baseComponent)`, but without
+   * using RTTI (run-time type information).
+   */
+  template <typename TBaseComponent>
+  static auto
+  AsITKBaseType(TBaseComponent * const baseComponent) -> decltype(baseComponent->GetAsITKBaseType())
+  {
+    return (baseComponent == nullptr) ? nullptr : baseComponent->GetAsITKBaseType();
+  }
 
 protected:
-
   BaseComponent() = default;
   virtual ~BaseComponent() = default;
 
 private:
-
   std::string m_ComponentLabel;
-
 };
 
 } // end namespace elastix
@@ -141,4 +169,4 @@ private:
 /** Define an alias for the elastix namespace.*/
 namespace elx = elastix;
 
-#endif // end #ifndef __elxBaseComponent_h
+#endif // end #ifndef elxBaseComponent_h
