@@ -20,7 +20,7 @@
 #define elxComponentLoader_h
 
 #include "elxComponentDatabase.h"
-#include "xoutmain.h"
+#include "elxlog.h"
 
 namespace elastix
 {
