@@ -31,8 +31,9 @@
 #include "elxBaseComponent.h"
 #include "elxComponentDatabase.h"
 #include "elxConfiguration.h"
+#include "elxIterationInfo.h"
 #include "elxMacro.h"
-#include "xoutmain.h"
+#include "elxlog.h"
 
 // ITK header files:
 #include <itkChangeInformationImageFilter.h>
@@ -52,15 +53,15 @@
  * These macros are undef'd at the end of this file
  */
 #define elxGetObjectMacro(_name, _type)                                                                                \
-  _type * Get##_name() const { return this->m_##_name.GetPointer(); }
+  _type * Get##_name() const { return m_##_name.GetPointer(); }
 // end elxGetObjectMacro
 
 #define elxSetObjectMacro(_name, _type)                                                                                \
   void Set##_name(_type * _arg)                                                                                        \
   {                                                                                                                    \
-    if (this->m_##_name != _arg)                                                                                       \
+    if (m_##_name != _arg)                                                                                             \
     {                                                                                                                  \
-      this->m_##_name = _arg;                                                                                          \
+      m_##_name = _arg;                                                                                                \
       this->itk::Object::Modified();                                                                                   \
     }                                                                                                                  \
   }
@@ -70,9 +71,9 @@
 #define elxGetNumberOfMacro(_name)                                                                                     \
   unsigned int GetNumberOf##_name##s() const                                                                           \
   {                                                                                                                    \
-    if (this->m_##_name##Container != nullptr)                                                                         \
+    if (m_##_name##Container != nullptr)                                                                               \
     {                                                                                                                  \
-      return this->m_##_name##Container->Size();                                                                       \
+      return m_##_name##Container->Size();                                                                             \
     }                                                                                                                  \
     return 0;                                                                                                          \
   }
@@ -93,10 +94,6 @@ namespace elastix
  * \parameter RandomSeed: Sets a global seed for the random generator.\n
  *   example: <tt>(RandomSeed 121212)</tt>\n
  *   It must be a positive integer number. Default: 121212.
- * \parameter DefaultOutputPrecision: Set the default precision of floating values in the output.
- *   Most importantly, it affects the output precision of the parameters in the transform parameter file.\n
- *   example: <tt>(DefaultOutputPrecision 6)</tt>\n
- *   Default value: 6.
  *
  * The command line arguments used by this class are:
  * \commandlinearg -f: mandatory argument for elastix with the file name of the fixed image. \n
@@ -152,7 +149,6 @@ public:
   using Superclass = BaseComponent;
 
   /** Typedefs used in this class. */
-  using ConfigurationPointer = Configuration::Pointer;
   using ObjectPointer = itk::Object::Pointer;
   using DataObjectPointer = itk::DataObject::Pointer; // for the images
   using ObjectContainerType = itk::VectorContainer<unsigned int, ObjectPointer>;
@@ -190,7 +186,7 @@ public:
   DBIndexType
   GetDBIndex()
   {
-    return this->m_DBIndex;
+    return m_DBIndex;
   }
 
   /** Get the component containers.
@@ -317,12 +313,6 @@ public:
   int
   BeforeAllTransformixBase();
 
-  /** Function called before registration.
-   * It installs the IterationInfo field.
-   */
-  void
-  BeforeRegistrationBase() override;
-
   ResultImageType *
   GetResultImage(const unsigned int idx = 0) const;
 
@@ -336,17 +326,6 @@ public:
   SetResultDeformationField(DataObjectPointer result_deformationfield);
 
 
-  /** Get the default precision of xout.
-   * (The value assumed when no DefaultOutputPrecision is given in the
-   * parameter file.
-   */
-  int
-  GetDefaultOutputPrecision() const
-  {
-    return this->m_DefaultOutputPrecision;
-  }
-
-
   /** Get whether direction cosines should be taken into account (true)
    * or ignored (false). This depends on the UseDirectionCosines
    * parameter. */
@@ -363,27 +342,36 @@ public:
 
   /** Creates transformation parameters map. */
   virtual void
-  CreateTransformParametersMap() = 0;
+  CreateTransformParameterMap() = 0;
 
   /** Gets transformation parameters map. */
   ParameterMapType
-  GetTransformParametersMap() const;
+  GetTransformParameterMap() const;
 
   /** Set configuration vector. Library only. */
   void
-  SetConfigurations(const std::vector<ConfigurationPointer> & configurations);
+  SetTransformConfigurations(const std::vector<Configuration::ConstPointer> & configurations);
 
-  /** Return configuration from vector of configurations. Library only. */
-  ConfigurationPointer
-  GetConfiguration(const size_t index) const;
+  /** Return configuration from vector of transformation configurations. Library only. */
+  Configuration::ConstPointer
+  GetTransformConfiguration(const size_t index) const;
 
-  xl::xoutrow &
+  /** Returns the transformation configuration just before the specified one, or null. Returns null if the specified
+   * configuration does not have a previous one in the vector of transformation configurations. */
+  Configuration::ConstPointer
+  GetPreviousTransformConfiguration(const Configuration & configuration) const;
+
+  /** Returns the number of configurations in the vector of transformation configurations. */
+  size_t
+  GetNumberOfTransformConfigurations() const;
+
+  IterationInfo &
   GetIterationInfo()
   {
     return m_IterationInfo;
   }
 
-  xl::xoutbase &
+  std::ostream &
   GetIterationInfoAt(const char * const name)
   {
     return m_IterationInfo[name];
@@ -399,8 +387,7 @@ protected:
   ElastixBase();
   ~ElastixBase() override = default;
 
-  ConfigurationPointer m_Configuration{ nullptr };
-  DBIndexType          m_DBIndex{ 0 };
+  DBIndexType m_DBIndex{ 0 };
 
   FlatDirectionCosinesType m_OriginalFixedImageDirection;
 
@@ -412,14 +399,11 @@ protected:
   /** Store the CurrentTransformParameterFileName. */
   std::string m_CurrentTransformParameterFileName;
 
-  /** A vector of configuration objects, needed when transformix is used as library. */
-  std::vector<ConfigurationPointer> m_Configurations;
-
   /** Count the number of iterations. */
   unsigned int m_IterationCounter{};
 
   /** Stores transformation parameters map. */
-  ParameterMapType m_TransformParametersMap;
+  ParameterMapType m_TransformParameterMap;
 
   std::ofstream m_IterationInfoFile;
 
@@ -499,10 +483,12 @@ protected:
   GenerateDataObjectContainer(DataObjectPointer dataObject);
 
 private:
-  xl::xoutrow m_IterationInfo;
+  Configuration::Pointer m_Configuration{ nullptr };
 
-  /** The default output precision of elxout is set to 6. */
-  int m_DefaultOutputPrecision{ 6 };
+  /** A vector of configuration objects, needed when transformix is used as library. */
+  std::vector<Configuration::ConstPointer> m_TransformConfigurations;
+
+  IterationInfo m_IterationInfo;
 
   /** The component containers. These containers contain
    * SmartPointer's to itk::Object.
