@@ -16,8 +16,6 @@
  *
  *=========================================================================*/
 
-#define _USE_MATH_DEFINES // For M_PI_4.
-
 // First include the header file to be tested:
 #include <itkTransformixFilter.h>
 #include <itkElastixRegistrationMethod.h>
@@ -27,6 +25,7 @@
 #include "elxDefaultConstruct.h"
 #include "elxTransformIO.h"
 #include "GTesting/elxGTestUtilities.h"
+#include "elxForEachSupportedImageType.h"
 
 #include <itkStackTransform.h>
 
@@ -35,6 +34,8 @@
 #include <itkAffineTransform.h>
 #include <itkBSplineTransform.h>
 #include <itkCompositeTransform.h>
+#include <itkDeref.h>
+#include <itkDisplacementFieldTransform.h>
 #include <itkEuler2DTransform.h>
 #include <itkEuler3DTransform.h>
 #include <itkFileTools.h>
@@ -66,13 +67,20 @@ using ParameterMapVectorType = elx::ParameterObject::ParameterMapVectorType;
 using elx::CoreMainGTestUtilities::CheckNew;
 using elx::CoreMainGTestUtilities::CreateImage;
 using elx::CoreMainGTestUtilities::CreateImageFilledWithSequenceOfNaturalNumbers;
-using elx::CoreMainGTestUtilities::Deref;
+using elx::CoreMainGTestUtilities::CreateParameterObject;
+using elx::CoreMainGTestUtilities::CreateRandomImageDomain;
 using elx::CoreMainGTestUtilities::DerefSmartPointer;
 using elx::CoreMainGTestUtilities::FillImageRegion;
 using elx::CoreMainGTestUtilities::GetCurrentBinaryDirectoryPath;
 using elx::CoreMainGTestUtilities::GetDataDirectoryPath;
 using elx::CoreMainGTestUtilities::GetNameOfTest;
+using elx::CoreMainGTestUtilities::GenerateRandomSign;
+using elx::CoreMainGTestUtilities::ImageDomain;
+using elx::CoreMainGTestUtilities::TypeHolder;
+using elx::CoreMainGTestUtilities::minimumImageSizeValue;
 using elx::GTestUtilities::GeneratePseudoRandomParameters;
+using elx::GTestUtilities::MakeMergedMap;
+using itk::Deref;
 
 template <typename TMovingImage>
 using DefaultConstructibleTransformixFilter = elx::DefaultConstruct<itk::TransformixFilter<TMovingImage>>;
@@ -90,21 +98,12 @@ ConvertToItkVector(const T & arg)
 }
 
 
-auto
-CreateParameterObject(const ParameterMapType & parameterMap)
-{
-  const auto parameterObject = CheckNew<elx::ParameterObject>();
-  parameterObject->SetParameterMap(parameterMap);
-  return parameterObject;
-}
-
-
 template <unsigned ImageDimension>
 auto
 CreateDefaultDirectionParameterValues()
 {
-  constexpr auto      numberOfValues = ImageDimension * ImageDimension;
-  ParameterValuesType values(numberOfValues, "0");
+  static constexpr auto numberOfValues = ImageDimension * ImageDimension;
+  ParameterValuesType   values(numberOfValues, "0");
 
   for (std::size_t i{}; i < numberOfValues; i += (ImageDimension + 1))
   {
@@ -133,7 +132,7 @@ template <typename TImage>
 itk::SmartPointer<TImage>
 TranslateImage(TImage & image, const typename TImage::OffsetType & translationOffset)
 {
-  constexpr auto ImageDimension = TImage::ImageDimension;
+  static constexpr auto ImageDimension = TImage::ImageDimension;
 
   DefaultConstructibleTransformixFilter<TImage> filter;
 
@@ -179,7 +178,7 @@ template <typename TPixel, unsigned VImageDimension>
 auto
 CreateTransformixFilter(itk::Image<TPixel, VImageDimension> &                            image,
                         const itk::Transform<double, VImageDimension, VImageDimension> & itkTransform,
-                        const std::string & initialTransformParametersFileName = "NoInitialTransform",
+                        const std::string & initialTransformParameterFileName = "NoInitialTransform",
                         const std::string & howToCombineTransforms = "Compose")
 {
   const auto filter = CheckNew<itk::TransformixFilter<itk::Image<TPixel, VImageDimension>>>();
@@ -190,7 +189,7 @@ CreateTransformixFilter(itk::Image<TPixel, VImageDimension> &
                             { "Direction", CreateDefaultDirectionParameterValues<VImageDimension>() },
                             { "HowToCombineTransforms", { howToCombineTransforms } },
                             { "Index", ParameterValuesType(VImageDimension, "0") },
-                            { "InitialTransformParametersFileName", { initialTransformParametersFileName } },
+                            { "InitialTransformParameterFileName", { initialTransformParameterFileName } },
                             { "Origin", ParameterValuesType(VImageDimension, "0") },
                             { "ResampleInterpolator", { "FinalLinearInterpolator" } },
                             { "Size", ConvertToParameterValues(image.GetBufferedRegion().GetSize()) },
@@ -204,11 +203,11 @@ template <typename TPixel, unsigned VImageDimension>
 itk::SmartPointer<itk::Image<TPixel, VImageDimension>>
 RetrieveOutputFromTransformixFilter(itk::Image<TPixel, VImageDimension> &                            image,
                                     const itk::Transform<double, VImageDimension, VImageDimension> & itkTransform,
-                                    const std::string & initialTransformParametersFileName = "NoInitialTransform",
+                                    const std::string & initialTransformParameterFileName = "NoInitialTransform",
                                     const std::string & howToCombineTransforms = "Compose")
 {
   const auto transformixFilter =
-    CreateTransformixFilter(image, itkTransform, initialTransformParametersFileName, howToCombineTransforms);
+    CreateTransformixFilter(image, itkTransform, initialTransformParameterFileName, howToCombineTransforms);
   const auto output = transformixFilter->GetOutput();
   EXPECT_NE(output, nullptr);
   return output;
@@ -416,12 +415,13 @@ Test_BSplineViaExternalTransformFile(const std::string & rootOutputDirectoryPath
   }
 }
 
+
 } // namespace
 
 
 GTEST_TEST(itkTransformixFilter, IsDefaultInitialized)
 {
-  constexpr auto ImageDimension = 2U;
+  static constexpr auto ImageDimension = 2U;
   using PixelType = float;
   using TransformixFilterType = itk::TransformixFilter<itk::Image<PixelType, ImageDimension>>;
 
@@ -442,7 +442,7 @@ GTEST_TEST(itkTransformixFilter, IsDefaultInitialized)
 // Tests translating a small (5x6) binary image, having a 2x2 white square.
 GTEST_TEST(itkTransformixFilter, Translation2D)
 {
-  constexpr auto ImageDimension = 2U;
+  static constexpr auto ImageDimension = 2U;
   using ImageType = itk::Image<float, ImageDimension>;
   using SizeType = itk::Size<ImageDimension>;
 
@@ -453,12 +453,12 @@ GTEST_TEST(itkTransformixFilter, Translation2D)
 
   const auto fixedImage = ImageType::New();
   fixedImage->SetRegions(imageSize);
-  fixedImage->Allocate(true);
+  fixedImage->AllocateInitialized();
   FillImageRegion(*fixedImage, fixedImageRegionIndex, regionSize);
 
   const auto movingImage = ImageType::New();
   movingImage->SetRegions(imageSize);
-  movingImage->Allocate(true);
+  movingImage->AllocateInitialized();
   FillImageRegion(*movingImage, fixedImageRegionIndex + translationOffset, regionSize);
 
   const auto transformedImage = TranslateImage(*movingImage, translationOffset);
@@ -467,10 +467,44 @@ GTEST_TEST(itkTransformixFilter, Translation2D)
 }
 
 
+// Tests translating a small (5x6) binary image, using a TransformParameterFileName.
+GTEST_TEST(itkTransformixFilter, Translation2DTransformParameterFileName)
+{
+  static constexpr auto ImageDimension = 2U;
+  using ImageType = itk::Image<float, ImageDimension>;
+  using SizeType = itk::Size<ImageDimension>;
+
+  const itk::Offset<ImageDimension> translationOffset{ { 1, -2 } };
+  const auto                        regionSize = SizeType::Filled(2);
+  const SizeType                    imageSize{ { 5, 6 } };
+  const itk::Index<ImageDimension>  fixedImageRegionIndex{ { 1, 3 } };
+
+  const auto fixedImage = ImageType::New();
+  fixedImage->SetRegions(imageSize);
+  fixedImage->AllocateInitialized();
+  FillImageRegion(*fixedImage, fixedImageRegionIndex, regionSize);
+
+  const auto movingImage = ImageType::New();
+  movingImage->SetRegions(imageSize);
+  movingImage->AllocateInitialized();
+  FillImageRegion(*movingImage, fixedImageRegionIndex + translationOffset, regionSize);
+
+  DefaultConstructibleTransformixFilter<ImageType> filter;
+
+  filter.SetMovingImage(movingImage);
+  filter.SetTransformParameterFileName(GetDataDirectoryPath() + "/Translation(1,-2)/TransformParameters-Size-5x6.txt");
+  filter.Update();
+
+
+  const auto transformedImage = filter.GetOutput();
+  ExpectEqualImages(*transformedImage, *fixedImage);
+}
+
+
 // Tests translating a mesh of two points.
 GTEST_TEST(itkTransformixFilter, MeshTranslation2D)
 {
-  constexpr auto ImageDimension = 2U;
+  static constexpr auto ImageDimension = 2U;
   using PixelType = float;
   using TransformixFilterType = itk::TransformixFilter<itk::Image<PixelType, ImageDimension>>;
   using VectorType = itk::Vector<float, ImageDimension>;
@@ -525,7 +559,7 @@ GTEST_TEST(itkTransformixFilter, MeshTranslation2D)
 // Tests translating a small (5x7x9) binary 3D image, having a 2x2x2 white cube.
 GTEST_TEST(itkTransformixFilter, Translation3D)
 {
-  constexpr auto ImageDimension = 3U;
+  static constexpr auto ImageDimension = 3U;
   using ImageType = itk::Image<float, ImageDimension>;
   using SizeType = itk::Size<ImageDimension>;
 
@@ -536,12 +570,12 @@ GTEST_TEST(itkTransformixFilter, Translation3D)
 
   const auto fixedImage = ImageType::New();
   fixedImage->SetRegions(imageSize);
-  fixedImage->Allocate(true);
+  fixedImage->AllocateInitialized();
   FillImageRegion(*fixedImage, fixedImageRegionIndex, regionSize);
 
   const auto movingImage = ImageType::New();
   movingImage->SetRegions(imageSize);
-  movingImage->Allocate(true);
+  movingImage->AllocateInitialized();
   FillImageRegion(*movingImage, fixedImageRegionIndex + translationOffset, regionSize);
 
   const auto transformedImage = TranslateImage(*movingImage, translationOffset);
@@ -552,7 +586,7 @@ GTEST_TEST(itkTransformixFilter, Translation3D)
 
 GTEST_TEST(itkTransformixFilter, TranslationViaExternalTransformFile)
 {
-  constexpr auto ImageDimension = 2U;
+  static constexpr auto ImageDimension = 2U;
   using PixelType = float;
 
   const itk::Offset<ImageDimension> translationOffset{ { 1, -2 } };
@@ -601,7 +635,7 @@ GTEST_TEST(itkTransformixFilter, BSplineViaExternalTransformFile)
 
 GTEST_TEST(itkTransformixFilter, ITKTranslationTransform2D)
 {
-  constexpr auto ImageDimension = 2U;
+  static constexpr auto ImageDimension = 2U;
 
   elx::DefaultConstruct<itk::TranslationTransform<double, ImageDimension>> itkTransform;
   itkTransform.SetOffset(itk::MakeVector(1.0, -2.0));
@@ -613,7 +647,7 @@ GTEST_TEST(itkTransformixFilter, ITKTranslationTransform2D)
 
 GTEST_TEST(itkTransformixFilter, ITKTranslationTransform3D)
 {
-  constexpr auto ImageDimension = 3U;
+  static constexpr auto ImageDimension = 3U;
 
   elx::DefaultConstruct<itk::TranslationTransform<double, ImageDimension>> itkTransform;
   itkTransform.SetOffset(itk::MakeVector(1.0, -2.0, 3.0));
@@ -625,7 +659,7 @@ GTEST_TEST(itkTransformixFilter, ITKTranslationTransform3D)
 
 GTEST_TEST(itkTransformixFilter, ITKAffineTransform2D)
 {
-  constexpr auto ImageDimension = 2U;
+  static constexpr auto ImageDimension = 2U;
 
   elx::DefaultConstruct<itk::AffineTransform<double, ImageDimension>> itkTransform;
   itkTransform.SetTranslation(itk::MakeVector(1.0, -2.0));
@@ -639,7 +673,7 @@ GTEST_TEST(itkTransformixFilter, ITKAffineTransform2D)
 
 GTEST_TEST(itkTransformixFilter, ITKAffineTransform3D)
 {
-  constexpr auto ImageDimension = 3U;
+  static constexpr auto ImageDimension = 3U;
 
   elx::DefaultConstruct<itk::AffineTransform<double, ImageDimension>> itkTransform;
   itkTransform.SetTranslation(itk::MakeVector(1.0, 2.0, 3.0));
@@ -733,9 +767,9 @@ GTEST_TEST(itkTransformixFilter, ITKBSplineTransform3D)
 
 GTEST_TEST(itkTransformixFilter, CombineTranslationAndDefaultTransform)
 {
-  const auto     imageSize = itk::MakeSize(5, 6);
-  const auto     inputImage = CreateImageFilledWithSequenceOfNaturalNumbers<float>(imageSize);
-  constexpr auto dimension = decltype(imageSize)::Dimension;
+  const auto            imageSize = itk::MakeSize(5, 6);
+  const auto            inputImage = CreateImageFilledWithSequenceOfNaturalNumbers<float>(imageSize);
+  static constexpr auto dimension = decltype(imageSize)::Dimension;
 
   using ParametersValueType = double;
 
@@ -745,7 +779,7 @@ GTEST_TEST(itkTransformixFilter, CombineTranslationAndDefaultTransform)
   const auto   resampleImageFilter = CreateResampleImageFilter(*inputImage, translationTransform);
   const auto & expectedOutputImage = Deref(resampleImageFilter->GetOutput());
 
-  const std::string initialTransformParametersFileName =
+  const std::string initialTransformParameterFileName =
     GetDataDirectoryPath() + "/Translation(1,-2)/TransformParameters.txt";
 
   for (const auto defaultTransform : { CreateTransform<itk::AffineTransform<ParametersValueType, dimension>>(),
@@ -755,7 +789,7 @@ GTEST_TEST(itkTransformixFilter, CombineTranslationAndDefaultTransform)
                                        CreateTransform<itk::TranslationTransform<ParametersValueType, dimension>>() })
   {
     const auto actualOutputImage =
-      RetrieveOutputFromTransformixFilter(*inputImage, *defaultTransform, initialTransformParametersFileName);
+      RetrieveOutputFromTransformixFilter(*inputImage, *defaultTransform, initialTransformParameterFileName);
     EXPECT_EQ(*actualOutputImage, expectedOutputImage);
   }
 
@@ -775,20 +809,17 @@ GTEST_TEST(itkTransformixFilter, CombineTranslationAndDefaultTransform)
 
 GTEST_TEST(itkTransformixFilter, CombineTranslationAndInverseTranslation)
 {
-  const auto imageSize = itk::MakeSize(5, 6);
-  enum
-  {
-    dimension = decltype(imageSize)::Dimension
-  };
+  const auto            imageSize = itk::MakeSize(5, 6);
+  static constexpr auto dimension = decltype(imageSize)::Dimension;
 
   const auto inputImage = itk::Image<float, dimension>::New();
   inputImage->SetRegions(imageSize);
-  inputImage->Allocate(true);
+  inputImage->AllocateInitialized();
   FillImageRegion(*inputImage, { 2, 1 }, itk::Size<dimension>::Filled(2));
 
   using ParametersValueType = double;
 
-  const std::string initialTransformParametersFileName =
+  const std::string initialTransformParameterFileName =
     GetDataDirectoryPath() + "/Translation(1,-2)/TransformParameters.txt";
 
   const auto offset = itk::MakeVector(1.0, -2.0);
@@ -798,7 +829,7 @@ GTEST_TEST(itkTransformixFilter, CombineTranslationAndInverseTranslation)
   // makes the output image unequal to the input image.
   const elx::DefaultConstruct<itk::TranslationTransform<ParametersValueType, dimension>> identityTransform;
 
-  EXPECT_NE(*(RetrieveOutputFromTransformixFilter(*inputImage, identityTransform, initialTransformParametersFileName)),
+  EXPECT_NE(*(RetrieveOutputFromTransformixFilter(*inputImage, identityTransform, initialTransformParameterFileName)),
             *inputImage);
 
   // The inverse of the transform from the TransformParameters.txt file.
@@ -809,7 +840,7 @@ GTEST_TEST(itkTransformixFilter, CombineTranslationAndInverseTranslation)
   }();
 
   EXPECT_EQ(*(RetrieveOutputFromTransformixFilter(
-              *inputImage, *inverseTranslationTransform, initialTransformParametersFileName)),
+              *inputImage, *inverseTranslationTransform, initialTransformParameterFileName)),
             *inputImage);
 
   for (const auto matrixOffsetTransform :
@@ -819,7 +850,7 @@ GTEST_TEST(itkTransformixFilter, CombineTranslationAndInverseTranslation)
   {
     matrixOffsetTransform->SetOffset(inverseOffset);
     EXPECT_EQ(
-      *(RetrieveOutputFromTransformixFilter(*inputImage, *matrixOffsetTransform, initialTransformParametersFileName)),
+      *(RetrieveOutputFromTransformixFilter(*inputImage, *matrixOffsetTransform, initialTransformParameterFileName)),
       *inputImage);
   }
 
@@ -835,23 +866,20 @@ GTEST_TEST(itkTransformixFilter, CombineTranslationAndInverseTranslation)
   }();
 
   const auto inverseBSplineOutputImage = RetrieveOutputFromTransformixFilter(
-    *inputImage, *inverseBSplineTransform, initialTransformParametersFileName, "Add");
+    *inputImage, *inverseBSplineTransform, initialTransformParameterFileName, "Add");
   ExpectAlmostEqualPixelValues(*inverseBSplineOutputImage, *inputImage, 1e-15);
 }
 
 
 GTEST_TEST(itkTransformixFilter, CombineTranslationAndScale)
 {
-  const auto imageSize = itk::MakeSize(5, 6);
-  enum
-  {
-    dimension = decltype(imageSize)::Dimension
-  };
-  const auto inputImage = CreateImageFilledWithSequenceOfNaturalNumbers<float>(imageSize);
+  const auto            imageSize = itk::MakeSize(5, 6);
+  static constexpr auto dimension = decltype(imageSize)::Dimension;
+  const auto            inputImage = CreateImageFilledWithSequenceOfNaturalNumbers<float>(imageSize);
 
   using ParametersValueType = double;
 
-  const std::string initialTransformParametersFileName =
+  const std::string initialTransformParameterFileName =
     GetDataDirectoryPath() + "/Translation(1,-2)/TransformParameters.txt";
 
   elx::DefaultConstruct<itk::AffineTransform<ParametersValueType, dimension>> scaleTransform;
@@ -861,7 +889,7 @@ GTEST_TEST(itkTransformixFilter, CombineTranslationAndScale)
   translationTransform.SetOffset(itk::MakeVector(1.0, -2.0));
 
   const auto transformixOutput =
-    RetrieveOutputFromTransformixFilter(*inputImage, scaleTransform, initialTransformParametersFileName);
+    RetrieveOutputFromTransformixFilter(*inputImage, scaleTransform, initialTransformParameterFileName);
 
   elx::DefaultConstruct<itk::CompositeTransform<double, 2>> translationAndScaleTransform;
   translationAndScaleTransform.AddTransform(&translationTransform);
@@ -887,9 +915,10 @@ GTEST_TEST(itkTransformixFilter, CombineTranslationAndScale)
 GTEST_TEST(itkTransformixFilter, OutputEqualsRegistrationOutputForStackTransform)
 {
   using PixelType = float;
+  static constexpr auto ImageDimension = 3U;
+
   enum
   {
-    ImageDimension = 3,
     imageSizeX = 5,
     imageSizeY = 6,
     imageSizeZ = 4
@@ -962,7 +991,7 @@ GTEST_TEST(itkTransformixFilter, OutputEqualsRegistrationOutputForBSplineStackTr
 GTEST_TEST(itkTransformixFilter, SetTranslationTransform)
 {
   using PixelType = float;
-  constexpr unsigned int ImageDimension{ 2 };
+  static constexpr unsigned int ImageDimension{ 2 };
 
   using SizeType = itk::Size<ImageDimension>;
   const itk::Offset<ImageDimension> translationOffset{ { 1, -2 } };
@@ -977,12 +1006,12 @@ GTEST_TEST(itkTransformixFilter, SetTranslationTransform)
 
   elx::DefaultConstruct<ImageType> fixedImage{};
   fixedImage.SetRegions(imageSize);
-  fixedImage.Allocate(true);
+  fixedImage.AllocateInitialized();
   FillImageRegion(fixedImage, fixedImageRegionIndex, regionSize);
 
   elx::DefaultConstruct<ImageType> movingImage{};
   movingImage.SetRegions(imageSize);
-  movingImage.Allocate(true);
+  movingImage.AllocateInitialized();
   FillImageRegion(movingImage, fixedImageRegionIndex + translationOffset, regionSize);
 
   elx::DefaultConstruct<itk::TranslationTransform<double, ImageDimension>> transform{};
@@ -1025,13 +1054,12 @@ GTEST_TEST(itkTransformixFilter, SetTranslationTransform)
 
 GTEST_TEST(itkTransformixFilter, SetCombinationTransform)
 {
-  constexpr auto ImageDimension = 2U;
+  static constexpr auto ImageDimension = 2U;
   using PixelType = float;
   using ImageType = itk::Image<PixelType, ImageDimension>;
   const itk::Size<ImageDimension> imageSize{ { 5, 6 } };
 
-  const auto numberOfPixels =
-    std::accumulate(imageSize.cbegin(), imageSize.cend(), std::size_t{ 1 }, std::multiplies<>{});
+  const auto numberOfPixels = imageSize.CalculateProductOfElements();
 
   const auto fixedImage = CreateImage<PixelType>(imageSize);
   const auto movingImage = CreateImage<PixelType>(imageSize);
@@ -1105,7 +1133,7 @@ GTEST_TEST(itkTransformixFilter, SetCombinationTransform)
 GTEST_TEST(itkTransformixFilter, UpdateThrowsExceptionOnZeroParameterMaps)
 {
   using PixelType = float;
-  constexpr unsigned int ImageDimension{ 2 };
+  static constexpr unsigned int ImageDimension{ 2 };
   using ImageType = itk::Image<PixelType, ImageDimension>;
   const auto imageSize = ImageType::SizeType::Filled(2);
 
@@ -1113,7 +1141,7 @@ GTEST_TEST(itkTransformixFilter, UpdateThrowsExceptionOnZeroParameterMaps)
   {
     elx::DefaultConstruct<ImageType> image{};
     image.SetRegions(imageSize);
-    image.Allocate(true);
+    image.AllocateInitialized();
 
     elx::DefaultConstruct<itk::TranslationTransform<double, ImageDimension>> transform{};
 
@@ -1129,7 +1157,7 @@ GTEST_TEST(itkTransformixFilter, UpdateThrowsExceptionOnZeroParameterMaps)
                                      { "Size", ConvertToParameterValues(imageSize) },
                                      { "Spacing", ParameterValuesType(ImageDimension, "1") } } };
 
-    transformParameterObject.SetParameterMap(parameterMaps);
+    transformParameterObject.SetParameterMaps(parameterMaps);
 
     elx::DefaultConstruct<itk::TransformixFilter<ImageType>> transformixFilter{};
     transformixFilter.SetMovingImage(&image);
@@ -1154,13 +1182,13 @@ GTEST_TEST(itkTransformixFilter, UpdateThrowsExceptionOnZeroParameterMaps)
 GTEST_TEST(itkTransformixFilter, UpdateThrowsExceptionOnEmptyCompositeTransform)
 {
   using PixelType = float;
-  constexpr unsigned int ImageDimension{ 2 };
+  static constexpr unsigned int ImageDimension{ 2 };
   using ImageType = itk::Image<PixelType, ImageDimension>;
   const itk::Size<ImageDimension> imageSize{ { 5, 6 } };
 
   elx::DefaultConstruct<ImageType> movingImage{};
   movingImage.SetRegions(imageSize);
-  movingImage.Allocate(true);
+  movingImage.AllocateInitialized();
 
   elx::DefaultConstruct<itk::TranslationTransform<double, ImageDimension>> translationTransform{};
   elx::DefaultConstruct<itk::CompositeTransform<double, ImageDimension>>   compositeTransform{};
@@ -1179,7 +1207,7 @@ GTEST_TEST(itkTransformixFilter, UpdateThrowsExceptionOnEmptyCompositeTransform)
                             { "Size", ConvertToParameterValues(imageSize) },
                             { "Spacing", ParameterValuesType(ImageDimension, "1") } }));
 
-  for (const bool isSecondIteration : { false, true })
+  for ([[maybe_unused]] const bool isSecondIteration : { false, true })
   {
     transformixFilter.SetTransform(&emptyCompositeTransform);
     EXPECT_THROW(transformixFilter.Update(), itk::ExceptionObject);
@@ -1195,8 +1223,8 @@ GTEST_TEST(itkTransformixFilter, UpdateThrowsExceptionOnEmptyCompositeTransform)
 GTEST_TEST(itkTransformixFilter, SetCompositeTransformOfTranslationAndScale)
 {
   using PixelType = float;
-  const auto             imageSize = itk::MakeSize(5, 6);
-  constexpr unsigned int ImageDimension{ decltype(imageSize)::Dimension };
+  const auto                    imageSize = itk::MakeSize(5, 6);
+  static constexpr unsigned int ImageDimension{ decltype(imageSize)::Dimension };
   using ImageType = itk::Image<PixelType, ImageDimension>;
 
   const auto inputImage = CreateImageFilledWithSequenceOfNaturalNumbers<PixelType>(imageSize);
@@ -1226,7 +1254,7 @@ GTEST_TEST(itkTransformixFilter, SetCompositeTransformOfTranslationAndScale)
   for (size_t numberOfParameterMaps{ 1 }; numberOfParameterMaps <= 3; ++numberOfParameterMaps)
   {
     elx::DefaultConstruct<elx::ParameterObject> transformParameterObject{};
-    transformParameterObject.SetParameterMap(ParameterMapVectorType(numberOfParameterMaps, transformParameterMap));
+    transformParameterObject.SetParameterMaps(ParameterMapVectorType(numberOfParameterMaps, transformParameterMap));
 
     elx::DefaultConstruct<itk::TransformixFilter<ImageType>> transformixFilter{};
     transformixFilter.SetMovingImage(inputImage);
@@ -1244,7 +1272,7 @@ GTEST_TEST(itkTransformixFilter, SetCompositeTransformOfTranslationAndScale)
 GTEST_TEST(itkTransformixFilter, ComputeSpatialJacobianDeterminantImage)
 {
   using PixelType = float;
-  constexpr unsigned int ImageDimension{ 2 };
+  static constexpr unsigned int ImageDimension{ 2 };
 
   using SizeType = itk::Size<ImageDimension>;
   const SizeType imageSize{ { 5, 6 } };
@@ -1254,7 +1282,7 @@ GTEST_TEST(itkTransformixFilter, ComputeSpatialJacobianDeterminantImage)
 
   elx::DefaultConstruct<ImageType> movingImage{};
   movingImage.SetRegions(imageSize);
-  movingImage.Allocate(true);
+  movingImage.AllocateInitialized();
 
   elx::DefaultConstruct<itk::TranslationTransform<double, ImageDimension>> transform{};
   transform.SetOffset(itk::MakeVector(1.0, -2.0));
@@ -1291,3 +1319,252 @@ GTEST_TEST(itkTransformixFilter, ComputeSpatialJacobianDeterminantImage)
     EXPECT_EQ(matrix, expectedMatrix);
   }
 }
+
+
+// Checks a minimum size moving image having the same pixel type as any of the supported internal pixel types.
+GTEST_TEST(itkTransformixFilter, CheckMinimumMovingImageHavingInternalPixelType)
+{
+  elx::ForEachSupportedImageType([](const auto elxTypedef) {
+    using ElxTypedef = decltype(elxTypedef);
+    using ImageType = typename ElxTypedef::MovingImageType;
+    static constexpr auto ImageDimension = ElxTypedef::MovingDimension;
+
+    using PixelType = typename ImageType::PixelType;
+    using SizeType = itk::Size<ImageDimension>;
+
+    const ImageDomain<ElxTypedef::MovingDimension> imageDomain(
+      itk::Size<ElxTypedef::MovingDimension>::Filled(minimumImageSizeValue));
+
+    elx::DefaultConstruct<ImageType> movingImage{};
+    imageDomain.ToImage(movingImage);
+    movingImage.AllocateInitialized();
+
+    // Some "extreme" values to test if each of them is preserved during the transformation.
+    const std::array pixelValues{ PixelType{},
+                                  PixelType{ 1 },
+                                  std::numeric_limits<PixelType>::lowest(),
+                                  std::numeric_limits<PixelType>::min(),
+                                  PixelType{ std::numeric_limits<PixelType>::max() - 1 },
+                                  std::numeric_limits<PixelType>::max() };
+    std::copy(pixelValues.cbegin(), pixelValues.cend(), itk::ImageBufferRange<ImageType>(movingImage).begin());
+
+    const ParameterMapType parameterMap = MakeMergedMap(
+      { // Parameters in alphabetic order:
+        { "FixedInternalImagePixelType", { ElxTypedef::FixedPixelTypeString } },
+        { "MovingInternalImagePixelType", { ElxTypedef::MovingPixelTypeString } },
+        { "ResampleInterpolator", { "FinalLinearInterpolator" } } },
+      imageDomain.AsParameterMap());
+
+    const elx::DefaultConstruct<itk::TranslationTransform<double, ImageType::ImageDimension>> identityTransform{};
+    elx::DefaultConstruct<itk::TransformixFilter<ImageType>>                                  transformixFilter{};
+
+    transformixFilter.SetMovingImage(&movingImage);
+    transformixFilter.SetTransform(&identityTransform);
+    transformixFilter.SetTransformParameterObject(CreateParameterObject(parameterMap));
+    transformixFilter.Update();
+
+    EXPECT_EQ(Deref(transformixFilter.GetOutput()), movingImage);
+  });
+}
+
+
+// Checks a zero-filled moving image with a random domain, having the same pixel type as any of the supported internal
+// pixel types.
+GTEST_TEST(itkTransformixFilter, CheckZeroFilledMovingImageWithRandomDomainHavingInternalPixelType)
+{
+  std::mt19937 randomNumberEngine{};
+
+  elx::ForEachSupportedImageType([&randomNumberEngine](const auto elxTypedef) {
+    using ElxTypedef = decltype(elxTypedef);
+    using ImageType = typename ElxTypedef::MovingImageType;
+    static constexpr auto ImageDimension = ElxTypedef::MovingDimension;
+
+    using PixelType = typename ImageType::PixelType;
+    using SizeType = itk::Size<ImageDimension>;
+
+    const auto imageDomain = CreateRandomImageDomain<ElxTypedef::MovingDimension>(randomNumberEngine);
+
+    elx::DefaultConstruct<ImageType> movingImage{};
+    imageDomain.ToImage(movingImage);
+    movingImage.AllocateInitialized();
+
+    const ParameterMapType parameterMap = MakeMergedMap(
+      { // Parameters in alphabetic order:
+        { "FixedInternalImagePixelType", { ElxTypedef::FixedPixelTypeString } },
+        { "MovingInternalImagePixelType", { ElxTypedef::MovingPixelTypeString } },
+        { "ResampleInterpolator", { "FinalLinearInterpolator" } } },
+      imageDomain.AsParameterMap());
+
+    const elx::DefaultConstruct<itk::TranslationTransform<double, ImageType::ImageDimension>> identityTransform{};
+    elx::DefaultConstruct<itk::TransformixFilter<ImageType>>                                  transformixFilter{};
+
+    transformixFilter.SetMovingImage(&movingImage);
+    transformixFilter.SetTransform(&identityTransform);
+    transformixFilter.SetTransformParameterObject(CreateParameterObject(parameterMap));
+    transformixFilter.Update();
+
+    EXPECT_EQ(Deref(transformixFilter.GetOutput()), movingImage);
+  });
+}
+
+
+// Checks a minimum size moving image using any supported internal pixel type (which may be different from the input
+// pixel type).
+GTEST_TEST(itkTransformixFilter, CheckMinimumMovingImageUsingAnyInternalPixelType)
+{
+  const auto check = [](const auto inputPixelTypeHolder) {
+    (void)inputPixelTypeHolder;
+    elx::ForEachSupportedImageType([](const auto elxTypedef) {
+      using ElxTypedef = decltype(elxTypedef);
+      using InputPixelType = typename decltype(inputPixelTypeHolder)::Type;
+      using InputImageType = itk::Image<InputPixelType, ElxTypedef::MovingDimension>;
+
+      const ImageDomain<ElxTypedef::MovingDimension> imageDomain(
+        itk::Size<ElxTypedef::MovingDimension>::Filled(minimumImageSizeValue));
+      const auto movingImage = CreateImageFilledWithSequenceOfNaturalNumbers<InputPixelType>(imageDomain);
+
+      const ParameterMapType parameterMap = MakeMergedMap(
+        { // Parameters in alphabetic order:
+          { "FixedInternalImagePixelType", { ElxTypedef::FixedPixelTypeString } },
+          { "MovingInternalImagePixelType", { ElxTypedef::MovingPixelTypeString } },
+          { "ResampleInterpolator", { "FinalLinearInterpolator" } } },
+        imageDomain.AsParameterMap());
+
+      const elx::DefaultConstruct<itk::TranslationTransform<double, ElxTypedef::MovingDimension>> identityTransform{};
+      elx::DefaultConstruct<itk::TransformixFilter<InputImageType>>                               transformixFilter{};
+
+      transformixFilter.SetMovingImage(movingImage);
+      transformixFilter.SetTransform(&identityTransform);
+      transformixFilter.SetTransformParameterObject(CreateParameterObject(parameterMap));
+      transformixFilter.Update();
+
+      EXPECT_EQ(Deref(transformixFilter.GetOutput()), DerefSmartPointer(movingImage));
+    });
+  };
+
+  check(TypeHolder<char>{});
+  check(TypeHolder<unsigned long>{});
+  check(TypeHolder<double>{});
+}
+
+// Checks a zero-filled moving image with a random domain, using any supported internal pixel type (which may be
+// different from the input pixel type).
+GTEST_TEST(itkTransformixFilter, CheckZeroFilledMovingImageWithRandomDomainUsingAnyInternalPixelType)
+{
+  std::mt19937 randomNumberEngine{};
+
+  const auto check = [&randomNumberEngine](const auto inputPixelTypeHolder) {
+    (void)inputPixelTypeHolder;
+    elx::ForEachSupportedImageType([&randomNumberEngine](const auto elxTypedef) {
+      using ElxTypedef = decltype(elxTypedef);
+      using InputPixelType = typename decltype(inputPixelTypeHolder)::Type;
+      using InputImageType = itk::Image<InputPixelType, ElxTypedef::MovingDimension>;
+
+      const auto imageDomain = CreateRandomImageDomain<ElxTypedef::MovingDimension>(randomNumberEngine);
+      elx::DefaultConstruct<InputImageType> movingImage{};
+      imageDomain.ToImage(movingImage);
+      movingImage.AllocateInitialized();
+
+      const ParameterMapType parameterMap = MakeMergedMap(
+        { // Parameters in alphabetic order:
+          { "FixedInternalImagePixelType", { ElxTypedef::FixedPixelTypeString } },
+          { "MovingInternalImagePixelType", { ElxTypedef::MovingPixelTypeString } },
+          { "ResampleInterpolator", { "FinalLinearInterpolator" } } },
+        imageDomain.AsParameterMap());
+
+      const elx::DefaultConstruct<itk::TranslationTransform<double, ElxTypedef::MovingDimension>> identityTransform{};
+      elx::DefaultConstruct<itk::TransformixFilter<InputImageType>>                               transformixFilter{};
+
+      transformixFilter.SetMovingImage(&movingImage);
+      transformixFilter.SetTransform(&identityTransform);
+      transformixFilter.SetTransformParameterObject(CreateParameterObject(parameterMap));
+      transformixFilter.Update();
+
+      EXPECT_EQ(Deref(transformixFilter.GetOutput()), movingImage);
+    });
+  };
+
+  check(TypeHolder<char>{});
+  check(TypeHolder<unsigned long>{});
+  check(TypeHolder<double>{});
+}
+
+
+GTEST_TEST(itkTransformixFilter, ExternalTransform)
+{
+  static constexpr unsigned int ImageDimension{ 2 };
+
+  using PixelType = float;
+  using SizeType = itk::Size<ImageDimension>;
+  const SizeType imageSize{ { 5, 6 } };
+
+  using ImageType = itk::Image<PixelType, ImageDimension>;
+  using TransformixFilterType = itk::TransformixFilter<ImageType>;
+
+  const ImageDomain<ImageDimension> imageDomain(imageSize);
+  const auto                        movingImage = CreateImageFilledWithSequenceOfNaturalNumbers<PixelType>(imageDomain);
+
+  elx::DefaultConstruct<itk::TranslationTransform<double, ImageDimension>> itkTransform;
+  itkTransform.SetOffset(itk::MakeVector(1.0, -2.0));
+
+  elx::DefaultConstruct<TransformixFilterType> transformixFilter{};
+  transformixFilter.SetMovingImage(movingImage);
+  transformixFilter.SetTransformParameterObject(CreateParameterObject(MakeMergedMap(
+    { // Parameters in alphabetic order:
+      { "ResampleInterpolator", { "FinalLinearInterpolator" } },
+      { "Transform", ParameterValuesType{ "ExternalTransform" } },
+      { "TransformAddress", { elx::Conversion::ObjectPtrToString(&itkTransform) } } },
+    imageDomain.AsParameterMap())));
+  transformixFilter.Update();
+
+  const auto resampleImageFilter = CreateResampleImageFilter(*movingImage, itkTransform);
+
+  EXPECT_EQ(Deref(transformixFilter.GetOutput()), Deref(resampleImageFilter->GetOutput()));
+}
+
+GTEST_TEST(itkTransformixFilter, SetExternalTransform)
+{
+  static constexpr auto ImageDimension = 2U;
+  using PixelType = float;
+  using SizeType = itk::Size<ImageDimension>;
+  const SizeType imageSize{ { 5, 6 } };
+
+  using ImageType = itk::Image<PixelType, ImageDimension>;
+  using TransformixFilterType = itk::TransformixFilter<ImageType>;
+
+  const ImageDomain<ImageDimension> imageDomain(imageSize);
+  const auto                        movingImage = CreateImageFilledWithSequenceOfNaturalNumbers<PixelType>(imageDomain);
+
+  const auto displacementField = itk::Image<itk::Vector<double, ImageDimension>, ImageDimension>::New();
+
+  displacementField->SetRegions(imageSize);
+  displacementField->AllocateInitialized();
+
+  std::mt19937 randomNumberEngine{};
+
+  // Generate a rather arbitrary displacement field.
+  const itk::ImageBufferRange displacementFieldImageBufferRange{ *displacementField };
+  std::generate_n(
+    displacementFieldImageBufferRange.begin(), displacementFieldImageBufferRange.size(), [&randomNumberEngine] {
+      itk::Vector<double, ImageDimension> displacementVector{};
+
+      std::generate_n(displacementVector.begin(), ImageDimension, [&randomNumberEngine] {
+        return std::uniform_int_distribution<>{ -1, 1 }(randomNumberEngine);
+      });
+      return displacementVector;
+    });
+
+  elx::DefaultConstruct<itk::DisplacementFieldTransform<double, ImageDimension>> itkTransform{};
+  itkTransform.SetDisplacementField(displacementField);
+
+  elx::DefaultConstruct<TransformixFilterType> transformixFilter{};
+  transformixFilter.SetMovingImage(movingImage);
+  transformixFilter.SetExternalTransform(&itkTransform);
+  transformixFilter.SetTransformParameterObject(CreateParameterObject(
+    MakeMergedMap({ { "ResampleInterpolator", { "FinalLinearInterpolator" } } }, imageDomain.AsParameterMap())));
+  transformixFilter.Update();
+
+  const auto resampleImageFilter = CreateResampleImageFilter(*movingImage, itkTransform);
+
+  EXPECT_EQ(Deref(transformixFilter.GetOutput()), Deref(resampleImageFilter->GetOutput()));
+}
