@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __elastixlib_h
-#define __elastixlib_h
+#ifndef elastixlib_h
+#define elastixlib_h
 
 /*
  *  Includes
@@ -39,18 +39,18 @@ namespace elastix
 class ELASTIXLIB_API ELASTIX
 {
 public:
+  // typedefs for images
+  using Image = itk::DataObject;
+  using ImagePointer = Image::Pointer;
+  using ConstImagePointer = Image::ConstPointer;
 
-  //typedefs for images
-  typedef itk::DataObject Image;
-  typedef Image::Pointer  ImagePointer;
+  // typedefs for parameter map
+  using ParameterValuesType = itk::ParameterFileParser::ParameterValuesType;
+  using ParameterMapType = itk::ParameterFileParser::ParameterMapType;
+  using ParameterMapListType = std::vector<itk::ParameterFileParser::ParameterMapType>;
 
-  //typedefs for parameter map
-  typedef itk::ParameterFileParser::ParameterValuesType             ParameterValuesType;
-  typedef itk::ParameterFileParser::ParameterMapType                ParameterMapType;
-  typedef std::vector< itk::ParameterFileParser::ParameterMapType > ParameterMapListType;
-
-  //typedefs for ObjectPointer
-  typedef elastix::ElastixMain::ObjectPointer              ObjectPointer;
+  // typedefs for ObjectPointer
+  using ObjectPointer = elastix::ElastixMain::ObjectPointer;
 
   /**
    *  Constructor and destructor
@@ -81,44 +81,51 @@ public:
    *     1 = error
    *    -2 = output folder does not exist
    *    \todo generate file elastix_errors.h containing error codedefines
-   *      (e.g. #define ELASTIX_NO_ERROR 0)
+   *      (e.g. \#define ELASTIX_NO_ERROR 0)
    */
-  int RegisterImages( ImagePointer fixedImage,
-    ImagePointer movingImage,
-    const ParameterMapType & parameterMap,
-    const std::string & outputPath,
-    bool performLogging,
-    bool performCout,
-    ImagePointer fixedMask = nullptr,
-    ImagePointer movingMask = nullptr );
+  int
+  RegisterImages(ImagePointer             fixedImage,
+                 ImagePointer             movingImage,
+                 const ParameterMapType & parameterMap,
+                 const std::string &      outputPath,
+                 bool                     performLogging,
+                 bool                     performCout,
+                 ImagePointer             fixedMask = nullptr,
+                 ImagePointer             movingMask = nullptr);
 
-  int RegisterImages( ImagePointer fixedImage,
-    ImagePointer movingImage,
-    const std::vector< ParameterMapType > & parameterMaps,
-    const std::string & outputPath,
-    bool performLogging,
-    bool performCout,
-    ImagePointer fixedMask = nullptr,
-    ImagePointer movingMask = nullptr,
-    ObjectPointer transform = nullptr);
+  int
+  RegisterImages(ImagePointer                          fixedImage,
+                 ImagePointer                          movingImage,
+                 const std::vector<ParameterMapType> & parameterMaps,
+                 const std::string &                   outputPath,
+                 bool                                  performLogging,
+                 bool                                  performCout,
+                 ImagePointer                          fixedMask = nullptr,
+                 ImagePointer                          movingMask = nullptr,
+                 ObjectPointer                         transform = nullptr);
 
   /** Getter for result image. */
-  ImagePointer GetResultImage( void );
+  ConstImagePointer
+  GetResultImage() const;
+
+  /** Getter for result image. Non-const overload */
+  ImagePointer
+  GetResultImage();
 
   /** Get transform parameters of last registration step. */
-  ParameterMapType GetTransformParameterMap( void );
+  ParameterMapType
+  GetTransformParameterMap() const;
 
   /** Get transform parameters of all registration steps. */
-  ParameterMapListType GetTransformParameterMapList( void );
+  ParameterMapListType
+  GetTransformParameterMapList() const;
 
 private:
-
   /* the result images */
   ImagePointer m_ResultImage;
 
   /* Final transformation*/
   ParameterMapListType m_TransformParametersList;
-
 };
 
 // end class ELASTIX
