@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __transformixlib_h
-#define __transformixlib_h
+#ifndef transformixlib_h
+#define transformixlib_h
 
 /**
  *  Includes
@@ -36,15 +36,15 @@ namespace transformix
 class ELASTIXLIB_API TRANSFORMIX
 {
 public:
+  // typedefs for images
+  using Image = itk::DataObject;
+  using ImagePointer = Image::Pointer;
+  using ConstImagePointer = Image::ConstPointer;
 
-  //typedefs for images
-  typedef itk::DataObject Image;
-  typedef Image::Pointer  ImagePointer;
-
-  //typedefs for parameter map
-  typedef itk::ParameterFileParser::ParameterValuesType             ParameterValuesType;
-  typedef itk::ParameterFileParser::ParameterMapType                ParameterMapType;
-  typedef std::vector< itk::ParameterFileParser::ParameterMapType > ParameterMapListType;
+  // typedefs for parameter map
+  using ParameterValuesType = itk::ParameterFileParser::ParameterValuesType;
+  using ParameterMapType = itk::ParameterFileParser::ParameterMapType;
+  using ParameterMapListType = std::vector<itk::ParameterFileParser::ParameterMapType>;
 
   /** Constructor and destructor. */
   TRANSFORMIX();
@@ -55,34 +55,39 @@ public:
    *    1 = error
    *   -2 = output folder does not exist
    */
-  int TransformImage( ImagePointer inputImage,
-    ParameterMapType & parameterMap,
-    std::string outputPath,
-    bool performLogging,
-    bool performCout );
+  int
+  TransformImage(ImagePointer       inputImage,
+                 ParameterMapType & parameterMap,
+                 std::string        outputPath,
+                 bool               performLogging,
+                 bool               performCout);
 
   /** Return value: 0 is success in case not 0 an error occurred
    *    0 = success
    *    1 = error
    *   -2 = output folder does not exist
    */
-  int TransformImage( ImagePointer inputImage,
-    std::vector< ParameterMapType > & parameterMaps,
-    std::string outputPath,
-    bool performLogging,
-    bool performCout );
+  int
+  TransformImage(ImagePointer                    inputImage,
+                 std::vector<ParameterMapType> & parameterMaps,
+                 const std::string &             outputPath,
+                 bool                            performLogging,
+                 bool                            performCout);
 
   /** Getter for result image. */
-  ImagePointer GetResultImage( void );
+  ConstImagePointer
+  GetResultImage() const;
+
+  /** Getter for result image. Non-const overload */
+  ImagePointer
+  GetResultImage();
 
 private:
-
   ImagePointer m_ResultImage;
-
 };
 
 // end class TRANSFORMIX
 
 } // namespace transformix
 
-#endif // end #ifndef __transformixlib_h
+#endif // end #ifndef transformixlib_h
