@@ -95,8 +95,7 @@ main(int argc, char * argv[])
   gridSize[0] = 44;
   gridSize[1] = 43;
   gridSize[2] = 35;
-  IndexType gridIndex;
-  gridIndex.Fill(0);
+  IndexType  gridIndex{};
   RegionType gridRegion;
   gridRegion.SetSize(gridSize);
   gridRegion.SetIndex(gridIndex);
@@ -162,7 +161,7 @@ main(int argc, char * argv[])
 
   /** Resize some of the variables. */
   nzji.resize(nonzji);
-  jacobian.SetSize(Dimension, nonzji);
+  jacobian.set_size(Dimension, nonzji);
   jacobianOfSpatialJacobian.resize(nonzji);
   jacobianOfSpatialHessian.resize(nonzji);
   jacobian.Fill(0.0);
@@ -331,12 +330,11 @@ main(int argc, char * argv[])
     return 1;
   }
 
-  JacobianType jacobianITK;
-  jacobianITK.Fill(0.0);
+  JacobianType jacobianITK{};
   transformITK->ComputeJacobianWithRespectToParameters(inputPoint, jacobianITK);
   JacobianType jacobianElastix;
-  jacobianElastix.SetSize(Dimension, nzji.size());
-  jacobianElastix.Fill(0.0);
+  jacobianElastix.set_size(Dimension, nzji.size());
+  jacobianElastix.fill(0.0);
   transform->GetJacobian(inputPoint, jacobianElastix, nzji);
   // ITK4 B-spline is non-local and returns a full matrix. Cannot compute diff like this anymore:
   // JacobianType jacobianDifferenceMatrix = jacobianElastix - jacobianITK;
@@ -358,8 +356,8 @@ main(int argc, char * argv[])
 
   //// Check
   // JacobianType jacobian1, jacobian2;
-  // jacobian1.SetSize( Dimension, nzji.size() ); jacobian2.SetSize( Dimension, nzji.size() );
-  // jacobian1.Fill( 0.0 ); jacobian2.Fill( 0.0 );
+  // jacobian1.set_size( Dimension, nzji.size() ); jacobian2.set_size( Dimension, nzji.size() );
+  // jacobian1.fill( 0.0 ); jacobian2.Fill( 0.0 );
   // transform->GetJacobian( inputPoint, jacobian1, nzji );
   // transform->GetJacobian_opt( inputPoint, jacobian2, nzji );
   // JacobianType jacobianDifferenceMatrix = jacobian1 - jacobian2;
