@@ -120,8 +120,7 @@ main(int argc, char * argv[])
   // gridSize[ 0 ] = 44; gridSize[ 1 ] = 43; gridSize[ 2 ] = 35;
   // gridSize[ 0 ] = 68; gridSize[ 1 ] = 69; gridSize[ 2 ] = 64;
 
-  IndexType gridIndex;
-  gridIndex.Fill(0);
+  IndexType  gridIndex{};
   RegionType gridRegion;
   gridRegion.SetSize(gridSize);
   gridRegion.SetIndex(gridIndex);
@@ -193,7 +192,7 @@ main(int argc, char * argv[])
 
   /** Resize some of the variables. */
   nzji.resize(nonzji);
-  jacobian.SetSize(Dimension, nonzji);
+  jacobian.set_size(Dimension, nonzji);
   jacobianOfSpatialJacobian.resize(nonzji);
   jacobianOfSpatialHessian.resize(nonzji);
   jacobian.Fill(0.0);
@@ -386,13 +385,13 @@ main(int argc, char * argv[])
 
   /** Jacobian. */
   JacobianType jacobianElastix;
-  jacobianElastix.SetSize(Dimension, nzji.size());
-  jacobianElastix.Fill(0.0);
+  jacobianElastix.set_size(Dimension, nzji.size());
+  jacobianElastix.fill(0.0);
   transform->GetJacobian(inputPoint, jacobianElastix, nzjiElastix);
 
   JacobianType jacobianRecursive;
-  jacobianRecursive.SetSize(Dimension, nzji.size());
-  jacobianRecursive.Fill(0.0);
+  jacobianRecursive.set_size(Dimension, nzji.size());
+  jacobianRecursive.fill(0.0);
   recursiveTransform->GetJacobian(inputPoint, jacobianRecursive, nzjiRecursive);
 
   JacobianType jacobianDifferenceMatrix = jacobianElastix - jacobianRecursive;
