@@ -90,8 +90,7 @@ main(int argc, char * argv[])
   gridSize[0] = 44;
   gridSize[1] = 43;
   gridSize[2] = 35;
-  IndexType gridIndex;
-  gridIndex.Fill(0);
+  IndexType  gridIndex{};
   RegionType gridRegion;
   gridRegion.SetSize(gridSize);
   gridRegion.SetIndex(gridIndex);
