@@ -85,7 +85,7 @@ public:
     /** Check if the coefficient image has been set. */
     if (!this->m_CoefficientImages[0])
     {
-      itkWarningMacro(<< "B-spline coefficients have not been set");
+      itkWarningMacro("B-spline coefficients have not been set");
       for (unsigned int j = 0; j < SpaceDimension; ++j)
       {
         outputPoint[j] = transformedPoint[j];
@@ -112,10 +112,10 @@ public:
 
     // For each dimension, correlate coefficient with weights
     RegionType supportRegion;
-    supportRegion.SetSize(this->m_SupportSize);
+    supportRegion.SetSize(WeightsFunctionType::SupportSize);
     supportRegion.SetIndex(supportIndex);
 
-    outputPoint.Fill(NumericTraits<ScalarType>::ZeroValue());
+    outputPoint.Fill(ScalarType{});
 
     /** Create iterators over the coefficient images. */
     using IteratorType = ImageRegionConstIterator<ImageType>;
@@ -214,8 +214,7 @@ main(int argc, char * argv[])
   gridSize[0] = 44;
   gridSize[1] = 43;
   gridSize[2] = 35;
-  IndexType gridIndex;
-  gridIndex.Fill(0);
+  IndexType  gridIndex{};
   RegionType gridRegion;
   gridRegion.SetSize(gridSize);
   gridRegion.SetIndex(gridIndex);
