@@ -21,6 +21,8 @@
 #include "itkGPUImageFactory.h"
 #include "itkGPUCastImageFilterFactory.h"
 
+#include "itkOpenCLContextScopeGuard.h"
+
 // ITK include files
 #include "itkImageFileReader.h"
 #include "itkImageFileWriter.h"
@@ -35,10 +37,10 @@
 // We compare the CPU and GPU output image write RMSE and speed.
 
 int
-main( int argc, char * argv[] )
+main(int argc, char * argv[])
 {
   // Check arguments for help
-  if( argc < 4 )
+  if (argc < 4)
   {
     std::cerr << "ERROR: insufficient command line arguments.\n"
               << "  inputFileName outputNameCPU outputNameGPU" << std::endl;
@@ -49,40 +51,40 @@ main( int argc, char * argv[] )
   itk::SetupForDebugging();
 
   // Create and check OpenCL context
-  if( !itk::CreateContext() )
+  if (!itk::CreateContext())
   {
     return EXIT_FAILURE;
   }
+  const itk::OpenCLContextScopeGuard openCLContextScopeGuard{};
 
   /** Get the command line arguments. */
-  std::string        inputFileName     = argv[ 1 ];
-  std::string        outputFileNameCPU = argv[ 2 ];
-  std::string        outputFileNameGPU = argv[ 3 ];
-  const double       epsilon           = 1e-3;
-  const unsigned int runTimes          = 5;
+  std::string        inputFileName = argv[1];
+  std::string        outputFileNameCPU = argv[2];
+  std::string        outputFileNameGPU = argv[3];
+  const double       epsilon = 1e-3;
+  const unsigned int runTimes = 5;
 
-  std::cout << std::showpoint << std::setprecision( 4 );
+  std::cout << std::showpoint << std::setprecision(4);
 
   // Typedefs.
   const unsigned int Dimension = 3;
-  typedef short                                    InputPixelType;
-  typedef float                                    OutputPixelType;
-  typedef itk::Image< InputPixelType, Dimension >  InputImageType;
-  typedef itk::Image< OutputPixelType, Dimension > OutputImageType;
+  using InputPixelType = short;
+  using OutputPixelType = float;
+  using InputImageType = itk::Image<InputPixelType, Dimension>;
+  using OutputImageType = itk::Image<OutputPixelType, Dimension>;
 
   // CPU Typedefs
-  typedef itk::CastImageFilter
-    < InputImageType, OutputImageType >           FilterType;
-  typedef itk::ImageFileReader< InputImageType >  ReaderType;
-  typedef itk::ImageFileWriter< OutputImageType > WriterType;
+  using FilterType = itk::CastImageFilter<InputImageType, OutputImageType>;
+  using ReaderType = itk::ImageFileReader<InputImageType>;
+  using WriterType = itk::ImageFileWriter<OutputImageType>;
 
   // Reader
-  ReaderType::Pointer reader = ReaderType::New();
-  reader->SetFileName( inputFileName );
+  auto reader = ReaderType::New();
+  reader->SetFileName(inputFileName);
   reader->Update();
 
   // Construct the filter
-  FilterType::Pointer cpuFilter = FilterType::New();
+  auto cpuFilter = FilterType::New();
 
   std::cout << "Testing the CastImageFilter, CPU vs GPU:\n";
   std::cout << "CPU/GPU splineOrder #threads time speedup RMSE\n";
@@ -90,55 +92,49 @@ main( int argc, char * argv[] )
   // Time the filter, run on the CPU
   itk::TimeProbe cputimer;
   cputimer.Start();
-  for( unsigned int i = 0; i < runTimes; i++ )
+  for (unsigned int i = 0; i < runTimes; ++i)
   {
-    cpuFilter->SetInput( reader->GetOutput() );
+    cpuFilter->SetInput(reader->GetOutput());
     try
     {
       cpuFilter->Update();
     }
-    catch( itk::ExceptionObject & e )
+    catch (itk::ExceptionObject & e)
     {
       std::cerr << "ERROR: " << e << std::endl;
-      itk::ReleaseContext();
       return EXIT_FAILURE;
     }
 
     // Modify the filter, only not the last iteration
-    if( i != runTimes - 1 )
+    if (i != runTimes - 1)
     {
       cpuFilter->Modified();
     }
   }
   cputimer.Stop();
 
-  std::cout << "CPU "
-            << cpuFilter->GetNumberOfWorkUnits()
-            << " " << cputimer.GetMean() / runTimes << std::endl;
+  std::cout << "CPU " << cpuFilter->GetNumberOfWorkUnits() << " " << cputimer.GetMean() / runTimes << std::endl;
 
   /** Write the CPU result. */
-  WriterType::Pointer writer = WriterType::New();
-  writer->SetInput( cpuFilter->GetOutput() );
-  writer->SetFileName( outputFileNameCPU.c_str() );
+  auto writer = WriterType::New();
+  writer->SetInput(cpuFilter->GetOutput());
+  writer->SetFileName(outputFileNameCPU.c_str());
   try
   {
     writer->Update();
   }
-  catch( itk::ExceptionObject & e )
+  catch (itk::ExceptionObject & e)
   {
     std::cerr << "ERROR: " << e << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
 
   // Register object factory for GPU image and filter
   // All these filters that are constructed after this point are
   // turned into a GPU filter.
-  typedef typelist::MakeTypeList< short, float >::Type OCLImageTypes;
-  itk::GPUImageFactory2< OCLImageTypes, OCLImageDims >
-  ::RegisterOneFactory();
-  itk::GPUCastImageFilterFactory2< OCLImageTypes, OCLImageTypes, OCLImageDims >
-  ::RegisterOneFactory();
+  using OCLImageTypes = typelist::MakeTypeList<short, float>::Type;
+  itk::GPUImageFactory2<OCLImageTypes, OCLImageDims>::RegisterOneFactory();
+  itk::GPUCastImageFilterFactory2<OCLImageTypes, OCLImageTypes, OCLImageDims>::RegisterOneFactory();
 
   // Construct the filter
   // Use a try/catch, because construction of this filter will trigger
@@ -147,12 +143,11 @@ main( int argc, char * argv[] )
   try
   {
     gpuFilter = FilterType::New();
-    itk::ITKObjectEnableWarnings( gpuFilter.GetPointer() );
+    itk::ITKObjectEnableWarnings(gpuFilter.GetPointer());
   }
-  catch( itk::ExceptionObject & e )
+  catch (itk::ExceptionObject & e)
   {
     std::cerr << "ERROR: " << e << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
 
@@ -160,66 +155,61 @@ main( int argc, char * argv[] )
   // reads a GPUImage instead of a normal image.
   // Otherwise, you will get an exception when running the GPU filter:
   // "ERROR: The GPU InputImage is NULL. Filter unable to perform."
-  ReaderType::Pointer gpuReader = ReaderType::New();
-  gpuReader->SetFileName( inputFileName );
+  auto gpuReader = ReaderType::New();
+  gpuReader->SetFileName(inputFileName);
 
   // Time the filter, run on the GPU
   itk::TimeProbe gputimer;
   gputimer.Start();
-  for( unsigned int i = 0; i < runTimes; i++ )
+  for (unsigned int i = 0; i < runTimes; ++i)
   {
-    gpuFilter->SetInput( gpuReader->GetOutput() );
+    gpuFilter->SetInput(gpuReader->GetOutput());
     try
     {
       gpuFilter->Update();
     }
-    catch( itk::ExceptionObject & e )
+    catch (itk::ExceptionObject & e)
     {
       std::cerr << "ERROR: " << e << std::endl;
-      itk::ReleaseContext();
       return EXIT_FAILURE;
     }
     // Modify the filter, only not the last iteration
-    if( i != runTimes - 1 )
+    if (i != runTimes - 1)
     {
       gpuFilter->Modified();
     }
   }
   gputimer.Stop();
 
-  std::cout << "GPU x " << gputimer.GetMean() / runTimes
-            << " " << cputimer.GetMean() / gputimer.GetMean();
+  std::cout << "GPU x " << gputimer.GetMean() / runTimes << " " << cputimer.GetMean() / gputimer.GetMean();
 
   /** Write the GPU result. */
-  WriterType::Pointer gpuWriter = WriterType::New();
-  gpuWriter->SetInput( gpuFilter->GetOutput() );
-  gpuWriter->SetFileName( outputFileNameGPU.c_str() );
+  auto gpuWriter = WriterType::New();
+  gpuWriter->SetInput(gpuFilter->GetOutput());
+  gpuWriter->SetFileName(outputFileNameGPU.c_str());
   try
   {
     gpuWriter->Update();
   }
-  catch( itk::ExceptionObject & e )
+  catch (itk::ExceptionObject & e)
   {
     std::cerr << "ERROR: " << e << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
 
   // Compute RMSE
   double       RMSrelative = 0.0;
-  const double RMSerror    = itk::ComputeRMSE< double, OutputImageType, OutputImageType >
-      ( cpuFilter->GetOutput(), gpuFilter->GetOutput(), RMSrelative );
+  const double RMSerror = itk::ComputeRMSE<double, OutputImageType, OutputImageType>(
+    cpuFilter->GetOutput(), gpuFilter->GetOutput(), RMSrelative);
   std::cout << " " << RMSerror << std::endl;
 
   // Check
-  if( RMSerror > epsilon )
+  if (RMSerror > epsilon)
   {
     std::cerr << "ERROR: RMSE between CPU and GPU result larger than expected" << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
 
   // End program.
-  itk::ReleaseContext();
   return EXIT_SUCCESS;
 } // end main()
