@@ -21,6 +21,8 @@
 #include "itkGPUImageFactory.h"
 #include "itkGPUShrinkImageFilterFactory.h"
 
+#include "itkOpenCLContextScopeGuard.h"
+
 // ITK include files
 #include "itkImageFileReader.h"
 #include "itkImageFileWriter.h"
@@ -35,10 +37,10 @@
 // We compare the CPU and GPU output image write RMSE and speed.
 
 int
-main( int argc, char * argv[] )
+main(int argc, char * argv[])
 {
   // Check arguments for help
-  if( argc < 4 )
+  if (argc < 4)
   {
     std::cerr << "ERROR: insufficient command line arguments.\n"
               << "  inputFileName outputNameCPU outputNameGPU" << std::endl;
@@ -49,40 +51,40 @@ main( int argc, char * argv[] )
   itk::SetupForDebugging();
 
   // Create and check OpenCL context
-  if( !itk::CreateContext() )
+  if (!itk::CreateContext())
   {
     return EXIT_FAILURE;
   }
+  const itk::OpenCLContextScopeGuard openCLContextScopeGuard{};
 
   /** Get the command line arguments. */
-  const std::string  inputFileName     = argv[ 1 ];
-  const std::string  outputFileNameCPU = argv[ 2 ];
-  const std::string  outputFileNameGPU = argv[ 3 ];
-  const unsigned int shrinkFactor      = 2;
-  const double       epsilon           = 1e-3;
-  const unsigned int runTimes          = 5;
+  const std::string  inputFileName = argv[1];
+  const std::string  outputFileNameCPU = argv[2];
+  const std::string  outputFileNameGPU = argv[3];
+  const unsigned int shrinkFactor = 2;
+  const double       epsilon = 1e-3;
+  const unsigned int runTimes = 5;
 
-  std::cout << std::showpoint << std::setprecision( 4 );
+  std::cout << std::showpoint << std::setprecision(4);
 
   // Typedefs.
   const unsigned int Dimension = 3;
-  typedef float                              PixelType;
-  typedef itk::Image< PixelType, Dimension > ImageType;
+  using PixelType = float;
+  using ImageType = itk::Image<PixelType, Dimension>;
 
   // CPU Typedefs
-  typedef itk::ShrinkImageFilter
-    < ImageType, ImageType >                 FilterType;
-  typedef itk::ImageFileReader< ImageType > ReaderType;
-  typedef itk::ImageFileWriter< ImageType > WriterType;
+  using FilterType = itk::ShrinkImageFilter<ImageType, ImageType>;
+  using ReaderType = itk::ImageFileReader<ImageType>;
+  using WriterType = itk::ImageFileWriter<ImageType>;
 
   // Reader
-  ReaderType::Pointer reader = ReaderType::New();
-  reader->SetFileName( inputFileName );
+  auto reader = ReaderType::New();
+  reader->SetFileName(inputFileName);
   reader->Update();
 
   // Construct the filter
-  FilterType::Pointer cpuFilter = FilterType::New();
-  cpuFilter->SetShrinkFactors( shrinkFactor );
+  auto cpuFilter = FilterType::New();
+  cpuFilter->SetShrinkFactors(shrinkFactor);
 
   std::cout << "Testing the ShrinkImageFilter, CPU vs GPU:\n";
   std::cout << "CPU/GPU shrinkFactor #threads time speedup RMSE\n";
@@ -90,55 +92,50 @@ main( int argc, char * argv[] )
   // Time the filter, run on the CPU
   itk::TimeProbe cputimer;
   cputimer.Start();
-  for( unsigned int i = 0; i < runTimes; i++ )
+  for (unsigned int i = 0; i < runTimes; ++i)
   {
-    cpuFilter->SetInput( reader->GetOutput() );
+    cpuFilter->SetInput(reader->GetOutput());
     try
     {
       cpuFilter->Update();
     }
-    catch( itk::ExceptionObject & e )
+    catch (itk::ExceptionObject & e)
     {
       std::cerr << "ERROR: " << e << std::endl;
-      itk::ReleaseContext();
       return EXIT_FAILURE;
     }
 
     // Modify the filter, only not the last iteration
-    if( i != runTimes - 1 )
+    if (i != runTimes - 1)
     {
       cpuFilter->Modified();
     }
   }
   cputimer.Stop();
 
-  std::cout << "CPU " << shrinkFactor
-            << " " << cpuFilter->GetNumberOfWorkUnits()
-            << " " << cputimer.GetMean() / runTimes << std::endl;
+  std::cout << "CPU " << shrinkFactor << " " << cpuFilter->GetNumberOfWorkUnits() << " "
+            << cputimer.GetMean() / runTimes << std::endl;
 
   /** Write the CPU result. */
-  WriterType::Pointer writer = WriterType::New();
-  writer->SetInput( cpuFilter->GetOutput() );
-  writer->SetFileName( outputFileNameCPU.c_str() );
+  auto writer = WriterType::New();
+  writer->SetInput(cpuFilter->GetOutput());
+  writer->SetFileName(outputFileNameCPU.c_str());
   try
   {
     writer->Update();
   }
-  catch( itk::ExceptionObject & e )
+  catch (itk::ExceptionObject & e)
   {
     std::cerr << "ERROR: " << e << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
 
   // Register object factory for GPU image and filter
   // All these filters that are constructed after this point are
   // turned into a GPU filter.
-  typedef typelist::MakeTypeList< float >::Type OCLImageTypes;
-  itk::GPUImageFactory2< OCLImageTypes, OCLImageDims >
-  ::RegisterOneFactory();
-  itk::GPUShrinkImageFilterFactory2< OCLImageTypes, OCLImageTypes, OCLImageDims >
-  ::RegisterOneFactory();
+  using OCLImageTypes = typelist::MakeTypeList<float>::Type;
+  itk::GPUImageFactory2<OCLImageTypes, OCLImageDims>::RegisterOneFactory();
+  itk::GPUShrinkImageFilterFactory2<OCLImageTypes, OCLImageTypes, OCLImageDims>::RegisterOneFactory();
 
   // Construct the filter
   // Use a try/catch, because construction of this filter will trigger
@@ -147,22 +144,21 @@ main( int argc, char * argv[] )
   try
   {
     gpuFilter = FilterType::New();
-    itk::ITKObjectEnableWarnings( gpuFilter.GetPointer() );
+    itk::ITKObjectEnableWarnings(gpuFilter.GetPointer());
   }
-  catch( itk::ExceptionObject & e )
+  catch (itk::ExceptionObject & e)
   {
     std::cerr << "ERROR: " << e << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
-  gpuFilter->SetShrinkFactors( shrinkFactor );
+  gpuFilter->SetShrinkFactors(shrinkFactor);
 
   // Also need to re-construct the image reader, so that it now
   // reads a GPUImage instead of a normal image.
   // Otherwise, you will get an exception when running the GPU filter:
   // "ERROR: The GPU InputImage is NULL. Filter unable to perform."
-  ReaderType::Pointer gpuReader = ReaderType::New();
-  gpuReader->SetFileName( inputFileName );
+  auto gpuReader = ReaderType::New();
+  gpuReader->SetFileName(inputFileName);
 
   // \todo: If the following line is uncommented something goes wrong with
   // the ITK pipeline synchronization.
@@ -174,61 +170,56 @@ main( int argc, char * argv[] )
   // Time the filter, run on the GPU
   itk::TimeProbe gputimer;
   gputimer.Start();
-  for( unsigned int i = 0; i < runTimes; i++ )
+  for (unsigned int i = 0; i < runTimes; ++i)
   {
-    gpuFilter->SetInput( gpuReader->GetOutput() );
+    gpuFilter->SetInput(gpuReader->GetOutput());
     try
     {
       gpuFilter->Update();
     }
-    catch( itk::ExceptionObject & e )
+    catch (itk::ExceptionObject & e)
     {
       std::cerr << "ERROR: " << e << std::endl;
-      itk::ReleaseContext();
       return EXIT_FAILURE;
     }
     // Modify the filter, only not the last iteration
-    if( i != runTimes - 1 )
+    if (i != runTimes - 1)
     {
       gpuFilter->Modified();
     }
   }
   gputimer.Stop();
 
-  std::cout << "GPU " << shrinkFactor
-            << " x " << gputimer.GetMean() / runTimes
-            << " " << cputimer.GetMean() / gputimer.GetMean();
+  std::cout << "GPU " << shrinkFactor << " x " << gputimer.GetMean() / runTimes << " "
+            << cputimer.GetMean() / gputimer.GetMean();
 
   /** Write the GPU result. */
-  WriterType::Pointer gpuWriter = WriterType::New();
-  gpuWriter->SetInput( gpuFilter->GetOutput() );
-  gpuWriter->SetFileName( outputFileNameGPU.c_str() );
+  auto gpuWriter = WriterType::New();
+  gpuWriter->SetInput(gpuFilter->GetOutput());
+  gpuWriter->SetFileName(outputFileNameGPU.c_str());
   try
   {
     gpuWriter->Update();
   }
-  catch( itk::ExceptionObject & e )
+  catch (itk::ExceptionObject & e)
   {
     std::cerr << "ERROR: " << e << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
 
   // Compute RMSE
   double       RMSrelative = 0.0;
-  const double RMSerror    = itk::ComputeRMSE< double, ImageType, ImageType >
-      ( cpuFilter->GetOutput(), gpuFilter->GetOutput(), RMSrelative );
+  const double RMSerror =
+    itk::ComputeRMSE<double, ImageType, ImageType>(cpuFilter->GetOutput(), gpuFilter->GetOutput(), RMSrelative);
   std::cout << " " << RMSerror << std::endl;
 
   // Check
-  if( RMSerror > epsilon )
+  if (RMSerror > epsilon)
   {
     std::cerr << "ERROR: RMSE between CPU and GPU result larger than expected" << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
 
   // End program.
-  itk::ReleaseContext();
   return EXIT_SUCCESS;
 } // end main()
