@@ -22,6 +22,8 @@
 #include "itkGPURecursiveGaussianImageFilterFactory.h"
 #include "itkGPUCastImageFilterFactory.h" // used internally in smoothing filter
 
+#include "itkOpenCLContextScopeGuard.h"
+
 // ITK include files
 #include "itkSmoothingRecursiveGaussianImageFilter.h"
 #include "itkImageFileReader.h"
@@ -38,10 +40,10 @@
 // We compare the CPU and GPU output image write RMSE and speed.
 
 int
-main( int argc, char * argv[] )
+main(int argc, char * argv[])
 {
   // Check arguments for help
-  if( argc < 4 )
+  if (argc < 4)
   {
     std::cerr << "ERROR: insufficient command line arguments.\n"
               << "  inputFileName outputNameCPU outputNameGPU" << std::endl;
@@ -52,46 +54,46 @@ main( int argc, char * argv[] )
   itk::SetupForDebugging();
 
   // Create and check OpenCL context
-  if( !itk::CreateContext() )
+  if (!itk::CreateContext())
   {
     return EXIT_FAILURE;
   }
+  const itk::OpenCLContextScopeGuard openCLContextScopeGuard{};
 
   /** Get the command line arguments. */
-  const std::string  inputFileName     = argv[ 1 ];
-  const std::string  outputFileNameCPU = argv[ 2 ];
-  const std::string  outputFileNameGPU = argv[ 3 ];
-  const double       epsilon           = 1e-3;
-  const unsigned int runTimes          = 5;
+  const std::string  inputFileName = argv[1];
+  const std::string  outputFileNameCPU = argv[2];
+  const std::string  outputFileNameGPU = argv[3];
+  const double       epsilon = 1e-3;
+  const unsigned int runTimes = 5;
 
-  std::cout << std::showpoint << std::setprecision( 4 );
+  std::cout << std::showpoint << std::setprecision(4);
 
   // Typedefs.
   const unsigned int Dimension = 3;
-  typedef float                                    InputPixelType;
-  typedef float                                    OutputPixelType;
-  typedef itk::Image< InputPixelType, Dimension >  InputImageType;
-  typedef itk::Image< OutputPixelType, Dimension > OutputImageType;
+  using InputPixelType = float;
+  using OutputPixelType = float;
+  using InputImageType = itk::Image<InputPixelType, Dimension>;
+  using OutputImageType = itk::Image<OutputPixelType, Dimension>;
 
   // CPU Typedefs
-  typedef itk::SmoothingRecursiveGaussianImageFilter
-    < InputImageType, OutputImageType >           FilterType;
-  typedef itk::ImageFileReader< InputImageType >  ReaderType;
-  typedef itk::ImageFileWriter< OutputImageType > WriterType;
+  using FilterType = itk::SmoothingRecursiveGaussianImageFilter<InputImageType, OutputImageType>;
+  using ReaderType = itk::ImageFileReader<InputImageType>;
+  using WriterType = itk::ImageFileWriter<OutputImageType>;
 
   // Reader
-  ReaderType::Pointer reader = ReaderType::New();
-  reader->SetFileName( inputFileName );
+  auto reader = ReaderType::New();
+  reader->SetFileName(inputFileName);
   reader->Update();
 
   // Construct the filter
-  FilterType::Pointer        filter = FilterType::New();
+  auto                       filter = FilterType::New();
   FilterType::SigmaArrayType sigmaArray;
-  for( unsigned int i = 0; i < Dimension; i++ )
+  for (unsigned int i = 0; i < Dimension; ++i)
   {
-    sigmaArray[ i ] = 3.0;
+    sigmaArray[i] = 3.0;
   }
-  filter->SetSigmaArray( sigmaArray );
+  filter->SetSigmaArray(sigmaArray);
 
   std::cout << "Testing the SmoothingRecursiveGaussianImageFilter, CPU vs GPU:\n";
   std::cout << "CPU/GPU sigma #threads time speedup RMSE\n";
@@ -99,39 +101,35 @@ main( int argc, char * argv[] )
   // Time the filter, run on the CPU
   itk::TimeProbe cputimer;
   cputimer.Start();
-  for( unsigned int i = 0; i < runTimes; i++ )
+  for (unsigned int i = 0; i < runTimes; ++i)
   {
-    filter->SetInput( reader->GetOutput() );
+    filter->SetInput(reader->GetOutput());
     try
     {
       filter->Update();
     }
-    catch( itk::ExceptionObject & e )
+    catch (itk::ExceptionObject & e)
     {
       std::cerr << "ERROR: " << e << std::endl;
-      itk::ReleaseContext();
       return EXIT_FAILURE;
     }
     filter->Modified();
   }
   cputimer.Stop();
 
-  std::cout << "CPU " << sigmaArray[ 0 ]
-            << " " << filter->GetNumberOfWorkUnits()
-            << " " << cputimer.GetMean() / runTimes;
+  std::cout << "CPU " << sigmaArray[0] << " " << filter->GetNumberOfWorkUnits() << " " << cputimer.GetMean() / runTimes;
 
   /** Write the CPU result. */
-  WriterType::Pointer writer = WriterType::New();
-  writer->SetInput( filter->GetOutput() );
-  writer->SetFileName( outputFileNameCPU.c_str() );
+  auto writer = WriterType::New();
+  writer->SetInput(filter->GetOutput());
+  writer->SetFileName(outputFileNameCPU.c_str());
   try
   {
     writer->Update();
   }
-  catch( itk::ExceptionObject & e )
+  catch (itk::ExceptionObject & e)
   {
     std::cerr << "ERROR: " << e << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
 
@@ -144,13 +142,10 @@ main( int argc, char * argv[] )
   // that internally uses the recursive filter. By registering the recursive
   // filter, we now automatically use it, even if it's usage is hidden by a
   // wrapper.
-  typedef typelist::MakeTypeList< float >::Type OCLImageTypes;
-  itk::GPUImageFactory2< OCLImageTypes, OCLImageDims >
-  ::RegisterOneFactory();
-  itk::GPURecursiveGaussianImageFilterFactory2< OCLImageTypes, OCLImageTypes, OCLImageDims >
-  ::RegisterOneFactory();
-  itk::GPUCastImageFilterFactory2< OCLImageTypes, OCLImageTypes, OCLImageDims >
-  ::RegisterOneFactory();
+  using OCLImageTypes = typelist::MakeTypeList<float>::Type;
+  itk::GPUImageFactory2<OCLImageTypes, OCLImageDims>::RegisterOneFactory();
+  itk::GPURecursiveGaussianImageFilterFactory2<OCLImageTypes, OCLImageTypes, OCLImageDims>::RegisterOneFactory();
+  itk::GPUCastImageFilterFactory2<OCLImageTypes, OCLImageTypes, OCLImageDims>::RegisterOneFactory();
 
   // Construct the filter
   // Use a try/catch, because construction of this filter will trigger
@@ -159,22 +154,21 @@ main( int argc, char * argv[] )
   try
   {
     gpuFilter = FilterType::New();
-    itk::ITKObjectEnableWarnings( gpuFilter.GetPointer() );
+    itk::ITKObjectEnableWarnings(gpuFilter.GetPointer());
   }
-  catch( itk::ExceptionObject & e )
+  catch (itk::ExceptionObject & e)
   {
     std::cerr << "ERROR: " << e << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
-  gpuFilter->SetSigmaArray( sigmaArray );
+  gpuFilter->SetSigmaArray(sigmaArray);
 
   // Also need to re-construct the image reader, so that it now
   // reads a GPUImage instead of a normal image.
   // Otherwise, you will get an exception when running the GPU filter:
   // "ERROR: The GPU InputImage is NULL. Filter unable to perform."
-  ReaderType::Pointer gpuReader = ReaderType::New();
-  gpuReader->SetFileName( inputFileName );
+  auto gpuReader = ReaderType::New();
+  gpuReader->SetFileName(inputFileName);
 
   // \todo: If the following line is uncommented something goes wrong with
   // the ITK pipeline synchronization.
@@ -186,57 +180,52 @@ main( int argc, char * argv[] )
   // Time the filter, run on the GPU
   itk::TimeProbe gputimer;
   gputimer.Start();
-  for( unsigned int i = 0; i < runTimes; i++ )
+  for (unsigned int i = 0; i < runTimes; ++i)
   {
-    gpuFilter->SetInput( gpuReader->GetOutput() );
+    gpuFilter->SetInput(gpuReader->GetOutput());
     try
     {
       gpuFilter->Update();
     }
-    catch( itk::ExceptionObject & e )
+    catch (itk::ExceptionObject & e)
     {
       std::cerr << "ERROR: " << e << std::endl;
-      itk::ReleaseContext();
       return EXIT_FAILURE;
     }
     gpuFilter->Modified();
   }
   gputimer.Stop();
 
-  std::cout << "GPU " << sigmaArray[ 0 ]
-            << " x " << gputimer.GetMean() / runTimes
-            << " " << cputimer.GetMean() / gputimer.GetMean();
+  std::cout << "GPU " << sigmaArray[0] << " x " << gputimer.GetMean() / runTimes << " "
+            << cputimer.GetMean() / gputimer.GetMean();
 
   /** Write the GPU result. */
-  WriterType::Pointer gpuWriter = WriterType::New();
-  gpuWriter->SetInput( gpuFilter->GetOutput() );
-  gpuWriter->SetFileName( outputFileNameGPU.c_str() );
+  auto gpuWriter = WriterType::New();
+  gpuWriter->SetInput(gpuFilter->GetOutput());
+  gpuWriter->SetFileName(outputFileNameGPU.c_str());
   try
   {
     gpuWriter->Update();
   }
-  catch( itk::ExceptionObject & e )
+  catch (itk::ExceptionObject & e)
   {
     std::cerr << "ERROR: " << e << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
 
   // Compute RMSE
   double       RMSrelative = 0.0;
-  const double RMSerror    = itk::ComputeRMSE< double, OutputImageType, OutputImageType >
-      ( filter->GetOutput(), gpuFilter->GetOutput(), RMSrelative );
+  const double RMSerror = itk::ComputeRMSE<double, OutputImageType, OutputImageType>(
+    filter->GetOutput(), gpuFilter->GetOutput(), RMSrelative);
   std::cout << " " << RMSerror << std::endl;
 
   // Check
-  if( RMSerror > epsilon )
+  if (RMSerror > epsilon)
   {
     std::cerr << "ERROR: RMSE between CPU and GPU result larger than expected" << std::endl;
-    itk::ReleaseContext();
     return EXIT_FAILURE;
   }
 
   // End program.
-  itk::ReleaseContext();
   return EXIT_SUCCESS;
 } // end main()
