@@ -15,15 +15,15 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkOpenCLImageTest_h
-#define __itkOpenCLImageTest_h
+#ifndef itkOpenCLImageTest_h
+#define itkOpenCLImageTest_h
 
 #include "itkMacro.h"
 
 namespace itk
 {
 /** Create a helper GPU Kernel class for OpenCLImageTest.cl kernel */
-itkGPUKernelClassMacro( OpenCLImageTestKernel );
+itkGPUKernelClassMacro(OpenCLImageTestKernel);
 } // end namespace itk
 
-#endif /* __itkOpenCLImageTest_h */
+#endif /* itkOpenCLImageTest_h */
