@@ -19,24 +19,24 @@
 #include "itkOpenCLPlatform.h"
 
 int
-main( int argc, char * argv[] )
+main()
 {
   itk::OpenCLPlatform platform;
 
-  if( !platform.IsNull() )
+  if (!platform.IsNull())
   {
     return EXIT_FAILURE;
   }
 
   // Check null platform
-  ITK_OPENCL_COMPARE( platform.GetPlatformId(), cl_platform_id( 0 ) );
-  ITK_OPENCL_COMPARE( platform == platform, true );
-  ITK_OPENCL_COMPARE( !( platform != platform ), true );
-  ITK_OPENCL_COMPARE( platform.GetName().empty(), true );
+  ITK_OPENCL_COMPARE(platform.GetPlatformId(), cl_platform_id(0));
+  ITK_OPENCL_COMPARE(platform == platform, true);
+  ITK_OPENCL_COMPARE(!(platform != platform), true);
+  ITK_OPENCL_COMPARE(platform.GetName().empty(), true);
 
   // Get all platforms and print it
-  const std::list< itk::OpenCLPlatform > platforms = itk::OpenCLPlatform::GetAllPlatforms();
-  for( std::list< itk::OpenCLPlatform >::const_iterator it = platforms.begin(); it != platforms.end(); ++it )
+  const std::list<itk::OpenCLPlatform> platforms = itk::OpenCLPlatform::GetAllPlatforms();
+  for (std::list<itk::OpenCLPlatform>::const_iterator it = platforms.begin(); it != platforms.end(); ++it)
   {
     std::cout << *it;
   }
