@@ -80,11 +80,11 @@ main(int argc, char * argv[])
     {
       if (context->GetDefaultDevice().HasCompiler())
       {
-        itkGenericExceptionMacro(<< "Could not compile the OpenCL test program");
+        itkGenericExceptionMacro("Could not compile the OpenCL test program");
       }
       else
       {
-        itkGenericExceptionMacro(<< "OpenCL implementation does not have a compiler");
+        itkGenericExceptionMacro("OpenCL implementation does not have a compiler");
       }
     }
 
