@@ -15,15 +15,15 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkOpenCLVectorTest_h
-#define __itkOpenCLVectorTest_h
+#ifndef itkOpenCLVectorTest_h
+#define itkOpenCLVectorTest_h
 
 #include "itkMacro.h"
 
 namespace itk
 {
 /** Create a helper GPU Kernel class for OpenCLVectorTest.cl kernel */
-itkGPUKernelClassMacro( OpenCLVectorTestKernel );
+itkGPUKernelClassMacro(OpenCLVectorTestKernel);
 } // end namespace itk
 
-#endif /* __itkOpenCLVectorTest_h */
+#endif /* itkOpenCLVectorTest_h */
