@@ -19,14 +19,6 @@
 
 namespace itk
 {
-//------------------------------------------------------------------------------
-void
-TestOutputWindow::PrintSelf(std::ostream & os, Indent indent) const
-{
-  Superclass::PrintSelf(os, indent);
-}
-
-
 //------------------------------------------------------------------------------
 void
 TestOutputWindow::DisplayText(const char * text)
