@@ -275,8 +275,6 @@ main(int argc, char * argv[])
     //   std::cerr << "L matrix inversion (method 2, lu ) took: "
     //     << clock() - startClock << " ms." << std::endl;
 
-    // To do: Add SuiteSparse tests.
-
     // Write L Matrix to Matlab file. For inspection of matrix appearance.
     std::ostringstream makeFileName;
     makeFileName << argv[2] << "/LMatrix_N" << numberOfLandmarks << ".mat";
@@ -298,8 +296,8 @@ main(int argc, char * argv[])
     p[2] = 11.0;
     timeCollector.Start("ComputeJacobianOLD");
     JacobianType jac1;
-    jac1.SetSize(Dimension, numberOfLandmarks * Dimension);
-    jac1.Fill(0.0);
+    jac1.set_size(Dimension, numberOfLandmarks * Dimension);
+    jac1.fill(0.0);
     PointsIterator sp = usedLandmarks->GetPoints()->Begin();
     for (unsigned int lnd = 0; lnd < numberOfLandmarks; ++lnd)
     {
